@@ -70,7 +70,7 @@ static  void    delete_global_namepool(CSOUND *);
 static  void    delete_local_namepool(CSOUND *);
 static  int     pnum(char *s) ;
 
-extern void     print_tree(CSOUND *, TREE *);
+extern void     print_tree(CSOUND *, char *, TREE *);
 
 void close_instrument(CSOUND *csound, INSTRTXT * ip);
 
@@ -161,57 +161,62 @@ static void append_optxt(OPTXT *op1, OPTXT *op2)
  * only once if used multiple times; to be removed or reused in context
  * of redoing namset functions (if even desirable)
  */
-/* void update_lclcount(CSOUND *csound, INSTRTXT *ip, TREE *argslist)
+
+/*
+void update_lclcount(CSOUND *csound, INSTRTXT *ip, TREE *argslist)
 {
     TREE * current = argslist;
 
     while(current != NULL) {
-        switch(current->type) {
-            case T_IDENT_S:
-                ip->lclscnt++;
-                csound->Message(csound, "S COUNT INCREASED: %d\n", ip->lclscnt);
-                break;
-            case T_IDENT_W:
-                ip->lclwcnt++;
-                csound->Message(csound, "W COUNT INCREASED: %d\n", ip->lclwcnt);
-                break;
-            case T_IDENT_A:
-                ip->lclacnt++;
-                csound->Message(csound, "A COUNT INCREASED: %d\n", ip->lclacnt);
-                break;
-            case T_IDENT_K:
-            case T_IDENT_F:
-            case T_IDENT_I:
-            case T_NUMBER:
-            case T_INTGR:
-            default:
-                ip->lclkcnt++;
-                csound->Message(csound, "K COUNT INCREASED: %d\n", ip->lclkcnt);
-        }
-        current = current->next;
+      switch(current->type) {
+      case T_IDENT_S:
+        ip->lclscnt++;
+        if (UNLIKELY(PARSER_DEBUG))
+          csound->Message(csound, "S COUNT INCREASED: %d\n", ip->lclscnt);
+        break;
+      case T_IDENT_W:
+        ip->lclwcnt++;
+        if (UNLIKELY(PARSER_DEBUG))
+          csound->Message(csound, "W COUNT INCREASED: %d\n", ip->lclwcnt);
+        break;
+      case T_IDENT_A:
+        ip->lclacnt++;
+        if (UNLIKELY(PARSER_DEBUG))
+          csound->Message(csound, "A COUNT INCREASED: %d\n", ip->lclacnt);
+        break;
+      case T_IDENT_K:
+      case T_IDENT_F:
+      case T_IDENT_I:
+      case T_NUMBER:
+      case T_INTGR:
+      default:
+        ip->lclkcnt++;
+        if (UNLIKELY(PARSER_DEBUG))
+          csound->Message(csound, "K COUNT INCREASED: %d\n", ip->lclkcnt);
+      }
+      current = current->next;
     }
-}*/
+}
+*/
 
 void set_xincod(CSOUND *csound, TEXT *tp, OENTRY *ep)
 {
     int n = tp->inlist->count;
     char *s;
     char *types = ep->intypes;
-    int nreqd = -1;
+    int nreqd = strlen(types);
     char      tfound = '\0', treqd;
 
-    if (nreqd < 0)    /* for other opcodes */
-      nreqd = strlen(types = ep->intypes);
-
-    /*if (n > nreqd) {*/                  /* IV - Oct 24 2002: end of new code */
-    /*if ((treqd = types[nreqd-1]) == 'n') {*/  /* indef args: */
-    /*  if (!(incnt & 01))*/                    /* require odd */
-    /*synterr(csound, Str("missing or extra arg"));*/
-    /*}*/       /* IV - Sep 1 2002: added 'M' */
-    /*else if (treqd != 'm' && treqd != 'z' && treqd != 'y' &&*/
-    /*treqd != 'Z' && treqd != 'M' && treqd != 'N')*/ /* else any no */
-    /*synterr(csound, Str("too many input args"));*/
-    /*}*/
+    if (n > nreqd) {                 /* IV - Oct 24 2002: end of new code */
+      if ((treqd = types[nreqd-1]) == 'n') {  /* indef args: */
+        int incnt = -1;                       /* Should count args */
+        if (!(incnt & 01))                    /* require odd */
+          synterr(csound, Str("missing or extra arg"));
+      }       /* IV - Sep 1 2002: added 'M' */
+      else if (treqd != 'm' && treqd != 'z' && treqd != 'y' &&
+               treqd != 'Z' && treqd != 'M' && treqd != 'N') /* else any no */
+        synterr(csound, Str("too many input args\n"));
+    }
 
     while (n--) {                     /* inargs:   */
       s = tp->inlist->arg[n];
@@ -288,7 +293,8 @@ void set_xoutcod(CSOUND *csound, TEXT *tp, OENTRY *ep)
 /*      if ((n != nreqd) &&       */        /* IV - Oct 24 2002: end of new code */
 /*          !(n > 0 && n < nreqd &&
             (types[n] == (char) 'm' || types[n] == (char) 'z' ||
-             types[n] == (char) 'X' || types[n] == (char) 'N'))) {
+             types[n] == (char) 'X' || types[n] == (char) 'N' ||
+             types[n] == (char) 'F' || types[n] == (char) 'I'))) {
              synterr(csound, Str("illegal no of output args"));
              if (n > nreqd)
              n = nreqd;
@@ -358,7 +364,7 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
     case T_OPCODE:
     case T_OPCODE0:
     case S_ASSIGN:
-      if (PARSER_DEBUG)
+      if (UNLIKELY(PARSER_DEBUG))
         csound->Message(csound,
                         "create_opcode: Found node for opcode %s\n",
                         root->value->lexeme);
@@ -400,7 +406,8 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
 
           if ((n = pnum(arg)) >= 0) {
             if (n > ip->pmax)  ip->pmax = n;
-          } else {
+          }
+          else {
             lgbuild(csound, arg);
           }
 
@@ -421,7 +428,8 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
 
           if ((n = pnum(arg)) >= 0) {
             if (n > ip->pmax)  ip->pmax = n;
-          } else {
+          }
+          else {
             lgbuild(csound, arg);
           }
 
@@ -444,14 +452,16 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
         if (root->right != NULL) {
           if (ep->intypes[0] != 'l') {     /* intype defined by 1st inarg */
             tp->intype = argtyp2(csound, tp->inlist->arg[0]);
-          } else  {
+          }
+          else  {
             tp->intype = 'l';          /*   (unless label)  */
           }
         }
 
-        if (root->left != NULL) {                       /* pftype defined by outarg */
+        if (root->left != NULL) {      /* pftype defined by outarg */
           tp->pftype = argtyp2(csound, root->left->value->lexeme);
-        } else {                            /*    else by 1st inarg     */
+        }
+        else {                            /*    else by 1st inarg     */
           tp->pftype = tp->intype;
         }
 
@@ -462,9 +472,9 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
       break;
     default:
       csound->Message(csound,
-                      Str("create_opcode: No rule to handle statemnent of "
+                      Str("create_opcode: No rule to handle statement of "
                           "type %d\n"), root->type);
-      print_tree(csound, root);
+      print_tree(csound, NULL, root);
     }
 
     if (retOptxt == NULL) {
@@ -542,7 +552,8 @@ INSTRTXT *create_instrument0(CSOUND *csound, TREE *root)
 
       if (current->type != T_INSTR && current->type != T_UDO) {
 
-        /* csound->Message(csound, "In INSTR 0: %s\n", current->value->lexeme); */
+        if (UNLIKELY(PARSER_DEBUG))
+          csound->Message(csound, "In INSTR 0: %s\n", current->value->lexeme);
 
         if (current->type == S_ASSIGN
            && strcmp(current->value->lexeme, "=.r") == 0) {
@@ -551,7 +562,7 @@ INSTRTXT *create_instrument0(CSOUND *csound, TREE *root)
                                             current->right->value->lexeme)];
 
 
-          /* if(current->right->type == T_INTGR) {
+          /* if (current->right->type == T_INTGR) {
              val = FL(current->right->value->value);
              } else {
              val = FL(current->right->value->fvalue);
@@ -560,21 +571,26 @@ INSTRTXT *create_instrument0(CSOUND *csound, TREE *root)
           /* modify otran defaults*/
           if (current->left->type == T_SRATE) {
             csound->tran_sr = val;
-          } else if (current->left->type == T_KRATE) {
+          }
+          else if (current->left->type == T_KRATE) {
             csound->tran_kr = val;
-          } else if (current->left->type == T_KSMPS) {
+          }
+          else if (current->left->type == T_KSMPS) {
             csound->tran_ksmps = val;
-          } else if (current->left->type == T_NCHNLS) {
+          }
+          else if (current->left->type == T_NCHNLS) {
             csound->tran_nchnls = current->right->value->value;
-          } else if (current->left->type == T_NCHNLSI) {
+          }
+          else if (current->left->type == T_NCHNLSI) {
             csound->tran_nchnlsi = current->right->value->value;
             /* csound->Message(csound, "SETTING NCHNLS: %d\n", csound->tran_nchnls); */
           }
-          /* TODO - Implement 0dbfs constant */
-          /*else if (strcmp(s, "0dbfs") == 0) {*/
-          /* we have set this as reserved in rdorch.c */
-          /*csound->tran_0dbfs = constval;
-            }*/
+          else if (current->left->type == T_0DBFS) {
+            csound->tran_0dbfs = val;
+            csound->Message(csound, "SETTING 0DBFS: %f\n", csound->tran_0dbfs);
+          }
+
+          /* TODO - Implement 0dbfs constant  -- surely done?? */
         }
 
         op->nxtop = create_opcode(csound, current, ip);
@@ -650,7 +666,9 @@ INSTRTXT *create_instrument(CSOUND *csound, TREE *root)
       c = csound->Malloc(csound, 10); /* arbritrarily chosen number of digits */
       sprintf(c, "%ld", instrNum);
 
-      csound->Message(csound, Str("create_instrument: instr num %ld\n"), instrNum);
+      if (PARSER_DEBUG)
+          csound->Message(csound,
+                          Str("create_instrument: instr num %ld\n"), instrNum);
 
       ip->t.inlist->arg[0] = strsav_string(csound, c);
 
@@ -659,7 +677,8 @@ INSTRTXT *create_instrument(CSOUND *csound, TREE *root)
       int32  insno_priority = -1L;
       c = root->left->value->lexeme;
 
-      csound->Message(csound, Str("create_instrument: instr name %s\n"), c);
+      if (PARSER_DEBUG)
+          csound->Message(csound, Str("create_instrument: instr name %s\n"), c);
 
       if (UNLIKELY(*c == '+')) {
         insno_priority--; c++;
@@ -951,6 +970,7 @@ OPCODINFO *find_opcode_info(CSOUND *csound, char *opname) {
         if (UNLIKELY(strcmp(opinfo->name, opname) == 0)) {
             return opinfo;
         }
+        opinfo = opinfo->prv;   /* Move on: JPff suggestion */
     }
 
     return NULL;
@@ -969,6 +989,8 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
     OPTXT       *bp;
     char        *opname;
     int32        count, sumcount, instxtcount, optxtcount;
+    TREE * current = root;
+    INSTRTXT * instr0;
 
     strsav_create(csound);
 
@@ -985,6 +1007,7 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
     gblnamset(csound, "kr");
     gblnamset(csound, "ksmps");
     gblnamset(csound, "nchnls");
+    gblnamset(csound, "nchnls_i");
     gblnamset(csound, "0dbfs"); /* no commandline override for that! */
     gblnamset(csound, "$sr");   /* incl command-line overrides */
     gblnamset(csound, "$kr");
@@ -996,96 +1019,101 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
     ST(constTbl) = (int*) mcalloc(csound, (256 + NCONSTS) * sizeof(int));
     constndx(csound, "0");
 
-
-    TREE * current = root;
-
-    INSTRTXT * instr0 = create_instrument0(csound, root);
+    instr0 = create_instrument0(csound, root);
     prvinstxt = prvinstxt->nxtinstxt = instr0;
     insert_instrtxt(csound, instr0, 0);
 
     while (current != NULL) {
 
-        switch (current->type) {
-            case T_INIT:
-            case S_ASSIGN:
-                /* csound->Message(csound, "Assignment found\n"); */
-                break;
-            case T_INSTR:
-                /* csound->Message(csound, "Instrument found\n"); */
+      switch (current->type) {
+      case T_INIT:
+      case S_ASSIGN:
+        /* csound->Message(csound, "Assignment found\n"); */
+        break;
+      case T_INSTR:
+        /* csound->Message(csound, "Instrument found\n"); */
 
-                resetouts(csound); /* reset #out counts */
-                lblclear(csound); /* restart labelist  */
+        resetouts(csound); /* reset #out counts */
+        lblclear(csound); /* restart labelist  */
 
-                instrtxt = create_instrument(csound, current);
+        instrtxt = create_instrument(csound, current);
 
-                prvinstxt = prvinstxt->nxtinstxt = instrtxt;
+        prvinstxt = prvinstxt->nxtinstxt = instrtxt;
 
-                /* Handle Inserting into CSOUND here by checking id's (name or
-                 * numbered) and using new insert_instrtxt?
-                 */
-                printf("Starting to install instruments\n");
-                /* Temporarily using the following code */
-                if (current->left->type == T_INTGR) { /* numbered instrument */
-                  int32 instrNum = (int32)current->left->value->value;
+        /* Handle Inserting into CSOUND here by checking id's (name or
+         * numbered) and using new insert_instrtxt?
+         */
+        //printf("Starting to install instruments\n");
+        /* Temporarily using the following code */
+        if (current->left->type == T_INTGR) { /* numbered instrument */
+          int32 instrNum = (int32)current->left->value->value;
 
-                  insert_instrtxt(csound, instrtxt, instrNum);
-                }
-                else if (current->left->type == T_INTLIST) {
-                  TREE *p =  current->left;
-                  printf("intlist case:\n");
-                  while (p) {
-                    print_tree(csound, p);
-                    if (p->left)
-                    insert_instrtxt(csound, instrtxt, p->left->value->value);
-                    else {
-                      insert_instrtxt(csound, instrtxt, p->value->value);
-                      break;
-                    }
-                    p = p->right;
-                  }
-                }
+          insert_instrtxt(csound, instrtxt, instrNum);
+        }
+        else if (current->left->type == T_INSTLIST) {
+          TREE *p =  current->left;
+          //printf("instlist case:\n"); /* This code is suspect */
+          while (p) {
+            print_tree(csound, "Top of loop\n", p);
+            if (p->left) {
+              //print_tree(csound, "Left\n", p->left);
+              if (p->left->type == T_INTGR)
+                insert_instrtxt(csound, instrtxt, p->left->value->value);
+            }
+            else {
+              if (p->type == T_INTGR)
+                insert_instrtxt(csound, instrtxt, p->value->value);
+              break;
+            }
+            p = p->right;
+          }
+        }
+        break;
+      case T_UDO:
+        /* csound->Message(csound, "UDO found\n"); */
 
-                break;
-            case T_UDO:
-                /* csound->Message(csound, "UDO found\n"); */
+        resetouts(csound); /* reset #out counts */
+        lblclear(csound); /* restart labelist  */
 
-                resetouts(csound); /* reset #out counts */
-                lblclear(csound); /* restart labelist  */
+        instrtxt = create_instrument(csound, current);
 
-                instrtxt = create_instrument(csound, current);
+        prvinstxt = prvinstxt->nxtinstxt = instrtxt;
 
-                prvinstxt = prvinstxt->nxtinstxt = instrtxt;
+        opname = current->left->value->lexeme;
 
-                opname = current->left->value->lexeme;
+        /* csound->Message(csound, */
+        /*     "Searching for OPCODINFO for opname: %s\n", opname); */
 
-                /* csound->Message(csound, */
-                /*     "Searching for OPCODINFO for opname: %s\n", opname); */
+        OPCODINFO *opinfo = find_opcode_info(csound, opname);
 
-                OPCODINFO *opinfo = find_opcode_info(csound, opname);
-
-                if (UNLIKELY(opinfo == NULL)) {
-                    csound->Message(csound,
-                        "ERROR: Could not find OPCODINFO for opname: %s\n",
-                        opname);
-                }
-                else {
-                    opinfo->ip = instrtxt;
-                    instrtxt->insname = (char*)mmalloc(csound, 1+strlen(opname));
-                    strcpy(instrtxt->insname, opname);
-                    instrtxt->opcode_info = opinfo;
-                }
-
-                /* Handle Inserting into CSOUND here by checking id's (name or
-                 * numbered) and using new insert_instrtxt?
-                 */
-
-                break;
-            default:
-              csound->Message(csound, Str("Unknown TREE node of type %d found in root.\n"), current->type);
-                if (PARSER_DEBUG) print_tree(csound, current);
+        if (UNLIKELY(opinfo == NULL)) {
+          csound->Message(csound,
+                          "ERROR: Could not find OPCODINFO for opname: %s\n",
+                          opname);
+        }
+        else {
+          opinfo->ip = instrtxt;
+          instrtxt->insname = (char*)mmalloc(csound, 1+strlen(opname));
+          strcpy(instrtxt->insname, opname);
+          instrtxt->opcode_info = opinfo;
         }
 
-        current = current->next;
+        /* Handle Inserting into CSOUND here by checking id's (name or
+         * numbered) and using new insert_instrtxt?
+         */
+
+        break;
+      case T_OPCODE:
+      case T_OPCODE0:
+        break;
+      default:
+        csound->Message(csound,
+                        Str("Unknown TREE node of type %d found in root.\n"),
+                        current->type);
+        /* if (PARSER_DEBUG) */ print_tree(csound, NULL, current);
+      }
+
+      current = current->next;
 
     }
 
@@ -1155,9 +1183,12 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
       int thread, opnum = bp->t.opnum;
       if (opnum == ENDIN) break;
       if (opnum == LABEL) continue;
+      if (PARSER_DEBUG) printf("Instr 0 check on opcode=%s\n", bp->t.opcod);
       if (UNLIKELY((thread = csound->opcodlst[opnum].thread) & 06 ||
-                   (!thread && bp->t.pftype != 'b')))
+                   (!thread && bp->t.pftype != 'b'))) {
+        printf("***opcode=%s thread=%d pftype=%c\n", bp->t.opcod, thread, bp->t.pftype);
         synterr(csound, Str("perf-pass statements illegal in header blk\n"));
+      }
     }
     if (UNLIKELY(csound->synterrcnt)) {
       print_opcodedir_warning(csound);
@@ -1581,6 +1612,7 @@ static NAME *lclnamset(CSOUND *csound, char *s)
       case 'w': p->type = WTYPE; p->count = ST(lclnxtwcnt)++; break;
       case 'a': p->type = ATYPE; p->count = ST(lclnxtacnt)++; break;
       case 'f': p->type = PTYPE; p->count = ST(lclnxtpcnt)++; break;
+      case 't': p->type = PTYPE; p->count = ST(lclnxtpcnt)++; break;
       case 'S': p->type = STYPE; p->count = ST(lclnxtscnt)++; break;
       default:  p->type = KTYPE; p->count = ST(lclnxtkcnt)++; break;
     }
@@ -1745,7 +1777,7 @@ static void convert_strconst_pool(CSOUND *csound, MYFLT *dst)
 #endif
 
 char argtyp2(CSOUND *csound, char *s)
-{                       /* find arg type:  d, w, a, k, i, c, p, r, S, B, b */
+{                       /* find arg type:  d, w, a, k, i, c, p, r, S, B, b, t */
     char c = *s;        /*   also set lgprevdef if !c && !p && !S */
 
     /* csound->Message(csound, "\nArgtyp2: received %s\n", s); */
@@ -1763,7 +1795,7 @@ char argtyp2(CSOUND *csound, char *s)
       return('S');                              /* quoted String */
       /* ST(lgprevdef) = lgexist(csound, s);  */             /* (lgprev) */
     if (strcmp(s,"sr") == 0    || strcmp(s,"kr") == 0 ||
-        strcmp(s,"0dbfs") == 0 ||
+        strcmp(s,"0dbfs") == 0 || strcmp(s,"nchnls_i") == 0 ||
         strcmp(s,"ksmps") == 0 || strcmp(s,"nchnls") == 0)
       return('r');                              /* rsvd */
     if (c == 'w')               /* N.B. w NOT YET #TYPE OR GLOBAL */
@@ -1772,7 +1804,7 @@ char argtyp2(CSOUND *csound, char *s)
       c = *(++s);
     if (c == 'g')
       c = *(++s);
-    if (strchr("akiBbfS", c) != NULL)
+    if (strchr("akiBbfSt", c) != NULL)
       return(c);
     else return('?');
 }
