@@ -26,12 +26,17 @@
 #include "csound_orc.h"
 
 extern char argtyp2(CSOUND *, char *);
-extern void print_tree(CSOUND *, TREE *);
+extern void print_tree(CSOUND *, char *, TREE *);
 extern void handle_polymorphic_opcode(CSOUND*, TREE *);
 extern void handle_optional_args(CSOUND *, TREE *);
 extern ORCTOKEN *make_token(CSOUND *, char *);
 extern ORCTOKEN *make_label(CSOUND *, char *);
 
+TREE* create_boolean_expression(CSOUND*, TREE*);
+TREE * create_expression(CSOUND *, TREE *);
+
+static int genlabs = 300;
+
 char *create_out_arg(CSOUND *csound, char outype)
 {
     char* s = (char *)csound->Malloc(csound, 8);
@@ -80,7 +85,7 @@ char *set_expression_type(CSOUND *csound, char * op, char arg1, char arg2)
 
     s = create_out_arg(csound, outype);
 
-    if (PARSER_DEBUG)
+    if (UNLIKELY(PARSER_DEBUG))
       csound->Message(csound, "SET_EXPRESSION_TYPE: %s : %s\n", op, s);
 
     return s;
@@ -89,7 +94,7 @@ char *set_expression_type(CSOUND *csound, char * op, char arg1, char arg2)
 char * get_boolean_arg(CSOUND *csound, int type)
 {
     char* s = (char *)csound->Malloc(csound, 8);
-
+    //    type = 1;
     sprintf(s, "#%c%d", type?'B':'b',csound->Bcount++);
 
     return s;
@@ -118,7 +123,7 @@ TREE *create_empty_token(CSOUND *csound)
 {
     TREE *ans;
     ans = (TREE*)mmalloc(csound, sizeof(TREE));
-    if (ans==NULL) {
+    if (UNLIKELY(ans==NULL)) {
       /* fprintf(stderr, "Out of memory\n"); */
       exit(1);
     }
@@ -136,7 +141,7 @@ TREE *create_minus_token(CSOUND *csound)
 {
     TREE *ans;
     ans = (TREE*)mmalloc(csound, sizeof(TREE));
-    if (ans==NULL) {
+    if (UNLIKELY(ans==NULL)) {
       /* fprintf(stderr, "Out of memory\n"); */
       exit(1);
     }
@@ -177,7 +182,7 @@ TREE * create_goto_token(CSOUND *csound, char * booleanVar,
                          TREE * gotoNode, int type)
 {
 /*     TREE *ans = create_empty_token(csound); */
-    char* op = (char *)csound->Malloc(csound, 7);
+    char* op = (char *)csound->Malloc(csound, 7); /* Unchecked */
     TREE *opTree, *bVar;
 
     switch(gotoNode->type) {
@@ -195,7 +200,8 @@ TREE * create_goto_token(CSOUND *csound, char * booleanVar,
       sprintf(op, "cngoto");
       break;
     default:
-      sprintf(op, "cggoto");
+      if (type) sprintf(op, "ckgoto");
+      else sprintf(op, "cggoto");
     }
 
     opTree = create_opcode_token(csound, op);
@@ -212,12 +218,12 @@ TREE * create_goto_token(CSOUND *csound, char * booleanVar,
 }
 
 /* THIS PROBABLY NEEDS TO CHANGE TO RETURN DIFFERENT GOTO TYPES LIKE IGOTO, ETC */
-TREE *create_simple_goto_token(CSOUND *csound, TREE *label)
+TREE *create_simple_goto_token(CSOUND *csound, TREE *label, int type)
 {
     char* op = (char *)csound->Calloc(csound, 6);
     TREE * opTree;
-
-    sprintf(op, "kgoto");
+    char *gt[3] = {"kgoto", "igoto", "goto"};
+    sprintf(op, gt[type]);       /* kgoto, igoto, goto ?? */
     opTree = create_opcode_token(csound, op);
     opTree->left = NULL;
     opTree->right = label;
@@ -226,7 +232,7 @@ TREE *create_simple_goto_token(CSOUND *csound, TREE *label)
 }
 
 /* Returns true if passed in TREE node is a numerical expression */
-int is_expression_node(TREE *node)
+static int is_expression_node(TREE *node)
 {
     if (node == NULL) {
       return 0;
@@ -237,6 +243,8 @@ int is_expression_node(TREE *node)
     case S_MINUS:
     case S_TIMES:
     case S_DIV:
+    case S_MOD:
+    case S_POW:
     case T_FUNCTION:
     case S_UMINUS:
     case S_BITOR:
@@ -245,13 +253,15 @@ int is_expression_node(TREE *node)
     case S_BITSHL:
     case S_NEQV:
     case S_BITNOT:
+    case S_Q:
+    case S_TABREF:
       return 1;
     }
    return 0;
 }
 
 /* Returns if passed in TREE node is a boolean expression */
-int is_boolean_expression_node(TREE *node)
+static int is_boolean_expression_node(TREE *node)
 {
     if (node == NULL) {
       return 0;
@@ -271,7 +281,65 @@ int is_boolean_expression_node(TREE *node)
     return 0;
 }
 
+static TREE *create_cond_expression(CSOUND *csound, TREE *root)
+{
+    char *op = (char*)mmalloc(csound, 4), arg1, arg2, *outarg = NULL;
+    char outype, *s;
+    TREE *anchor = create_boolean_expression(csound, root->left), *last;
+    TREE * opTree;
+    TREE *b= create_ans_token(csound, anchor->left->value->lexeme);;
+    TREE *c = root->right->left, *d = root->right->right;
+    last = anchor;
+    while (last->next != NULL) {
+      last = last->next;
+    }
+    if (is_expression_node(c)) {
+      last->next = create_expression(csound, c);
+      /* TODO - Free memory of old left node
+         freetree */
+      last = last->next;
+      while (last->next != NULL) {
+        last = last->next;
+      }
+      c = create_ans_token(csound, last->left->value->lexeme);
+    }
+    if (is_expression_node(d)) {
+      last->next = create_expression(csound, d);
+      /* TODO - Free memory of old left node
+         freetree */
+      last = last->next;
+      while (last->next != NULL) {
+        last = last->next;
+      }
+      d = create_ans_token(csound, last->left->value->lexeme);
+    }
 
+    arg1 = argtyp2(csound, c->value->lexeme);
+    arg2 = argtyp2(csound, d->value->lexeme);
+    if (arg1 == 'a' || arg2 == 'a') {
+      strcpy(op,":a");
+      outype = 'a';
+    }
+    else if (arg1 == 'k' || arg2 == 'k') {
+      strcpy(op,":k");
+      outype = 'k';
+    }
+    else {
+      strcpy(op,":i");
+      outype = 'i';
+      }
+    outarg = create_out_arg(csound, outype);
+    opTree = create_opcode_token(csound, op);
+    opTree->left = create_ans_token(csound, outarg);
+    opTree->right = b;
+    opTree->right->next = c;
+    opTree->right->next->next = d;
+    /* should recycle memory for root->right */
+    //mfree(csound, root->right); root->right = NULL;
+    last->next = opTree;
+    //    print_tree(csound, "Answer:\n", anchor);
+    return anchor;
+}
 /**
  * Create a chain of Opcode (OPTXT) text from the AST node given. Called from
  * create_opcode when an expression node has been found as an argument
@@ -283,6 +351,8 @@ TREE * create_expression(CSOUND *csound, TREE *root)
     TREE * opTree;
     /* HANDLE SUB EXPRESSIONS */
 
+    if (root->type==S_Q) return create_cond_expression(csound, root);
+
     if (is_expression_node(root->left)) {
       anchor = create_expression(csound, root->left);
 
@@ -316,17 +386,15 @@ TREE * create_expression(CSOUND *csound, TREE *root)
            freetree */
       root->right = create_ans_token(csound, last->left->value->lexeme);
     }
-
-
-    op = mcalloc(csound, 80);
-
     arg1 = '\0';
     if (root->left != NULL) {
-        arg1 = argtyp2(csound, root->left->value->lexeme);
+      arg1 = argtyp2(csound, root->left->value->lexeme);
     }
     arg2 = argtyp2(csound, root->right->value->lexeme);
 
-    switch(root->type) {
+    op = mcalloc(csound, 80);
+
+     switch(root->type) {
     case S_PLUS:
       strncpy(op, "add", 80);
       outarg = set_expression_type(csound, op, arg1, arg2);
@@ -339,21 +407,46 @@ TREE * create_expression(CSOUND *csound, TREE *root)
       strncpy(op, "mul", 80);
       outarg = set_expression_type(csound, op, arg1, arg2);
       break;
+    case S_MOD:
+      strncpy(op, "mod", 80);
+      outarg = set_expression_type(csound, op, arg1, arg2);
+      break;
     case S_DIV:
       strncpy(op, "div", 80);
       outarg = set_expression_type(csound, op, arg1, arg2);
       break;
+    case S_POW:
+      { int outype = 'i';
+        strncpy(op, "pow.", 80);
+        if (arg1 == 'a') {
+          strncat(op, "a", 80);
+          outype = arg1;
+        }
+        else if (arg1 == 'k') {
+          strncat(op, "k", 80);
+          outype = arg1;
+        }
+        else
+          strncat(op, "i", 80);
+        outarg = create_out_arg(csound, outype);
+      }
+      break;
+    case S_TABREF:
+      strncpy(op, "tabref", 80);
+      if (UNLIKELY(PARSER_DEBUG)) csound->Message(csound, "Found TABREF: %s\n", op);
+      outarg = create_out_arg(csound, 'k');
+      break;
     case T_FUNCTION: /* assumes on single arg input */
       c = arg2;
       if (c == 'p' || c == 'c')   c = 'i';
       sprintf(op, "%s.%c", root->value->lexeme, c);
-      if (PARSER_DEBUG) csound->Message(csound, "Found OP: %s\n", op);
+      if (UNLIKELY(PARSER_DEBUG)) csound->Message(csound, "Found OP: %s\n", op);
       outarg = create_out_arg(csound, c);
       break;
     case S_UMINUS:
-      if (PARSER_DEBUG) csound->Message(csound, "HANDLING UNARY MINUS!");
+      if (UNLIKELY(PARSER_DEBUG)) csound->Message(csound, "HANDLING UNARY MINUS!");
       root->left = create_minus_token(csound);
-      arg1 = 'k';
+      arg1 = 'i';
       strncpy(op, "mul", 80);
       outarg = set_expression_type(csound, op, arg1, arg2);
       break;
@@ -382,12 +475,12 @@ TREE * create_expression(CSOUND *csound, TREE *root)
       outarg = set_expression_type(csound, op, arg1, '\0');
       break;
     }
-
     opTree = create_opcode_token(csound, op);
     if (root->left != NULL) {
       opTree->right = root->left;
       opTree->right->next = root->right;
       opTree->left = create_ans_token(csound, outarg);
+      //print_tree(csound, "making expression", opTree);
     }
     else {
       opTree->right = root->right;
@@ -418,14 +511,30 @@ TREE * create_boolean_expression(CSOUND *csound, TREE *root)
     TREE *anchor = NULL, *last;
     TREE * opTree;
 
-    if (PARSER_DEBUG) csound->Message(csound, "Creating boolean expression\n");
+    /*   if (UNLIKELY(PARSER_DEBUG)) */csound->Message(csound, "Creating boolean expression\n");
     /* HANDLE SUB EXPRESSIONS */
     if (is_boolean_expression_node(root->left)) {
         anchor = create_boolean_expression(csound, root->left);
+        last = anchor;
+        while (last->next != NULL) {
+            last = last->next;
+        }
         /* TODO - Free memory of old left node
            freetree */
         root->left = create_ans_token(csound, anchor->left->value->lexeme);
+    } else if (is_expression_node(root->left)) {
+        anchor = create_expression(csound, root->left);
+        
+        /* TODO - Free memory of old left node
+         freetree */
+        last = anchor;
+        while (last->next != NULL) {
+            last = last->next;
+        }
+        root->left = create_ans_token(csound, last->left->value->lexeme);
     }
+
+    
     if (is_boolean_expression_node(root->right)) {
       TREE * newRight = create_boolean_expression(csound, root->right);
       if (anchor == NULL) {
@@ -441,6 +550,27 @@ TREE * create_boolean_expression(CSOUND *csound, TREE *root)
       /* TODO - Free memory of old right node
          freetree */
       root->right = create_ans_token(csound, newRight->left->value->lexeme);
+    } else if (is_expression_node(root->right)) {
+        TREE * newRight = create_expression(csound, root->right);
+        if (anchor == NULL) {
+            anchor = newRight;
+        }
+        else {
+            last = anchor;
+            while (last->next != NULL) {
+                last = last->next;
+            }
+            last->next = newRight;
+        }
+        last = newRight;
+        
+        while (last->next != NULL) {
+            last = last->next;
+        }
+        
+        /* TODO - Free memory of old right node
+         freetree */
+        root->right = create_ans_token(csound, last->left->value->lexeme);
     }
 
     op = mcalloc(csound, 80);
@@ -471,10 +601,14 @@ TREE * create_boolean_expression(CSOUND *csound, TREE *root)
       break;
     }
 
-    if (PARSER_DEBUG) csound->Message(csound, "Operator Found: %s\n", op);
+    if (UNLIKELY(PARSER_DEBUG))
+      csound->Message(csound, "Operator Found: %s (%c %c)\n", op,
+                      argtyp2(csound, root->left->value->lexeme),
+                      argtyp2(csound, root->right->value->lexeme));
 
     outarg = get_boolean_arg(csound,
-                             root->left->type=='k' || root->right->type=='k');
+                             argtyp2(csound, root->left->value->lexeme)=='k' ||
+                             argtyp2(csound, root->right->value->lexeme)=='k');
 
     opTree = create_opcode_token(csound, op);
     opTree->right = root->left;
@@ -502,19 +636,19 @@ static TREE *create_synthetic_ident(CSOUND *csound, int32 count)
     ORCTOKEN *token;
 
     sprintf(label, "__synthetic_%ld", count);
-    if (PARSER_DEBUG)
+    if (UNLIKELY(PARSER_DEBUG))
       csound->Message(csound, "Creating Synthetic T_IDENT: %s\n", label);
     token = make_token(csound, label);
     token->type = T_IDENT;
     return make_leaf(csound, T_IDENT, token);
 }
 
-static TREE *create_synthetic_label(CSOUND *csound, int32 count)
+TREE *create_synthetic_label(CSOUND *csound, int32 count)
 {
     char *label = (char *)csound->Calloc(csound, 20);
 
     sprintf(label, "__synthetic_%ld:", count);
-    if (PARSER_DEBUG)
+    if (UNLIKELY(PARSER_DEBUG))
       csound->Message(csound, "Creating Synthetic label: %s\n", label);
     return make_leaf(csound, T_LABEL, make_label(csound, label));
 }
@@ -540,9 +674,10 @@ static TREE *create_synthetic_label(CSOUND *csound, int32 count)
  *   2. for else statements found, do no conditional and just link in statements
  *
  * */
+
 TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
 {
-    int32 labelCounter = 300L;
+    //    int32 labelCounter = 300L;
 
     TREE *anchor = NULL;
     TREE * expressionNodes = NULL;
@@ -550,21 +685,22 @@ TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
     TREE *current = root;
     TREE *previous = NULL;
 
-    if (PARSER_DEBUG)
+    if (UNLIKELY(PARSER_DEBUG))
       csound->Message(csound, "[Begin Expanding Expressions in AST]\n");
 
     while (current != NULL) {
       switch(current->type) {
       case T_INSTR:
-        if (PARSER_DEBUG) csound->Message(csound, "Instrument found\n");
+        if (UNLIKELY(PARSER_DEBUG)) csound->Message(csound, "Instrument found\n");
         current->right = csound_orc_expand_expressions(csound, current->right);
+        //        print_tree(csound, "AFTER", current);
         break;
       case T_UDO:
-        if (PARSER_DEBUG) csound->Message(csound, "UDO found\n");
+        if (UNLIKELY(PARSER_DEBUG)) csound->Message(csound, "UDO found\n");
         current->right = csound_orc_expand_expressions(csound, current->right);
         break;
       case T_IF:
-        if (PARSER_DEBUG) csound->Message(csound, "Found IF statement\n");
+        if (UNLIKELY(PARSER_DEBUG)) csound->Message(csound, "Found IF statement\n");
         {
           TREE * left = current->left;
           TREE * right = current->right;
@@ -574,7 +710,7 @@ TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
           if (right->type == T_IGOTO ||
               right->type == T_KGOTO ||
               right->type == T_GOTO) {
-            if (PARSER_DEBUG) csound->Message(csound, "Found if-goto\n");
+            if (UNLIKELY(PARSER_DEBUG)) csound->Message(csound, "Found if-goto\n");
             expressionNodes = create_boolean_expression(csound, left);
             /* Set as anchor if necessary */
             if (anchor == NULL) {
@@ -589,9 +725,9 @@ TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
               previous->next = expressionNodes;
             }
             gotoToken = create_goto_token(csound,
-                                          expressionNodes->left->value->lexeme,
+                                          last->left->value->lexeme,
                                           right,
-                                          expressionNodes->left->type == 'k' ||
+                                          last->left->type == 'k' ||
                                           right->type =='k');
             last->next = gotoToken;
             gotoToken->next = current->next;
@@ -609,24 +745,39 @@ TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
             TREE *ifBlockCurrent = current;
             TREE *ifBlockLast = NULL;
 
-            if (PARSER_DEBUG) csound->Message(csound, "Found if-then\n");
+            if (UNLIKELY(PARSER_DEBUG)) csound->Message(csound, "Found if-then\n");
             if (right->next != NULL) {
-              endLabelCounter = labelCounter++;
+              endLabelCounter = genlabs++;
             }
 
             while (ifBlockCurrent != NULL) {
               tempLeft = ifBlockCurrent->left;
               tempRight = ifBlockCurrent->right;
               if (ifBlockCurrent->type == T_ELSE) {
-                ifBlockLast->next = ifBlockCurrent->right;
+                //                print_tree(csound, "ELSE case\n", ifBlockCurrent);
+                ifBlockLast->next =
+                  csound_orc_expand_expressions(csound, tempRight);
                 while (ifBlockLast->next != NULL) {
                   ifBlockLast = ifBlockLast->next;
                 }
+                //                print_tree(csound, "ELSE transformed\n", ifBlockCurrent);
                 break;
               }
+              else if (ifBlockCurrent->type == T_ELSEIF) { /* JPff code */
+                //                print_tree(csound, "ELSEIF case\n", ifBlockCurrent);
+                ifBlockCurrent->type = T_IF;
+                ifBlockCurrent = make_node(csound, T_ELSE, NULL, ifBlockCurrent);
+                //tempLeft = NULL;
+                /*   ifBlockLast->next = */
+                /*     csound_orc_expand_expressions(csound, ifBlockCurrent); */
+                /* while (ifBlockLast->next != NULL) { */
+                /*   ifBlockLast = ifBlockLast->next; */
+                /* } */
+                //                print_tree(csound, "ELSEIF transformed\n", ifBlockCurrent);
+                //break;
+              }
 
               expressionNodes = create_boolean_expression(csound, tempLeft);
-                            /* print_tree(csound, expressionNodes); */
                             /* Set as anchor if necessary */
               if (ifBlockStart == NULL) {
                 ifBlockStart = expressionNodes;
@@ -635,6 +786,7 @@ TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
               {
                 TREE* last = expressionNodes;
                 TREE *statements, *label, *labelEnd, *gotoToken;
+                int gotoType;
 
                 while (last->next != NULL) {
                   last = last->next;
@@ -644,14 +796,23 @@ TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
                 }
 
                 statements = tempRight->right;
-                label = create_synthetic_ident(csound, labelCounter);
-                labelEnd = create_synthetic_label(csound, labelCounter++);
+                label = create_synthetic_ident(csound, genlabs);
+                labelEnd = create_synthetic_label(csound, genlabs++);
                 tempRight->right = label;
-                gotoToken = create_goto_token(csound,
-                                              expressionNodes->left->value->lexeme,
-                                              tempRight,
-                                              expressionNodes->left->type == 'k' ||
-                                              tempRight->type == 'k');
+//                printf("goto types %c %c %c %c %d\n",
+//                       expressionNodes->left->type, tempRight->type,
+//                       argtyp2(csound, last->left->value->lexeme),
+//                       argtyp2(csound, tempRight->value->lexeme),
+//                       (argtyp2(csound, last->left->value->lexeme) == 'k') ||
+//                       (argtyp2(csound, tempRight->value->lexeme) == 'k'));
+//                print_tree(csound, "expression nodes", expressionNodes);
+                gotoType = (argtyp2(csound, last->left->value->lexeme) == 'B') ||
+                  (argtyp2(csound, tempRight->value->lexeme) == 'k');
+                gotoToken =
+                  create_goto_token(csound,
+                   last->left->value->lexeme,
+                   tempRight,
+                   gotoType);
                 /* relinking */
                 last->next = gotoToken;
                 gotoToken->next = statements;
@@ -661,9 +822,10 @@ TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
                 if (endLabelCounter > 0) {
                   TREE *endLabel = create_synthetic_ident(csound,
                                                           endLabelCounter);
-                  TREE *gotoEndLabelToken = create_simple_goto_token(csound,
-                                        endLabel);
-                  if (PARSER_DEBUG)
+                  int type = (gotoType == 1) ? 0 : 1;
+                  TREE *gotoEndLabelToken =
+                    create_simple_goto_token(csound, endLabel, type);
+                  if (UNLIKELY(PARSER_DEBUG))
                     csound->Message(csound, "Creating simple goto token\n");
 
                   statements->next = gotoEndLabelToken;
@@ -678,51 +840,127 @@ TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
               }
             }
 
-                    if (endLabelCounter > 0) {
-                          TREE *endLabel = create_synthetic_label(csound,
-                                                                                                        endLabelCounter);
-                          endLabel->next = ifBlockLast->next;
-                          ifBlockLast->next = endLabel;
-                          ifBlockLast = endLabel;
-                    }
-                    ifBlockLast->next = current->next;
+            if (endLabelCounter > 0) {
+              TREE *endLabel = create_synthetic_label(csound,
+                                                      endLabelCounter);
+              endLabel->next = ifBlockLast->next;
+              ifBlockLast->next = endLabel;
+              ifBlockLast = endLabel;
+            }
+            ifBlockLast->next = current->next;
 
-                    /* Connect in all of the TREE nodes that were flattened from
-                     * the if-else-else block
-                     */
+            /* Connect in all of the TREE nodes that were flattened from
+             * the if-else-else block
+             */
             /* Set as anchor if necessary */
-                    if (anchor == NULL) {
-                          anchor = ifBlockStart;
-                    }
+            if (anchor == NULL) {
+              anchor = ifBlockStart;
+            }
 
-                    /* reconnect into chain */
-                    if (previous != NULL) {
-                          previous->next = ifBlockStart;
-                    }
-                    current = ifBlockStart;
+            /* reconnect into chain */
+            if (previous != NULL) {
+              previous->next = ifBlockStart;
+            }
+            current = ifBlockStart;
           }
           else {
             csound->Message(csound, "ERROR: Neither if-goto or if-then found!!!");
           }
         }
         break;
+      case T_UNTIL:
+        if (UNLIKELY(PARSER_DEBUG))
+          csound->Message(csound, "Found UNTIL statement\n");
+        {
+          TREE * left = current->left;
+          TREE * right = current->right;
+          TREE* last;
+          TREE * gotoToken;
+
+          int32 topLabelCounter = genlabs++;
+          int32 endLabelCounter = genlabs++;
+          TREE *tempLeft = current->left;
+          TREE *tempRight = current->right;
+          TREE *ifBlockStart = current;
+          TREE *ifBlockCurrent = current;
+          TREE *ifBlockLast = current;
+          TREE *next = current->next;
+          TREE *statements, *label, *labelEnd;
+          int type;
+          /* *** Stage 1: Create a top label (overwriting *** */
+          {                           /* Change UNTIL to label and add IF */
+            TREE* t=create_synthetic_label(csound, topLabelCounter);
+            current->type = t->type; current->left = current->right = NULL;
+            current->value = t->value;
+            ifBlockCurrent = t;
+            ifBlockCurrent->left = tempLeft;
+            ifBlockCurrent->right = tempRight;
+            ifBlockCurrent->next = current->next;
+            ifBlockCurrent->type = T_IF;
+            current->next = t;
+          }
+          /* *** Stage 2: Boolean expression *** */
+          /* Deal with the boolean expression to variable */
+          tempRight = ifBlockCurrent->right;
+          expressionNodes =
+            ifBlockLast->next = create_boolean_expression(csound,
+                                                          ifBlockCurrent->left);
+          ifBlockLast = ifBlockLast->next;
+          /* *** Stage 3: Create the goto *** */
+          statements = tempRight;     /* the body of the loop */
+          label    = create_synthetic_ident(csound, topLabelCounter);
+          labelEnd = create_synthetic_label(csound, endLabelCounter);
+          gotoToken =
+            create_goto_token(csound,
+                              expressionNodes->left->value->lexeme,
+                              labelEnd,
+                              type =
+                              ((argtyp2(csound,
+                                        expressionNodes->left->value->lexeme)=='B')
+                               ||
+                               (argtyp2(csound,
+                                        tempRight->value->lexeme) == 'k')));
+          /* relinking */
+          tempRight = ifBlockLast->next;
+          ifBlockLast->next = gotoToken;
+          ifBlockLast->next->next = tempRight;
+          gotoToken->right->next = labelEnd;
+          gotoToken->next = statements;
+          labelEnd = create_synthetic_label(csound, endLabelCounter);
+          while (statements->next != NULL) { /* To end of body */
+            statements = statements->next;
+          }
+          {
+            TREE *topLabel = create_synthetic_ident(csound,
+                                                    topLabelCounter);
+            TREE *gotoTopLabelToken =
+              create_simple_goto_token(csound, topLabel, (type==1 ? 0 : 1));
+            if (UNLIKELY(PARSER_DEBUG))
+              csound->Message(csound, "Creating simple goto token\n");
+            statements->next = gotoTopLabelToken;
+            gotoTopLabelToken->next = labelEnd;
+          }
+          ifBlockLast = labelEnd;
+          ifBlockCurrent = tempRight->next;
+        }
+        break;
       default:
-        if (current->right != NULL)  { /* This is WRONG in optional argsq */
+        { /* This is WRONG in optional argsq */
           TREE* previousArg = NULL;
           TREE* currentArg = current->right;
-          if (PARSER_DEBUG) csound->Message(csound, "Found Statement.\n");
+          if (UNLIKELY(PARSER_DEBUG)) csound->Message(csound, "Found Statement.\n");
 
-          if (current->type == S_ASSIGN) {
-            // perhaps do optimization here?
-            //csound->Message(csound, "Assignment Statement.\n");
-          }
+          /* if (current->type == S_ASSIGN) { */
+          /*   //csound->Message(csound, "Assignment Statement.\n"); */
+          /* } */
           while (currentArg != NULL) {
             TREE* last;
             TREE *nextArg;
             TREE *newArgTree;
             if (is_expression_node(currentArg)) {
               char * newArg;
-              if (PARSER_DEBUG) csound->Message(csound, "Found Expression.\n");
+              if (UNLIKELY(PARSER_DEBUG))
+                csound->Message(csound, "Found Expression.\n");
               expressionNodes = create_expression(csound, currentArg);
 
               /* Set as anchor if necessary */
@@ -746,15 +984,13 @@ TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
 
               newArg = last->left->value->lexeme;
 
-              if (PARSER_DEBUG)
+              if (UNLIKELY(PARSER_DEBUG))
                 csound->Message(csound, "New Arg: %s\n", newArg);
 
               /* handle arg replacement of currentArg here */
               nextArg = currentArg->next;
               newArgTree = create_ans_token(csound, newArg);
 
-              /* print_tree(csound, newArgTree); */
-
               if (previousArg == NULL) {
                 current->right = newArgTree;
               }
@@ -782,7 +1018,7 @@ TREE *csound_orc_expand_expressions(CSOUND * csound, TREE *root)
       current = current->next;
     }
 
-    if (PARSER_DEBUG)
+    if (UNLIKELY(PARSER_DEBUG))
       csound->Message(csound, "[End Expanding Expressions in AST]\n");
 
     return anchor;
