@@ -27,34 +27,107 @@
 #include "csoundCore.h"
 #include "csound_orc.h"
 #include "namedins.h"
+#include "parse_param.h"
+
+char *csound_orcget_text ( void *scanner );
 
 extern  char argtyp2(CSOUND*, char*);
 extern  int tree_arg_list_count(TREE *);
-
-TREE* force_rate(TREE* a, char t)
-{                               /* Ensure a is of type t */
-    return a;
-}
+void print_tree(CSOUND *, char *, TREE *);
+/* TREE* force_rate(TREE* a, char t) */
+/* {                               /\* Ensure a is of type t *\/ */
+/*     return a; */
+/* } */
 
 
-/** Verifies that opcodes and args are correct*/
-int verify_tree(CSOUND *csound, TREE *root) {
-    csound->Message(csound, "Verifying AST (NEED TO IMPLEMENT)\n");
-    return 1;
+/** Verifies and optimise; constant fold and opcodes and args are correct*/
+TREE * verify_tree(CSOUND *csound, TREE *root) 
+{
+    TREE* ans;
+    double lval, rval;
+    //csound->Message(csound, "Verifying AST (NEED TO IMPLEMENT)\n");
+    //    print_tree(csound, "Verify", root);
+    if (root==NULL) return NULL;
+    if (root->left)  {
+      root->left = verify_tree(csound, root->left);
+      if (root->right) {
+        root->right= verify_tree(csound, root->right);
+        if ((root->left->type  == T_INTGR || root->left->type  == T_NUMBER) &&
+            (root->right->type == T_INTGR || root->right->type == T_NUMBER)) {
+          lval = (root->left->type == T_INTGR ?
+                  (double)root->left->value->value :root->left->value->fvalue);
+          rval = (root->right->type == T_INTGR ?
+                  (double)root->right->value->value :root->left->value->fvalue);
+          ans = root->left;
+          ans->type = ans->value->type = T_NUMBER;
+          switch (root->type) {
+          case S_PLUS:
+            ans->value->fvalue = lval+rval;
+            mrealloc(csound, ans->value->lexeme, 24);
+            sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
+            //Memory leak!! mfree(csound, root); mfree(csound, root->right);
+            return ans;
+          case S_MINUS:
+            ans->value->fvalue = lval-rval;
+            mrealloc(csound, ans->value->lexeme, 24);
+            sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
+            //Memory leak!! mfree(csound, root); mfree(csound, root->right);
+            return ans;
+          case S_TIMES:
+            ans->value->fvalue = lval*rval;
+            mrealloc(csound, ans->value->lexeme, 24);
+            sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
+            //Memory leak!! mfree(csound, root); mfree(csound, root->right);
+            return ans;
+          case S_DIV:
+            ans->value->fvalue = lval/rval;
+            mrealloc(csound, ans->value->lexeme, 24);
+            sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
+            //Memory leak!! mfree(csound, root); mfree(csound, root->right);
+            return ans;
+            /* case S_NEQ: */
+            /*   break; */
+            /* case S_AND: */
+            /*   break; */
+            /* case S_OR: */
+            /*   break; */
+            /* case S_LT: */
+            /*   break; */
+            /* case S_LE: */
+            /*   break; */
+            /* case S_EQ: */
+            /*   break; */
+            /* case S_GT: */
+            /*   break; */
+            /* case S_GE: */
+            /*   break; */
+          default: break;
+          }
+        }
+      }
+    }
+    return root;
 }
 
 
 /* BISON PARSER FUNCTION */
 int csound_orcwrap()
 {
-    /* csound->Message(csound, "END OF INPUT\n"); */
+    printf("END OF INPUT\n");
     return (1);
 }
 
 /* BISON PARSER FUNCTION */
-void csound_orcerror(CSOUND *csound, TREE *astTree, char *str)
+void csound_orcerror(PARSE_PARM *pp, void *yyscanner,
+                     CSOUND *csound, TREE *astTree, char *str)
 {
-    csound->Message(csound, Str("csound_orcerror: %s\n"), str);
+    //??    extern int yyline;
+    //    extern char* buffer;
+
+    csound->Message(csound, Str("error: %s (token \"%s\")"),
+                    str, csound_orcget_text(yyscanner));
+    csound->Message(csound, Str(" line %d: %s"),
+                    csound_orcget_lineno(yyscanner), pp->buffer); // buffer has \n at end
 }
 
 /**
@@ -64,11 +137,11 @@ void csound_orcerror(CSOUND *csound, TREE *astTree, char *str)
  */
 TREE* appendToTree(CSOUND * csound, TREE *first, TREE *newlast) {
     TREE *current;
-    if(first == NULL) {
+    if (first == NULL) {
         return newlast;
     }
 
-    if(newlast == NULL) {
+    if (newlast == NULL) {
         return first;
     }
 
@@ -78,7 +151,7 @@ TREE* appendToTree(CSOUND * csound, TREE *first, TREE *newlast) {
      * useful; the number 400 is arbitrary, chosen as it seemed to be a value
      * higher than all the type numbers that were being printed out
      */
-    if(first->type > 400 || first-> type < 0) {
+    if (first->type > 400 || first-> type < 0) {
         return newlast;
     }
 
@@ -114,20 +187,20 @@ TREE* make_node(CSOUND *csound, int type, TREE* left, TREE* right)
 
 TREE* make_leaf(CSOUND *csound, int type, ORCTOKEN *v)
 {
-  TREE *ans;
-  ans = (TREE*)mmalloc(csound, sizeof(TREE));
-  if (UNLIKELY(ans==NULL)) {
-    /* fprintf(stderr, "Out of memory\n"); */
-    exit(1);
-  }
-  ans->type = type;
-  ans->left = NULL;
-  ans->right = NULL;
-  ans->next = NULL;
-  ans->len = 0;
-  ans->rate = -1;
-  ans->value = v;
-  return ans;
+    TREE *ans;
+    ans = (TREE*)mmalloc(csound, sizeof(TREE));
+    if (UNLIKELY(ans==NULL)) {
+      /* fprintf(stderr, "Out of memory\n"); */
+      exit(1);
+    }
+    ans->type = type;
+    ans->left = NULL;
+    ans->right = NULL;
+    ans->next = NULL;
+    ans->len = 0;
+    ans->rate = -1;
+    ans->value = v;
+    return ans;
 }
 
 /** Utility function to create assignment statements
@@ -138,18 +211,18 @@ char* get_assignment_type(CSOUND *csound, char * ans, TREE* arg1) {
     char* str = (char*)mcalloc(csound, 65);
 
     switch (c) {
-          case 'S':
-                  strcpy(str, "strcpy");
-                  break;
-          case 'a':
-                c = argtyp2(csound, arg1->value->lexeme);
-                strcpy(str, (c == 'a' ? "=.a" : "upsamp"));
-                /* strcpy(str, "=.a"); */
-                break;
-          case 'p':
-                  c = 'i'; /* purposefully fall through */
-          default:
-                  sprintf(str, "=.%c", c);
+    case 'S':
+      strcpy(str, "strcpy");
+      break;
+    case 'a':
+      c = argtyp2(csound, arg1->value->lexeme);
+      strcpy(str, (c == 'a' ? "=.a" : "upsamp"));
+      /* strcpy(str, "=.a"); */
+      break;
+    case 'p':
+      c = 'i'; /* purposefully fall through */
+    default:
+      sprintf(str, "=.%c", c);
     }
 
     if (PARSER_DEBUG)
@@ -165,10 +238,10 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
 {
     int i;
     if (UNLIKELY(l==NULL)) {
-        return;
+      return;
     }
     for (i=0; i<n; i++) {
-        csound->Message(csound, " ");
+      csound->Message(csound, " ");
     }
 
     csound->Message(csound, "TYPE: %d ", l->type);
@@ -190,6 +263,10 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
       csound->Message(csound,"S_TIMES:\n"); break;
     case S_DIV:
       csound->Message(csound,"S_DIV:\n"); break;
+    case S_MOD:
+      csound->Message(csound,"S_MOD:\n"); break;
+    case S_POW:
+      csound->Message(csound,"S_POW:\n"); break;
     case S_NL:
       csound->Message(csound,"S_NL:\n"); break;
     case S_LB:
@@ -210,6 +287,10 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
       csound->Message(csound,"S_EQ:\n"); break;
     case S_ASSIGN:
       csound->Message(csound,"S_ASSIGN:\n"); break;
+    case S_TASSIGN:
+      csound->Message(csound,"S_TASSIGN:\n"); break;
+    case S_TABREF:
+      csound->Message(csound,"S_TABREF:\n"); break;
     case S_GT:
       csound->Message(csound,"S_GT:\n"); break;
     case S_GE:
@@ -228,6 +309,12 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
           csound->Message(csound,"T_ELSEIF:\n"); break;
     case T_ELSE:
           csound->Message(csound,"T_ELSE:\n"); break;
+    case T_UNTIL:
+          csound->Message(csound,"T_UNTIL:\n"); break;
+    case T_DO:
+          csound->Message(csound,"T_DO:\n"); break;
+    case T_OD:
+          csound->Message(csound,"T_OD:\n"); break;
     case T_GOTO:
       csound->Message(csound,"T_GOTO:\n"); break;
     case T_IGOTO:
@@ -263,9 +350,13 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
     case T_IDENT_GA:
       csound->Message(csound,"IDENT_GA: %s\n", l->value->lexeme); break;
     case T_IDENT_S:
-      csound->Message(csound,"IDENT_D: %s\n", l->value->lexeme); break;
+      csound->Message(csound,"IDENT_S: %s\n", l->value->lexeme); break;
     case T_IDENT_GS:
       csound->Message(csound,"IDENT_GS: %s\n", l->value->lexeme); break;
+    case T_IDENT_T:
+      csound->Message(csound,"IDENT_T: %s\n", l->value->lexeme); break;
+    case T_IDENT_GT:
+      csound->Message(csound,"IDENT_GT: %s\n", l->value->lexeme); break;
     case T_IDENT_W:
       csound->Message(csound,"IDENT_W: %s\n", l->value->lexeme); break;
     case T_IDENT_GW:
@@ -296,8 +387,8 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
       csound->Message(csound,"T_FUNCTION: %s\n", l->value->lexeme); break;
     case S_UMINUS:
         csound->Message(csound,"S_UMINUS:\n"); break;
-    case T_INTLIST:
-        csound->Message(csound,"T_INTLIST:\n"); break;
+    case T_INSTLIST:
+        csound->Message(csound,"T_INSTLIST:\n"); break;
     default:
       csound->Message(csound,"t:%d\n", l->type);
     }
@@ -305,22 +396,24 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
     print_tree_i(csound, l->left,n+1);
     print_tree_i(csound, l->right,n+1);
 
-    if(l->next != NULL) {
+    if (l->next != NULL) {
         print_tree_i(csound, l->next, n);
     }
 }
 
-static void print_tree_xml(CSOUND *csound, TREE *l, int n)
+enum {TREE_NONE, TREE_LEFT, TREE_RIGHT, TREE_NEXT};
+static void print_tree_xml(CSOUND *csound, TREE *l, int n, int which)
 {
     int i;
+    char *child[4] = {"", "left", "right", "next"};
     if (l==NULL) {
-        return;
+      return;
     }
     for (i=0; i<n; i++) {
-        csound->Message(csound, " ");
+      csound->Message(csound, " ");
     }
 
-    csound->Message(csound, "<tree type=\"%d\" ", l->type);
+    csound->Message(csound, "<tree%s type=\"%d\" ", child[which], l->type);
 
     switch (l->type) {
     case S_COM:
@@ -339,6 +432,10 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n)
       csound->Message(csound,"name=\"S_TIMES\""); break;
     case S_DIV:
       csound->Message(csound,"name=\"S_DIV\""); break;
+    case S_MOD:
+      csound->Message(csound,"name=\"S_MOD\""); break;
+    case S_POW:
+      csound->Message(csound,"name=\"S_POW\""); break;
     case S_NL:
       csound->Message(csound,"name=\"S_NL\""); break;
     case S_LB:
@@ -359,6 +456,10 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n)
       csound->Message(csound,"name=\"S_EQ\""); break;
     case S_ASSIGN:
       csound->Message(csound,"name=\"S_ASSIGN\""); break;
+    case S_TASSIGN:
+      csound->Message(csound,"name=\"S_TASSIGN\""); break;
+    case S_TABREF:
+      csound->Message(csound,"name=\"S_TABREF\""); break;
     case S_GT:
       csound->Message(csound,"name=\"S_GT\""); break;
     case S_GE:
@@ -390,6 +491,12 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n)
           csound->Message(csound,"name=\"T_ELSEIF\""); break;
     case T_ELSE:
           csound->Message(csound,"name=\"T_ELSE\""); break;
+    case T_UNTIL:
+          csound->Message(csound,"name=\"T_UNTIL\""); break;
+    case T_DO:
+          csound->Message(csound,"name=\"T_DO\""); break;
+    case T_OD:
+          csound->Message(csound,"name=\"T_OD\""); break;
     case T_GOTO:
       csound->Message(csound,"name=\"T_GOTO\""); break;
     case T_IGOTO:
@@ -404,6 +511,8 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n)
       csound->Message(csound,"name=\"T_KSMPS\""); break;
     case T_NCHNLS:
       csound->Message(csound,"name=\"T_NCHNLS\""); break;
+    case T_NCHNLSI:
+      csound->Message(csound,"name=\"T_NCHNLSI\""); break;
     case T_INSTR:
       csound->Message(csound,"name=\"T_INSTR\""); break;
     case T_STRCONST:
@@ -431,11 +540,17 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n)
       csound->Message(csound,"name=\"IDENT_GA\" varname=\"%s\"",
                       l->value->lexeme); break;
     case T_IDENT_S:
-      csound->Message(csound,"name=\"IDENT_D\" varname=\"%s\"",
+      csound->Message(csound,"name=\"IDENT_S\" varname=\"%s\"",
                       l->value->lexeme); break;
     case T_IDENT_GS:
       csound->Message(csound,"name=\"IDENT_GS\" varname=\"%s\"",
                       l->value->lexeme); break;
+    case T_IDENT_T:
+      csound->Message(csound,"name=\"IDENT_T\" varname=\"%s\"",
+                      l->value->lexeme); break;
+    case T_IDENT_GT:
+      csound->Message(csound,"name=\"IDENT_GT\" varname=\"%s\"",
+                      l->value->lexeme); break;
     case T_IDENT_W:
       csound->Message(csound,"name=\"IDENT_W\" varname=\"%s\"",
                       l->value->lexeme); break;
@@ -461,8 +576,8 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n)
       csound->Message(csound,"name=\"T_INTGR\" value=\"%d\"",
                       l->value->value); break;
     case T_NUMBER:
-      csound->Message(csound,"name=\"T_NUMBER\" value=\"%f\"",
-                      l->value->fvalue); break;
+      csound->Message(csound,"name=\"T_NUMBER\" value=\"%f\" type=%d",
+                      l->value->fvalue, l->value->type); break;
     case S_ANDTHEN:
       csound->Message(csound,"name=\"S_ANDTHEN\""); break;
     case S_APPLY:
@@ -478,8 +593,8 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n)
                       l->value->lexeme); break;
     case S_UMINUS:
         csound->Message(csound,"name=\"S_UMINUS\""); break;
-    case T_INTLIST:
-        csound->Message(csound,"name=\"T_INTLIST\""); break;
+    case T_INSTLIST:
+        csound->Message(csound,"name=\"T_INSTLIST\""); break;
     case T_UDO:
         csound->Message(csound,"name=\"T_UDO\""); break;
     case T_UDO_ANS:
@@ -494,38 +609,47 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n)
 
     csound->Message(csound, " >\n");
 
-    print_tree_xml(csound, l->left,n+1);
-    print_tree_xml(csound, l->right,n+1);
+    print_tree_xml(csound, l->left,n+1, TREE_LEFT);
+    print_tree_xml(csound, l->right,n+1, TREE_RIGHT);
 
     for (i=0; i<n; i++) {
-        csound->Message(csound, " ");
+      csound->Message(csound, " ");
     }
 
-    csound->Message(csound, "</tree>\n");
+    csound->Message(csound, "</tree%s>\n", child[which]);
 
-    if(l->next != NULL) {
-        print_tree_xml(csound, l->next, n);
+    if (l->next != NULL) {
+      print_tree_xml(csound, l->next, n, TREE_NEXT);
     }
 }
 
-void print_tree(CSOUND * csound, TREE *l)
+void print_tree(CSOUND * csound, char* msg, TREE *l)
 {
     /*if (PARSER_DEBUG)*/ {
-      csound->Message(csound, "Printing Tree\n");
+      if (msg)
+        csound->Message(csound, msg);
+      else
+        csound->Message(csound, "Printing Tree\n");
       csound->Message(csound, "<ast>\n");
-      print_tree_xml(csound, l, 0);
+      print_tree_xml(csound, l, 0, TREE_NONE);
       csound->Message(csound, "</ast>\n");
     }
 }
 
 void handle_optional_args(CSOUND *csound, TREE *l)
 {
+    if (l == NULL || l->type == T_LABEL) return;
+
     int opnum = find_opcode(csound, l->value->lexeme);
     OENTRY *ep = csound->opcodlst + opnum;
-    int nreqd = strlen(ep->intypes);
+    int nreqd = 0;
     int incnt = tree_arg_list_count(l->right);
     TREE * temp;
 
+    if (ep->intypes != NULL) {
+      nreqd = strlen(ep->intypes);
+    }
+
     if (PARSER_DEBUG) {
       csound->Message(csound, "Handling Optional Args for opcode %s, %d, %d",
                       ep->opname, incnt, nreqd);
@@ -563,6 +687,7 @@ void handle_optional_args(CSOUND *csound, TREE *l)
           if (l->right==NULL) l->right = temp;
           else appendToTree(csound, l->right, temp);
           break;
+        case 'J':
         case 'j':
           temp = make_leaf(csound, T_INTGR, make_int(csound, "-1"));
           if (l->right==NULL) l->right = temp;
@@ -582,7 +707,7 @@ void handle_optional_args(CSOUND *csound, TREE *l)
 }
 
 char tree_argtyp(CSOUND *csound, TREE *tree) {
-    if(tree->type == T_INTGR || tree->type == T_NUMBER) {
+    if (tree->type == T_INTGR || tree->type == T_NUMBER) {
       return 'i';
     }
 
@@ -597,11 +722,14 @@ void handle_polymorphic_opcode(CSOUND* csound, TREE * tree) {
                                                   tree->left->value->lexeme,
                                                   tree->right/*->value->lexeme*/);
       /* else {                    /\* Conditional expression so broken  *\/ */
-      /*   printf("Odd case\n"); */
-      /*   print_tree(csound, tree); */
+      /*   print_tree(csound, "Odd case\n", tree); */
       /* } */
       return;
     }
+    else if (tree->type==0) {
+      csound->Message(csound, "Null type in tree -- aborting\n");
+      exit(2);
+    }
     else {
       int opnum = find_opcode(csound, tree->value->lexeme);
       OENTRY *ep = csound->opcodlst + opnum;
@@ -613,8 +741,6 @@ void handle_polymorphic_opcode(CSOUND* csound, TREE * tree) {
 
       if (ep->dsblksiz >= 0xfffb) {
 
-        c = tree_argtyp(csound, tree->right);
-
         switch (ep->dsblksiz) {
 
         case 0xffff:
@@ -644,6 +770,7 @@ void handle_polymorphic_opcode(CSOUND* csound, TREE * tree) {
         case 0xfffe:                              /* Two tags for OSCIL's    */
           if (PARSER_DEBUG)
             csound->Message(csound, "POLYMORPHIC 0xfffe\n");
+          c = tree_argtyp(csound, tree->right);
           if (c != 'a') c = 'k';
           if ((d = tree_argtyp(csound, tree->right->next)) != 'a') d = 'k';
           sprintf(str, "%s.%c%c", ep->opname, c, d);
@@ -653,6 +780,7 @@ void handle_polymorphic_opcode(CSOUND* csound, TREE * tree) {
           strcpy(tree->value->lexeme, str);
           break;
         case 0xfffd:                              /* For peak, etc.          */
+          c = tree_argtyp(csound, tree->right);
           if (PARSER_DEBUG)
             csound->Message(csound, "POLYMORPHIC 0xfffd\n");
           if (c != 'a') c = 'k';
@@ -665,6 +793,7 @@ void handle_polymorphic_opcode(CSOUND* csound, TREE * tree) {
         case 0xfffc:                              /* For divz types          */
           if (PARSER_DEBUG)
             csound->Message(csound, "POLYMORPHIC 0xfffc\n");
+          c = tree_argtyp(csound, tree->right);
           d = tree_argtyp(csound, tree->right->next);
           if ((c=='i' || c=='c') && (d=='i' || d=='c'))
             c = 'i', d = 'i';
@@ -681,7 +810,8 @@ void handle_polymorphic_opcode(CSOUND* csound, TREE * tree) {
         case 0xfffb:          /* determine opcode by type of first input arg */
           if (PARSER_DEBUG)
             csound->Message(csound, "POLYMORPHIC 0xfffb\n");
-          /* allows a, k, and i types (e.g. Inc, Dec), but not constants */
+          c = tree_argtyp(csound, tree->right);
+           /* allows a, k, and i types (e.g. Inc, Dec), but not constants */
           if (c=='p') c = 'i';
           /*if (ST(typemask_tabl)[(unsigned char) c] & (ARGTYP_i | ARGTYP_p))
             c = 'i';
