@@ -100,47 +100,53 @@ OENTRY opcodlst_1[] = {
 { "midglobal",S(MIDGLOBAL),1,   "",     "Sm",   midglobal               },
 { "=",      0,          0,      "",     ""                              },
 { "init",   0xffff      /* base names for later prefixes,suffixes */    },
-{ "betarand", 0xffff                                                    },
+{ "betarand",0xffff                                                     },
 { "bexprnd", 0xffff                                                     },
 { "cauchy",  0xffff                                                     },
+{ "cauchyi", 0xffff                                                     },
 { "chanctrl",0xffff                                                     },
 { "cpsmidib",0xffff                                                     },
 { "exprand", 0xffff                                                     },
+{ "exprandi",0xffff                                                     },
 { "gauss" ,  0xffff                                                     },
-{ "limit", 0xffff,                                                      },
+{ "gaussi" ,  0xffff                                                    },
+{ "limit",   0xffff,                                                    },
 { "linrand", 0xffff                                                     },
 { "midictrl",0xffff                                                     },
-{ "polyaft",0xffff                                                      },
-{ "ntrpol", 0xffff                                                      },
+{ "polyaft", 0xffff                                                     },
+{ "ntrpol",  0xffff                                                     },
 { "octmidib",0xffff                                                     },
 { "pcauchy", 0xffff                                                     },
-{ "pchbend",0xffff                                                      },
+{ "pchbend", 0xffff                                                     },
 { "pchmidib",0xffff                                                     },
 { "poisson", 0xffff                                                     },
-{ "pow",    0xffff,                                                     },
+{ "pow",     0xffff,                                                    },
 { "tableng", 0xffff,                                                    },
 { "taninv2", 0xffff                                                     },
-{ "timek", 0xffff,                                                      },
-{ "times", 0xffff,                                                      },
+{ "timek",   0xffff,                                                    },
+{ "times",   0xffff,                                                    },
 { "trirand", 0xffff                                                     },
-{ "unirand",0xffff,                                                     },
+{ "unirand", 0xffff,                                                    },
 { "weibull", 0xffff                                                     },
-{ "oscil",  0xfffe                                                      },
-{ "oscil3", 0xfffe                                                      },
-{ "oscili", 0xfffe                                                      },
-{ "peak", 0xfffd                                                        },
+{ "oscil",   0xfffe                                                     },
+{ "oscil3",  0xfffe                                                     },
+{ "oscili",  0xfffe                                                     },
+{ "peak",    0xfffd                                                     },
 { "rtclock", 0xffff                                                     },
 { "tablew",  0xfffe                                                     },
-{ "tablewkt",  0xfffe                                                   },
+{ "tablewkt",0xfffe                                                     },
 { "ihold",  S(LINK),    1,      "",     "",     ihold                   },
 { "turnoff",S(LINK),    2,      "",     "",     NULL,   turnoff         },
 { "=.r",    S(ASSIGN),  1,      "r",    "i",    rassign                 },
 { "=.i",    S(ASSIGNM), 1,      "IIIIIIIIIIIIIIIIIIIIIIII", "m", minit  },
 { "=.k",    S(ASSIGNM), 2,      "zzzzzzzzzzzzzzzzzzzzzzzz", "z", NULL, minit },
 { "=.a",    S(ASSIGN),  4,      "a",    "x",    NULL,   NULL,   aassign },
+{ "=.t",    S(ASSIGNT), 2,      "t",    "kk",   NULL,   tassign, NULL   },
 { "init.i", S(ASSIGNM), 1,      "IIIIIIIIIIIIIIIIIIIIIIII", "m", minit  },
 { "init.k", S(ASSIGNM), 1,      "zzzzzzzzzzzzzzzzzzzzzzzz", "m", minit  },
 { "init.a", S(ASSIGNM), 1,      "mmmmmmmmmmmmmmmmmmmmmmmm", "m", mainit },
+{ "init.t", S(ASSIGNM), 1,      "t",    "io",                    tinit  },
+{ "tabref", S(TABREF),  3,      "k",    "tk",   tabref_check, tabref, NULL },
 { ">",      S(RELAT),   0,      "B",    "kk",   gt,     gt              },
 { ">=",     S(RELAT),   0,      "B",    "kk",   ge,     ge              },
 { "<",      S(RELAT),   0,      "B",    "kk",   lt,     lt              },
@@ -197,6 +203,8 @@ OENTRY opcodlst_1[] = {
 { "sin.i",  S(EVAL),    1,      "i",    "i",    sin1                    },
 { "cos.i",  S(EVAL),    1,      "i",    "i",    cos1                    },
 { "tan.i",  S(EVAL),    1,      "i",    "i",    tan1                    },
+{ "qinf.i", S(EVAL),    1,      "i",    "i",    is_inf                  },
+{ "qnan.i", S(EVAL),    1,      "i",    "i",    is_NaN                  },
 { "sininv.i", S(EVAL),  1,      "i",    "i",    asin1                   },
 { "cosinv.i", S(EVAL),  1,      "i",    "i",    acos1                   },
 { "taninv.i", S(EVAL),  1,      "i",    "i",    atan1                   },
@@ -219,6 +227,8 @@ OENTRY opcodlst_1[] = {
 { "sin.k",  S(EVAL),    2,      "k",    "k",    NULL,   sin1            },
 { "cos.k",  S(EVAL),    2,      "k",    "k",    NULL,   cos1            },
 { "tan.k",  S(EVAL),    2,      "k",    "k",    NULL,   tan1            },
+{ "qinf.k", S(EVAL),    2,      "k",    "k",    NULL,   is_inf          },
+{ "qnan.k", S(EVAL),    2,      "k",    "k",    NULL,   is_NaN          },
 { "sininv.k", S(EVAL),  2,      "k",    "k",    NULL,   asin1           },
 { "cosinv.k", S(EVAL),  2,      "k",    "k",    NULL,   acos1           },
 { "taninv.k", S(EVAL),  2,      "k",    "k",    NULL,   atan1           },
@@ -239,6 +249,8 @@ OENTRY opcodlst_1[] = {
 { "sin.a",  S(EVAL),    4,      "a",    "a",    NULL,   NULL,   sina    },
 { "cos.a",  S(EVAL),    4,      "a",    "a",    NULL,   NULL,   cosa    },
 { "tan.a",  S(EVAL),    4,      "a",    "a",    NULL,   NULL,   tana    },
+{ "qinf.a", S(EVAL),    4,      "a",    "a",    NULL,   NULL,   is_infa },
+{ "qnan.a", S(EVAL),    4,      "a",    "a",    NULL,   NULL,   is_NaNa },
 { "sininv.a", S(EVAL),  4,      "a",    "a",    NULL,   NULL,   asina   },
 { "cosinv.a", S(EVAL),  4,      "a",    "a",    NULL,   NULL,   acosa   },
 { "taninv.a", S(EVAL),  4,      "a",    "a",    NULL,   NULL,   atana   },
@@ -264,6 +276,7 @@ OENTRY opcodlst_1[] = {
 { "ftlptim.i",S(EVAL),  1,      "i",    "i",    ftlptim                 },
 { "ftchnls.i",S(EVAL),  1,      "i",    "i",    ftchnls                 },
 { "ftcps.i",S(EVAL),    1,      "i",    "i",    ftcps                   },
+{ "i.i",   S(ASSIGN),   1,      "i",    "i",    assign                  },
 { "i.k",   S(ASSIGN),   1,      "i",    "k",    assign                  },
 { "k.i",   S(ASSIGN),   1,      "k",    "i",    assign                  },
 { "cpsoct.i",S(EVAL),   1,      "i",    "i",    cpsoct                  },
@@ -307,9 +320,12 @@ OENTRY opcodlst_1[] = {
 { "line",   S(LINE),    7,      "s",    "iii",  linset, kline,  aline   },
 { "expon",  S(EXPON),   7,      "s",    "iii",  expset, kexpon, expon   },
 { "linseg", S(LINSEG),  7,      "s",    "iin",  lsgset, klnseg, linseg  },
+{ "linsegb", S(LINSEG),  7,      "s",    "iin", lsgset_bkpt, klnseg, linseg  },
 { "linsegr",S(LINSEG),  7,      "s",    "iin",  lsgrset,klnsegr,linsegr },
 { "expseg", S(EXXPSEG),  7,     "s",    "iin",  xsgset, kxpseg, expseg  },
+{ "expsegb", S(EXXPSEG),  7,     "s",    "iin",  xsgset_bkpt, kxpseg, expseg  },
 { "expsega",S(EXPSEG2),  7,     "a",    "iin",  xsgset2, NULL, expseg2  },
+{ "expsegba",S(EXPSEG2),  7,     "a",    "iin",  xsgset2b, NULL, expseg2  },
 { "expsegr",S(EXPSEG),  7,      "s",    "iin",  xsgrset,kxpsegr,expsegr },
 { "linen",  S(LINEN),   7,      "s",    "xiii", lnnset, klinen, linen   },
 { "linenr", S(LINENR),  7,      "s",    "xiii", lnrset, klinenr,linenr  },
@@ -372,16 +388,14 @@ OENTRY opcodlst_1[] = {
 { "rms",    S(RMS),     3,      "k",    "aqo",  rmsset, rms             },
 { "gain",   S(GAIN),    5,      "a",    "akqo", gainset,NULL,   gain    },
 { "balance",S(BALANCE), 5,      "a",    "aaqo", balnset,NULL,   balance },
-{ "pan",    S(PAN),   5, "aaaa", "akkioo",(SUBR)panset,NULL,   (SUBR)pan     },
-{ "soundin",S(SOUNDIN_),5,"mmmmmmmmmmmmmmmmmmmmmmmm","Toooo",
+{ "pan",    S(PAN),   5, "aaaa", "akkioo",(SUBR)panset,NULL, (SUBR)pan  },
+{ "soundin",S(SOUNDIN_),5,"mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm","Toooo",
                                                 sndinset, NULL, soundin   },
 { "soundout",S(SNDOUT), 5,      "",     "aTo",  sndo1set, NULL, soundout  },
 { "soundouts",S(SNDOUTS),5,     "",     "aaTo", sndo1set, NULL, soundouts },
 { "in",     S(INM),     4,      "a",    "",     NULL,   NULL,   in      },
 { "ins",    S(INS),     4,      "aa",   "",     NULL,   NULL,   ins     },
-#ifndef OLPC
 { "inq",    S(INQ),     4,      "aaaa", "",     NULL,   NULL,   inq     },
-#endif
   /* Note that there is code in rdorch.c that assumes that opcodes starting
      with the charcters out followed by a s, q, h, o or x are in this group
      ***BEWARE***
@@ -390,13 +404,11 @@ OENTRY opcodlst_1[] = {
 { "outs",   S(OUTS),    4,      "",     "aa",   NULL,   NULL,   outs    },
 { "outs1",  S(OUTM),    4,      "",     "a",    NULL,   NULL,   outs1   },
 { "outs2",  S(OUTM),    4,      "",     "a",    NULL,   NULL,   outs2   },
-#ifndef OLPC
 { "outq",   S(OUTQ),    4,      "",     "aaaa", NULL,   NULL,   outq    },
 { "outq1",  S(OUTM),    4,      "",     "a",    NULL,   NULL,   outq1   },
 { "outq2",  S(OUTM),    4,      "",     "a",    NULL,   NULL,   outq2   },
 { "outq3",  S(OUTM),    4,      "",     "a",    NULL,   NULL,   outq3   },
 { "outq4",  S(OUTM),    4,      "",     "a",    NULL,   NULL,   outq4   },
-#endif
 { "igoto",  S(GOTO),    1,      "",     "l",    igoto                   },
 { "kgoto",  S(GOTO),    2,      "",     "l",    NULL,   kgoto           },
 { "goto",   S(GOTO),    3,      "",     "l",    igoto,  kgoto           },
@@ -463,9 +475,9 @@ OENTRY opcodlst_1[] = {
 { "unirand.i",S(PRAND), 1,     "i",     "k",    ikuniform, NULL,  NULL  },
 { "unirand.k",S(PRAND), 2,     "k",     "k",    NULL,    ikuniform, NULL},
 { "unirand.a",S(PRAND), 4,     "a",     "k",    NULL,    NULL, auniform },
-{ "diskin",S(SOUNDINEW),5,  "mmmmmmmmmmmmmmmmmmmmmmmm", "Tkooooo",
+{ "diskin",S(SOUNDINEW),5,  "mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm", "Tkooooo",
                             (SUBR) newsndinset, NULL, (SUBR) soundinew  },
-{ "diskin2",S(DISKIN2), 5,  "mmmmmmmmmmmmmmmmmmmmmmmm", "Tkoooooo",
+{ "diskin2",S(DISKIN2), 5,  "mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm", "Tkoooooo",
                             (SUBR) diskin2_init, (SUBR) NULL,
                             (SUBR) diskin2_perf                         },
 { "noteon", S(OUT_ON),  1,      "",     "iii",  iout_on, NULL,   NULL   },
@@ -506,7 +518,7 @@ OENTRY opcodlst_1[] = {
 { "filesr", S(SNDINFO),  1,     "i",    "Tp",   filesr, NULL, NULL         },
 { "filebit", S(SNDINFO),  1,     "i",   "Tp",   filebit, NULL, NULL        },
 { "filepeak", S(SNDINFOPEAK), 1, "i",   "To",   filepeak, NULL, NULL       },
-{ "filevalid", S(FILEVALID), 1,  "i",   "S",    filevalid, NULL, NULL      },
+{ "filevalid", S(FILEVALID), 1,  "i",   "T",    filevalid, NULL, NULL      },
 /*  { "nlalp", S(NLALP),     5,     "a",    "akkoo", nlalp_set, NULL, nlalp }, */
 /* Robin Whittle */
 { "tableiw",  S(TABLEW),1,     "",      "iiiooo", (SUBR)itablew, NULL, NULL},
@@ -563,21 +575,18 @@ OENTRY opcodlst_1[] = {
 { "resonk", S(KRESON),  3, "k",     "kkkpo",(SUBR)krsnset, (SUBR)kreson, NULL  },
 { "aresonk",S(KRESON),  3, "k",     "kkkpo",(SUBR)krsnset, (SUBR)kareson, NULL },
 { "limit.i", S(LIMIT),  1, "i",     "iii",  (SUBR)klimit,  NULL,    NULL       },
-{ "limit.k",  S(LIMIT), 3, "k",     "xkk",  (SUBR)limitset, (SUBR)klimit, NULL },
-{ "limit.a",  S(LIMIT), 5, "a",     "xkk",  (SUBR)limitset, NULL,  (SUBR)limit },
+{ "limit.k",  S(LIMIT), 2, "k",     "xkk",  NULL,           (SUBR)klimit, NULL },
+{ "limit.a",  S(LIMIT), 4, "a",     "xkk",  NULL,           NULL,  (SUBR)limit },
 { "prealloc", S(AOP),   1, "",      "Tio",  (SUBR)prealloc, NULL, NULL  },
 /* opcode   dspace      thread  outarg  inargs  isub    ksub    asub    */
-#ifndef OLPC
 { "inh",    S(INH),     4,      "aaaaaa","",    NULL,   NULL,   inh     },
 { "ino",    S(INO),     4,      "aaaaaaaa","",  NULL,   NULL,   ino     },
 { "inx",    S(INALL),   4,      "aaaaaaaaaaaaaaaa","",  NULL,   NULL,   in16 },
 { "in32",   S(INALL),   4,      "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                         "",     NULL,   NULL,   in32 },
-#endif
 //{ "inch",   S(INCH),    4,      "a",    "k",    NULL,   NULL,   inch_opcode },
 { "inch",   S(INCH),    4,      "mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm",
                                         "z",    NULL,   NULL,   inch_opcode },
-#ifndef OLPC
 { "_in",    S(INALL),   4,      "mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm",
                                         "",     NULL,   NULL,   inall_opcode },
   /* Note that there is code in rdorch.c that assumes that opcodes starting
@@ -589,7 +598,6 @@ OENTRY opcodlst_1[] = {
 { "outx",   S(OUTX),    4,      "",     "aaaaaaaaaaaaaaaa",NULL,NULL, outx },
 { "out32",  S(OUTX),    4,      "",     "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                                                 NULL,   NULL,   outX    },
-#endif
 { "outch",  S(OUTCH),   4,      "",     "Z",    NULL,   NULL,   outch   },
 { "outc",   S(OUTX),    4,      "",     "y",    NULL,   NULL,   outall  },
 { "cpsxpch", S(XENH),   1,      "i",    "iiii", cpsxpch, NULL,  NULL    },
@@ -871,6 +879,19 @@ OENTRY opcodlst_1[] = {
    (SUBR) NULL, (SUBR) sensekey_perf, (SUBR) NULL                      },
 { "remove",      S(DELETEIN),         1,      "",             "T",
    (SUBR) delete_instr, (SUBR) NULL, (SUBR) NULL                       },
+#ifdef PARCS
+{ "##globallock",   S(GLOBAL_LOCK_UNLOCK), 3, "", "k", globallock,   globallock,   NULL},
+{ "##globalunlock", S(GLOBAL_LOCK_UNLOCK), 3, "", "k", globalunlock, globalunlock, NULL},
+#endif
+{ "exprandi.i",S(PRANDI), 1,      "i",    "kxx",  iexprndi, NULL,    NULL    },
+{ "exprandi.k",S(PRANDI), 3,      "k",    "kxx",  exprndiset, kexprndi, NULL },
+{ "exprandi.a",S(PRANDI), 4,      "a",    "kxx",  exprndiset, NULL, aexprndi },
+{ "cauchyi.i", S(PRANDI), 1,      "i",    "kxx",  icauchyi, NULL,    NULL    },
+{ "cauchyi.k", S(PRANDI), 3,      "k",    "kxx",  cauchyiset, kcauchyi, NULL },
+{ "cauchyi.a", S(PRANDI), 4,      "a",    "kxx",  cauchyiset, NULL, acauchyi },
+{ "gaussi.i", S(PRANDI), 1,      "i",    "kxx",  igaussi, NULL,    NULL    },
+{ "gaussi.k", S(PRANDI), 3,      "k",    "kxx",  gaussiset, kgaussi, NULL },
+{ "gaussi.a", S(PRANDI), 4,      "a",    "kxx",  gaussiset, NULL, agaussi },
 /* terminate list */
 {  NULL, 0, 0, NULL, NULL, (SUBR) NULL, (SUBR) NULL, (SUBR) NULL       }
 };
