@@ -29,7 +29,7 @@
 #include "aops.h"       /* for cond's */
 #include "midiops.h"
 #include "namedins.h"   /* IV - Oct 31 2002 */
-
+#include "pstream.h"
 extern MYFLT cpsocfrc[];        /* Needed by CPSOCTL */
 
 static  void    showallocs(CSOUND *);
@@ -166,15 +166,11 @@ int insert(CSOUND *csound, int insno, EVTBLK *newevtp)
 
     init:
       if (tp->psetdata) {
-        MYFLT *pfld = &ip->p3;              /* if pset data present */
         MYFLT *pdat = tp->psetdata + 2;
         int32 nn = tp->pmax - 2;             /*   put cur vals in pflds */
-        /* do { */
-        /*   *pfld++ = *pdat++; */
-        /* } while (--nn); */
         memcpy(&ip->p3, pdat, sizeof(MYFLT)*nn);
       }
-      if ((n = tp->pmax) != newevtp->pcnt && !tp->psetdata) {
+      if (UNLIKELY((n = tp->pmax) != newevtp->pcnt && !tp->psetdata)) {
         char *name = csound->instrtxtp[insno]->insname;
         if (UNLIKELY(name))
           csoundWarning(csound, Str("instr %s uses %d p-fields but is given %d"),
@@ -742,7 +738,7 @@ int csoundInitError(CSOUND *csound, const char *s, ...)
       do {
         ip = ((OPCOD_IOBUFS*) ip->opcod_iobufs)->parent_ip;
       } while (ip->opcod_iobufs);
-      if (op) 
+      if (op)
         sprintf(buf, Str("INIT ERROR in instr %d (opcode %s): "),
                 ip->insno, op->name);
       else
@@ -1089,6 +1085,13 @@ int xinset(CSOUND *csound, XIN *p)
       *(tmp++) = *(p->args + *ndx_list);/* "to" address */
     }
     *(tmp++) = NULL;            /* put delimiter */
+    /* fsigs: we'll need to do extra work 
+    while (*++ndx_list >= 0) {
+      *(tmp++) = *(bufs + *ndx_list);   
+      *(tmp++) = *(p->args + *ndx_list);
+    }
+    *(tmp++) = NULL;       */
+
     /* fix for case when xout is omitted */
     *(tmp++) = NULL; *tmp = NULL;
     return OK;
@@ -1140,6 +1143,13 @@ int xoutset(CSOUND *csound, XOUT *p)
       *(tmp++) = *(bufs + *ndx_list);   /* "to" address */
     }
     *tmp = NULL;                /* put delimiter */
+      /* fsigs: we'll need to do extra work 
+    while (*++ndx_list >= 0) {
+      *(tmp++) = *(p->args + *ndx_list);
+      *(tmp++) = *(bufs + *ndx_list);   
+    }
+    *tmp = NULL; */
+
     return OK;
 }
 
@@ -1238,7 +1248,7 @@ INSDS *insert_event(CSOUND *csound,
       if (name)
         csound->Message(csound, Str("instr %s expects midi event data, "
                                     "cannot run from score\n"), name);
-      else 
+      else
         csound->Message(csound, Str("instr %d expects midi event data, "
                                     "cannot run from score\n"), insno);
       csound->perferrcnt++;
