@@ -108,12 +108,12 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     OPCODINFO   *inm = (OPCODINFO*) opc->useropinfo;
     char    *types, *otypes;
     int     i, i_incnt, a_incnt, k_incnt, i_outcnt, a_outcnt, k_outcnt, err;
-    int     S_incnt, S_outcnt;
+    int     S_incnt, S_outcnt, f_outcnt, f_incnt;
     int16   *a_inlist, *k_inlist, *i_inlist, *a_outlist, *k_outlist, *i_outlist;
-    int16   *S_inlist, *S_outlist;
+    int16   *S_inlist, *S_outlist, *f_inlist, *f_outlist;
 
     /* count the number of arguments, and check types */
-    i = i_incnt = S_incnt = a_incnt = k_incnt =
+    i = i_incnt = S_incnt = a_incnt = k_incnt = f_incnt = f_outcnt =
         i_outcnt = S_outcnt = a_outcnt = k_outcnt = err = 0;
     types = inm->intypes; otypes = opc->intypes;
     opc->dsblksiz = (uint16) sizeof(UOPCODE);
@@ -129,6 +129,9 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       case 'k':
         k_incnt++; *otypes++ = 'k';
         break;
+      case 'f':
+        f_incnt++; *otypes++ = *types;
+        break;
       case 'i':
       case 'o':
       case 'p':
@@ -150,7 +153,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     }
     *otypes++ = 'o'; *otypes = '\0';    /* optional arg for local ksmps */
     inm->inchns = i;                    /* total number of input chnls */
-    inm->perf_incnt = a_incnt + k_incnt;
+    inm->perf_incnt = a_incnt + k_incnt + f_incnt;
     opc->dsblksiz += (uint16) (sizeof(MYFLT*) * i);
     /* same for outputs */
     i = 0;
@@ -171,6 +174,9 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       case 'k':
         k_outcnt++; *otypes++ = 'k';
         break;
+      case 'f':
+        f_outcnt++; *otypes++ = *types;
+        break;
       case 'i':
         i_outcnt++; *otypes++ = *types;
         break;
@@ -185,7 +191,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     }
     *otypes = '\0';
     inm->outchns = i;                   /* total number of output chnls */
-    inm->perf_outcnt = a_outcnt + k_outcnt;
+    inm->perf_outcnt = a_outcnt + k_outcnt + f_outcnt;
     opc->dsblksiz += (uint16) (sizeof(MYFLT*) * i);
     opc->dsblksiz = ((opc->dsblksiz + (uint16) 15)
                      & (~((uint16) 15)));   /* align (needed ?) */
@@ -193,15 +199,17 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     i = i_incnt + S_incnt + inm->perf_incnt +
         i_outcnt + S_outcnt + inm->perf_outcnt;
     i_inlist = inm->in_ndx_list = (int16*) mmalloc(csound,
-                                                   sizeof(int16) * (i + 8));
+                                                   sizeof(int16) * (i + 10));
     S_inlist = i_inlist + i_incnt + 1;
     a_inlist = S_inlist + S_incnt + 1;
     k_inlist = a_inlist + a_incnt + 1;
+    f_inlist = k_inlist + k_incnt + 1;
     i = 0; types = inm->intypes;
     while (*types) {
       switch (*types++) {
         case 'a': *a_inlist++ = i; break;
         case 'k': *k_inlist++ = i; break;
+        case 'f': *f_inlist++ = i; break;
         case 'K': *k_inlist++ = i;      /* also updated at i-time */
         case 'i':
         case 'o':
@@ -211,23 +219,25 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       }
       i++;
     }
-    *i_inlist = *S_inlist = *a_inlist = *k_inlist = -1;     /* put delimiters */
-    i_outlist = inm->out_ndx_list = k_inlist + 1;
+    *i_inlist = *S_inlist = *a_inlist = *k_inlist = *f_inlist = -1;     /* put delimiters */
+    i_outlist = inm->out_ndx_list = f_inlist + 1;
     S_outlist = i_outlist + i_outcnt + 1;
     a_outlist = S_outlist + S_outcnt + 1;
     k_outlist = a_outlist + a_outcnt + 1;
+    f_outlist = k_outlist + k_outcnt + 1;
     i = 0; types = inm->outtypes;
     while (*types) {
       switch (*types++) {
         case 'a': *a_outlist++ = i; break;
         case 'k': *k_outlist++ = i; break;
+        case 'f': *f_outlist++ = i; break;
         case 'K': *k_outlist++ = i;     /* also updated at i-time */
         case 'i': *i_outlist++ = i; break;
         case 'S': *S_outlist++ = i; break;
       }
       i++;
     }
-    *i_outlist = *S_outlist = *a_outlist = *k_outlist = -1;  /* put delimiters */
+    *i_outlist = *S_outlist = *a_outlist = *k_outlist = *f_outlist = -1;  /* put delimiters */
     return err;
 }
 
@@ -253,7 +263,7 @@ void otran(CSOUND *csound)
     ARGLST      *alp;
     char        *s;
     int32        pmax = -1, nn;
-    int32        n, opdstot = 0, count, sumcount, instxtcount, optxtcount;
+    int32        n = 0, opdstot = 0, count, sumcount, instxtcount, optxtcount;
 
     if (csound->otranGlobals == NULL) {
       csound->otranGlobals = csound->Calloc(csound, sizeof(OTRAN_GLOBALS));
@@ -494,7 +504,7 @@ void otran(CSOUND *csound)
                 else if (strcmp(s, "ksmps") == 0)
                   csound->tran_ksmps = constval;
                 else if (strcmp(s, "nchnls") == 0)
-                  csound->tran_nchnls = (int) constval;
+                 csound->tran_nchnlsi = csound->tran_nchnls = (int) constval;
                 else if (strcmp(s, "nchnls_i") == 0)
                   csound->tran_nchnlsi = (int) constval;
                 /* we have set this as reserved in rdorch.c */
@@ -1195,6 +1205,7 @@ void oload(CSOUND *p)
     MYFLT   ensmps;
 
     p->esr = p->tran_sr; p->ekr = p->tran_kr;
+    p->e0dbfs = p->tran_0dbfs;
     p->ksmps = (int) ((ensmps = p->tran_ksmps) + FL(0.5));
     ip = p->instxtanchor.nxtinstxt;        /* for instr 0 optxts:  */
     optxt = (OPTXT *) ip;
@@ -1260,7 +1271,9 @@ void oload(CSOUND *p)
     gblspace[1] = p->ekr;           /*   rsvd word      */
     gblspace[2] = (MYFLT) p->ksmps; /*   curr vals      */
     gblspace[3] = (MYFLT) p->nchnls;
-    gblspace[4] = p->e0dbfs;
+    if (p->inchnls<0) p->inchnls = p->nchnls;
+    gblspace[4] = (MYFLT) p->inchnls;
+    gblspace[5] = p->e0dbfs;
     p->gbloffbas = p->pool - 1;
     /* string constants: unquote, convert escape sequences, and copy to pool */
     convert_strconst_pool(p, (MYFLT*) p->gbloffbas + (int32) gblscbeg);
@@ -1387,7 +1400,7 @@ void oload(CSOUND *p)
     reverbinit(p);
     dbfs_init(p, p->e0dbfs);
     p->nspout = p->ksmps * p->nchnls;  /* alloc spin & spout */
-    p->nspin = p->ksmps * p->nchnls_i; /* JPff: in preparation */
+    p->nspin = p->ksmps * p->inchnls; /* JPff: in preparation */
     p->spin  = (MYFLT *) mcalloc(p, p->nspin * sizeof(MYFLT));
     p->spout = (MYFLT *) mcalloc(p, p->nspout * sizeof(MYFLT));
     /* chk consistency one more time (FIXME: needed ?) */
