@@ -26,6 +26,7 @@
 #include "namedins.h"   /* IV - Oct 31 2002 */
 #include "typetabl.h"   /* IV - Oct 31 2002 */
 #include "envvar.h"
+#include <stddef.h>
 
 #ifdef sun
 #define   SEEK_SET        0
@@ -395,6 +396,7 @@ static void init_math_constants_macros(CSOUND *csound)
      add_math_const_macro(csound, "2_SQRTPI", "1.12837916709551257390");
      add_math_const_macro(csound, "SQRT2", "1.41421356237309504880");
      add_math_const_macro(csound, "SQRT1_2", "0.70710678118654752440");
+     add_math_const_macro(csound, "INF", "2147483647.0"); /* ~7 years */
 }
 
 static void init_omacros(CSOUND *csound, NAMES *nn)
@@ -513,15 +515,17 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
 
  top:
     while ((c = getorchar(csound)) != EOF) {    /* read entire orch file  */
-      if (cp == endspace-1) {                   /* Must extend */
+      if (cp == endspace-5) {                   /* Must extend */
         char *orold = ortext;
         int  i;
+        /* printf("Expand orch: %p (%d) %p -> ", ortext, ST(orchsiz), endspace); */
         ST(orchsiz) = ST(orchsiz) + (ST(orchsiz) >> 4) + 1L;
         ST(orchsiz) = (ST(orchsiz) + 511L) & (~511L);
         ortext = mrealloc(csound, ortext, ST(orchsiz));
         endspace = ortext + ST(orchsiz) + 1;
+        /* printf("%p (%d) %p\n", ortext, ST(orchsiz), endspace); */
         if (ortext != orold) {
-          int adj = ortext - orold;
+          ptrdiff_t adj = ortext - orold;
           for (i=1; i<=lincnt; i++)
             ST(linadr)[i] += adj; /* Relocate */
           cp += adj;
@@ -546,14 +550,14 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
         else
           ungetorchar(csound, c2);
       }
-      if (c == ';' && !heredoc && !openquote) {
+      if (c == ';' && !heredoc) {
         skiporchar(csound);
         *(cp - 1) = (char) (c = '\n');
       }
       if (c == '"' && !heredoc) {
         openquote = !openquote;
       }
-      if (c == '\\' && !heredoc) {                   /* Continuation ?       */
+      if (c == '\\' && !heredoc & !openquote) {      /* Continuation ?       */
         while ((c = getorchar(csound)) == ' ' || c == '\t')
           ;                                          /* Ignore spaces        */
         if (c == ';') {                              /* Comments get skipped */
@@ -563,7 +567,7 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
         if (c == '\n') {
           cp--;                                      /* Ignore newline */
           srccnt++;                                  /*    record a fakeline */
-          lincnt++;
+          /* lincnt++; Thsi is wrong */
         }
         else {
           *cp++ = c;
@@ -583,6 +587,7 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
       }
       else if (c == '\n') {                          /* at each new line */
         char *lp = ST(linadr)[lincnt];
+        /* printf("lincnt=%d; lp=%p, ST(linadr)=%p\n", lincnt, lp, ST(linadr)); */
         while ((c = *lp) == ' ' || c == '\t')
           lp++;
         if (*lp != '\n' && *lp != ';') {
@@ -1138,11 +1143,15 @@ static int splitline(CSOUND *csound)
         grpp = ST(group)[grpcnt++] = cp;
         *cp++ = c;                          /*  cpy to nxt quote */
        do {
-          c = *lp++;
-          if (c=='\\') {                    /* Deal with \" case */
-            c = *lp++;
-          }
-          *cp++ = c;
+       loop:
+         c = *lp++;
+         if (c=='\\' && *lp=='"') {        /* Deal with \" case */
+           *cp++ = '\\';
+           *cp++ = '"';
+           lp++;
+           goto loop;
+         }
+         *cp++ = c;
        } while (c != '"' && c != '\n');
         if (c == '\n')
           synterrp(csound, lp - 1, Str("unmatched quotes"));
@@ -1805,6 +1814,7 @@ TEXT *getoptxt(CSOUND *csound, int *init)
             switch (c[i]) {
               case 'a':
               case 'k':
+	      case 'f':
               case 'i': xtypes[i] = c[i]; break;
               case 'K': xtypes[i] = 'k';
             }
@@ -1842,8 +1852,10 @@ TEXT *getoptxt(CSOUND *csound, int *init)
             break;
           case 'h': ST(nxtarglist)->arg[incnt++] = strsav_string(csound, "127");
             break;
+          case 'J':
           case 'j': ST(nxtarglist)->arg[incnt++] = strsav_string(csound, "-1");
             break;
+          case 'F':
           case 'M':
           case 'N':
           case 'm': nreqd--;
@@ -1970,6 +1982,7 @@ TEXT *getoptxt(CSOUND *csound, int *init)
           while (c[i]) {
             switch (c[i]) {
             case 'a': xtypes[i] = c[i]; break;
+            case  'f': xtypes[i] = c[i]; break;
             case 'k':
             case 'P':
             case 'K': xtypes[i] = 'k'; break;
@@ -1987,7 +2000,7 @@ TEXT *getoptxt(CSOUND *csound, int *init)
       if (UNLIKELY((n != nreqd) &&      /* IV - Oct 24 2002: end of new code */
           !(n > 0 && n < nreqd &&
             (types[n] == 'm' || types[n] == 'z' || types[n] == 'I' ||
-             types[n] == 'X' || types[n] ==  'N')))) {
+             types[n] == 'X' || types[n] == 'N' || types[n] == 'F')))) {
         synterr(csound, Str("illegal no of output args"));
         if (n > nreqd)
           n = nreqd;
@@ -2096,7 +2109,7 @@ char argtyp(CSOUND *csound, char *s)
       return('S');                              /* quoted String */
     ST(lgprevdef) = lgexist(csound, s);               /* (lgprev) */
     if (strcmp(s,"sr") == 0    || strcmp(s,"kr") == 0 ||
-        strcmp(s,"0dbfs") == 0 || strcmp(s,"nchnls_i") == 0 || 
+        strcmp(s,"0dbfs") == 0 || strcmp(s,"nchnls_i") == 0 ||
         strcmp(s,"ksmps") == 0 || strcmp(s,"nchnls") == 0)
       return('r');                              /* rsvd */
     if (c == 'w')               /* N.B. w NOT YET #TYPE OR GLOBAL */
