@@ -36,11 +36,9 @@
 #endif
 
 ORCTOKEN** symbtab;
-extern int yyline;
+
 #define udoflag csound->parserUdoflag
 #define namedInstrFlag csound->parserNamedInstrFlag
-//extern int udoflag;
-//extern int namedInstrFlag;
 
 ORCTOKEN *add_token(CSOUND *csound, char *s, int type);
 
@@ -48,12 +46,12 @@ int get_opcode_type(OENTRY *ep)
 {
     int retVal = 0;
 
-//    if((ep->outypes == NULL || strlen(ep->outypes) == 0) &&
+//    if ((ep->outypes == NULL || strlen(ep->outypes) == 0) &&
 //       (ep->intypes == NULL || strlen(ep->intypes) == 0)) {
 //        retVal = T_OPCODE00;
 //    } else
 
-    if(ep->outypes == NULL || strlen(ep->outypes) == 0) {
+    if (ep->outypes == NULL || strlen(ep->outypes) == 0) {
       retVal = T_OPCODE0;
     }
     else {
@@ -79,34 +77,20 @@ void init_symbtab(CSOUND *csound)
     for (ep = (OENTRY*) csound->opcodlst; ep < (OENTRY*) csound->oplstend; ep++) {
         if (ep->dsblksiz >= 0xfffb) {
           char * polyName;
-          /* if (PARSER_DEBUG) */
-          /*   csound->Message(csound, */
-          /*           "Found PolyMorphic Opcode %s\n",ep->opname); */
-
           len = strlen(ep->opname) + 1;
           polyName = mcalloc(csound, len + 1);
           sprintf(polyName, "%s.", ep->opname);
 
           for (temp = (OENTRY*) csound->opcodlst;
                temp < (OENTRY*) csound->oplstend; temp++) {
-            if(ep != temp && strncmp(polyName, temp->opname, len) == 0) {
+            if (ep != temp && strncmp(polyName, temp->opname, len) == 0) {
               add_token(csound, ep->opname, get_opcode_type(temp));
-
-              if (PARSER_DEBUG) {
-                if(get_opcode_type(temp) == T_OPCODE) {
-                  csound->Message(csound, "Using Type T_OPCODE\n");
-                }
-                else {
-                  csound->Message(csound, "Using Type T_OPCODE0\n");
-                }
-              }
-              break;
             }
           }
 
           mfree(csound, polyName);
 
-//        if(strchr(ep->opname, '.') != NULL) {
+//        if (strchr(ep->opname, '.') != NULL) {
 //           csound->Message(csound,
 //                   "Found PolyMorphic Opcode Definition %s\n",ep->opname);
 //        }
@@ -259,7 +243,7 @@ int isUDOAnsList(char *s)
     return 1;
 }
 
-ORCTOKEN *lookup_token(CSOUND *csound, char *s)
+ORCTOKEN *lookup_token(CSOUND *csound, char *s, void *yyscanner)
 {
     unsigned int h = hash(s);
     int type = T_IDENT;
@@ -320,36 +304,43 @@ ORCTOKEN *lookup_token(CSOUND *csound, char *s)
     if (PARSER_DEBUG)
       csound->Message(csound, "NamedInstrFlag: %d\n", namedInstrFlag);
 
-    if(udoflag == -2 || namedInstrFlag == 1) {
+    if (udoflag == -2 || namedInstrFlag == 1) {
         return ans;
     }
 
     // NEED TO FIX: In case of looking for label for kgoto or other opcodes, need
     // to return T_IDENT instead of any sub-type
-    if (s[0]=='i') type = T_IDENT_I;
-    else if (s[0]=='k') type = T_IDENT_K;
-    else if (s[0]=='a') type = T_IDENT_A;
-    else if (s[0]=='p') type = T_IDENT_P;
-    else if (s[0]=='f') type = T_IDENT_F;
-    else if (s[0]=='w') type = T_IDENT_W;
-    else if (s[0]=='S') type = T_IDENT_S;
-    else if (s[0]=='g') {
-      if (s[1]=='i') type = T_IDENT_GI;
-      else if (s[1]=='k') type = T_IDENT_GK;
-      else if (s[1]=='a') type = T_IDENT_GA;
-      else if (s[1]=='f') type = T_IDENT_GF;
-      else if (s[1]=='w') type = T_IDENT_GW;
-      else if (s[1]=='S') type = T_IDENT_GS;
-      else {
-        csound->Message(csound, Str("Unknown word type for %s on line %d\n"), s, yyline);
+    // Currently fixed by definition of label non-terminal
+    switch (s[0]) {
+    case 'S': type = T_IDENT_S; break;
+    case 'a': type = T_IDENT_A; break;
+    case 'f': type = T_IDENT_F; break;
+    case 'i': type = T_IDENT_I; break;
+    case 'k': type = T_IDENT_K; break;
+    case 'p': type = T_IDENT_P; break;
+    case 't': type = T_IDENT_T; break;
+    case 'w': type = T_IDENT_W; break;
+    case'g':
+      switch (s[1]) {
+      case 'i': type = T_IDENT_GI; break;
+      case 'k': type = T_IDENT_GK; break;
+      case 'a': type = T_IDENT_GA; break;
+      case 'f': type = T_IDENT_GF; break;
+      case 'w': type = T_IDENT_GW; break;
+      case 't': type = T_IDENT_GT; break;
+      case 'S': type = T_IDENT_GS; break;
+      default: 
+        csound->Message(csound, Str("Unknown word type for %s on line %d\n"),
+                        s, csound_orcget_lineno(yyscanner));
         exit(1);
       }
-    }
-    /* else {
+    default: /*
       printf("IDENT Token: %i : %i", ans->type, T_IDENT);
       printf("Unknown word type for %s on line %d\n", s, yyline);
       exit(1);
-    } */
+             */
+      break;
+    }
     ans->type = type;
     //symbtab[h] = ans;
 
