@@ -29,17 +29,53 @@
 #define CSOUNDCORE_H
 
 #include "sysdep.h"
-
+#ifdef PARCS
+#include <pthread.h>
+#endif
 #include <stdarg.h>
 #include <setjmp.h>
+
+/*
 #include <sndfile.h>
+JPff:  But this gives warnings in many files as rewriteheader expects
+to have an argument of SNDFILE*.  Might be able to fix with a void*
+VL: moved to allow opcodes to be built without libsndfile headers
+The libsndfile header is now place only where it is used:
+Engine/envvar.c
+Engine/memfiles.c
+Engine/libsnd_u.c
+OOps/sndinfUG.c
+Opcodes/fout.c
+util/atsa.c
+Opcodes/stdopcode.h
+H/diskin2.h
+H/soundio.h
+util/pvanal.c
+util/sndinfo.c
+util/xtrct.c
+*/
 
 #include "csound.h"
 
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
+#ifdef __MACH__
+#define BARRIER_SERIAL_THREAD (-1)
+typedef struct {
+  pthread_mutex_t mut;
+  pthread_cond_t cond;
+  unsigned int count, max, iteration;
+} barrier_t;
+
+#ifndef PTHREAD_BARRIER_SERIAL_THREAD
+#define pthread_barrier_t barrier_t
+#endif
+#endif
+
+
 #define OK        (0)
 #define NOTOK     (-1)
 
@@ -55,7 +91,7 @@ extern "C" {
 
 #define ORTXT       h.optext->t
 #define INCOUNT     ORTXT.inlist->count
-#define OUTCOUNT    ORTXT.outlist->count
+#define OUTCOUNT    ORTXT.outlist->count   /* Not used */
 #define INOCOUNT    ORTXT.inoffs->count
 #define OUTOCOUNT   ORTXT.outoffs->count
 #define XINCODE     ORTXT.xincod
@@ -92,17 +128,14 @@ extern "C" {
 #define LOMASK     1023
 
 #define SSTRCOD    3945467
+#define SSTRCOD1   3945466
+#define SSTRCOD2   3945465
+#define SSTRCOD3   3945464
 #define SSTRSIZ    200
 #define ALLCHNLS   0x7fff
-#ifdef OLPC
-#define DFLT_SR    FL(16000.0)
-#define DFLT_KR    FL(160.0)
-#define DFLT_KSMPS 100
-#else
 #define DFLT_SR    FL(44100.0)
 #define DFLT_KR    FL(4410.0)
 #define DFLT_KSMPS 10
-#endif
 #define DFLT_NCHNLS 1
 #define MAXCHNLS   256
 
@@ -123,6 +156,7 @@ extern "C" {
 #define TWOPI   (6.283185307179586476925286766559005768394)
 #define PI_F    ((MYFLT) PI)
 #define TWOPI_F ((MYFLT) TWOPI)
+#define INF     (2147483647.0)
 
 #define AMPLMSG 01
 #define RNGEMSG 02
@@ -161,6 +195,7 @@ extern "C" {
     int     useCsdLineCounts;
 #ifdef ENABLE_NEW_PARSER
     int     newParser; /* SYY - July 30, 2006: for --new-parser */
+    int     calculateWeights;
 #endif
   } OPARMS;
 
@@ -223,6 +258,7 @@ extern "C" {
     MYFLT   cpuload;                /* % load this instrumemnt makes */
     struct opcodinfo *opcode_info;  /* IV - Nov 10 2002 */
     char    *insname;               /* instrument name */
+    int     instcnt;                /* Count number of instances ever */
   } INSTRTXT;
 
   /**
@@ -444,6 +480,7 @@ extern "C" {
       MYFLT   *extra;
       MYFLT   p[2];
     } c;
+    char    estrarg[3];         /* Extra strings */
   } EVTBLK;
 
   typedef struct {
@@ -693,8 +730,7 @@ extern const uint32_t csPlayScoMask;
    * Contains all function pointers, data, and data pointers required
    * to run one instance of Csound.
    */
-  /* Eventually this will be changed to inchnls -- JPff */
-#define nchnls_i nchnls
+
   struct CSOUND_ {
     /* Csound API function pointers (320 total) */
     int (*GetVersion)(void);
@@ -823,7 +859,7 @@ extern const uint32_t csPlayScoMask;
     FUNC *(*FTFindP)(CSOUND *, MYFLT *argp);
     FUNC *(*FTnp2Find)(CSOUND *, MYFLT *argp);
     int (*GetTable)(CSOUND *, MYFLT **tablePtr, int tableNum);
-    SNDMEMFILE *(*LoadSoundFile)(CSOUND *, const char *, SF_INFO *);
+    SNDMEMFILE *(*LoadSoundFile)(CSOUND *, const char *, void *);
     char *(*getstrformat)(int format);
     int (*sfsampsize)(int format);
     char *(*type2string)(int type);
@@ -831,7 +867,7 @@ extern const uint32_t csPlayScoMask;
                          char *, void *, MYFLT *, MYFLT *, MYFLT *, int);
     void *(*sndgetset)(CSOUND *, void *);
     int (*getsndin)(CSOUND *, void *, MYFLT *, int, void *);
-    void (*rewriteheader)(SNDFILE *ofd);
+    void (*rewriteheader)(void *ofd);
     int (*Rand31)(int *seedVal);
     void (*FDRecord)(CSOUND *, FDCH *fdchp);
     void (*FDClose)(CSOUND *, FDCH *fdchp);
@@ -991,8 +1027,10 @@ extern const uint32_t csPlayScoMask;
     MYFLT (*ChanOKGetValue)(CSOUND *, int channel);
     int (*ChanIASetSample)(CSOUND *, int channel, int frame, MYFLT sample);
     MYFLT (*ChanOAGetSample)(CSOUND *, int channel, int frame);
+    void (*Stop)(CSOUND *);
+    void *(*GetNamedGens)(CSOUND *);
  /* SUBR dummyfn_1; */
-    SUBR dummyfn_2[78];
+    SUBR dummyfn_2[76];
     int           dither_output;
     void          *flgraphGlobals;
     char          *delayederrormessages;
@@ -1020,7 +1058,11 @@ extern const uint32_t csPlayScoMask;
     double        curBeat, curBeat_inc;
     /** beat time = 60 / tempo           */
     long          ibeatTime;   /* Beat time in samples */
+#if defined(HAVE_PTHREAD_SPIN_LOCK) && defined(PARCS)
+    pthread_spinlock_t spoutlock, spinlock;
+#else
     int           spoutlock, spinlock;
+#endif
     /* Widgets */
     void          *widgetGlobals;
     /** reserved for std opcode library  */
@@ -1053,9 +1095,13 @@ extern const uint32_t csPlayScoMask;
     CsoundRandMTState *csRandState;
     int           randSeed1;
     int           randSeed2;
+#if defined(HAVE_PTHREAD_SPIN_LOCK) && defined(PARCS)
+    pthread_spinlock_t memlock;
+#else
     int           memlock;
+#endif
     int           floatsize;
-    int           inchnls;      /* Not used yet -- JPff */
+    int           inchnls;      /* Not fully used yet -- JPff */
     int   dummyint[7];
     long  dummyint32[10];
     /* ------- private data (not to be used by hosts or externals) ------- */
@@ -1277,6 +1323,14 @@ extern const uint32_t csPlayScoMask;
     THREADINFO    *multiThreadedThreadInfo;
     INSDS         *multiThreadedStart;
     INSDS         *multiThreadedEnd;
+#ifdef PARCS
+    char                *weight_info;
+    char                *weight_dump;
+    char                *weights;
+    struct dag_t        *multiThreadedDag;
+    pthread_barrier_t   *barrier1;
+    pthread_barrier_t   *barrier2;
+#endif
     uint32_t      tempStatus;    /* keeps track of which files are temps */
     int           orcLineOffset; /* 1 less than 1st orch line in the CSD */
     int           scoLineOffset; /* 1 less than 1st score line in the CSD */
@@ -1284,6 +1338,11 @@ extern const uint32_t csPlayScoMask;
     int           parserUdoflag;
     int           parserNamedInstrFlag;
     int           tran_nchnlsi;
+    int           scnt0;        /* Count of extra strings */
+    char          *sstrbuf0[3]; /* For extra strings in scores */
+    int           sstrlen0[3];  /* lengths for extra strings */
+    int           genlabs;      /* Count for generated labels */
+
 #endif  /* __BUILDING_LIBCSOUND */
   };
 
