@@ -55,6 +55,9 @@
 #include "bus.h"
 #include "pstream.h"
 #include "remote.h"
+#ifdef PARCS
+#include "cs_par_ops.h"
+#endif
 
 #define S(x)    sizeof(x)
 
@@ -62,6 +65,9 @@ int     ihold(CSOUND *, void *), turnoff(CSOUND *, void *);
 int     assign(CSOUND *, void *), rassign(CSOUND *, void *);
 int     aassign(CSOUND *, void *);
 int     init(CSOUND *, void *), ainit(CSOUND *, void *);
+int     minit(CSOUND *, void *), mainit(CSOUND *, void *);
+int     tinit(CSOUND *, void *), tassign(CSOUND *, void *);
+int     tabref_check(CSOUND *, void *), tabref(CSOUND *, void *);
 int     gt(CSOUND *, void *), ge(CSOUND *, void *);
 int     lt(CSOUND *, void *), le(CSOUND *, void *);
 int     eq(CSOUND *, void *), ne(CSOUND *, void *);
@@ -90,6 +96,8 @@ int     rnd1(CSOUND *, void *), birnd1(CSOUND *, void *);
 int     abs1(CSOUND *, void *), exp01(CSOUND *, void *);
 int     log01(CSOUND *, void *), sqrt1(CSOUND *, void *);
 int     sin1(CSOUND *, void *), cos1(CSOUND *, void *);
+int     is_NaN(CSOUND *, void *), is_NaNa(CSOUND *, void *);
+int     is_inf(CSOUND *, void *), is_infa(CSOUND *, void *);
 int     tan1(CSOUND *, void *), asin1(CSOUND *, void *);
 int     acos1(CSOUND *, void *), atan1(CSOUND *, void *);
 int     sinh1(CSOUND *, void *), cosh1(CSOUND *, void *);
@@ -106,7 +114,7 @@ int     dbamp(CSOUND *, void *), ampdb(CSOUND *, void *);
 int     aampdb(CSOUND *, void *), dbfsamp(CSOUND *, void *);
 int     ampdbfs(CSOUND *, void *), aampdbfs(CSOUND *, void *);
 int     ftlen(CSOUND *, void *), ftlptim(CSOUND *, void *);
-int     ftchnls(CSOUND *, void *), rtclock(CSOUND *, void *);
+int     ftchnls(CSOUND *, void *), ftcps(CSOUND *, void *), rtclock(CSOUND *, void *);
 int     cpsoct(CSOUND *, void *), octpch(CSOUND *, void *);
 int     cpspch(CSOUND *, void *), pchoct(CSOUND *, void *);
 int     octcps(CSOUND *, void *), acpsoct(CSOUND *, void *);
@@ -243,6 +251,7 @@ int     krdset(CSOUND *, void *), krd2set(CSOUND *, void *);
 int     krd3set(CSOUND *, void *), krd4set(CSOUND *, void *);
 int     kread(CSOUND *, void *), kread2(CSOUND *, void *);
 int     kread3(CSOUND *, void *), kread4(CSOUND *, void *);
+int     krdsset(CSOUND *, void *), kreads(CSOUND *, void *);
 int     ipow(CSOUND *, void *), apow(CSOUND *, void *);
 int     alinear(CSOUND *, void *), iklinear(CSOUND *, void *);
 int     atrian(CSOUND *, void *), iktrian(CSOUND *, void *);
@@ -290,6 +299,7 @@ int     nestedapset(CSOUND *, void *), nestedap(CSOUND *, void *);
 int     lorenzset(CSOUND *, void *), lorenz(CSOUND *, void *);
 int     filelen(CSOUND *, void *), filenchnls(CSOUND *, void *);
 int     filesr(CSOUND *, void *), filepeak(CSOUND *, void *);
+int     filevalid(CSOUND *, void *);
 int     ilogbasetwo(CSOUND *, void *), logbasetwo_set(CSOUND *, void *);
 int     powoftwo(CSOUND *, void *), powoftwoa(CSOUND *, void *);
 int     logbasetwo(CSOUND *, void *), logbasetwoa(CSOUND *, void *);
@@ -370,4 +380,15 @@ int     delete_instr(CSOUND *, void *);
 int     insremot(CSOUND *, void *), insglobal(CSOUND *, void *);
 int     midremot(CSOUND *, void *), midglobal(CSOUND *, void *);
 int     remoteport(CSOUND *, void *);
-int filebit(CSOUND *, void *);
+int     globallock(CSOUND *, void *);
+int     globalunlock(CSOUND *, void *);
+int     filebit(CSOUND *, void *);
+int     iexprndi(CSOUND *, void *), exprndiset(CSOUND *, void *);
+int     kexprndi(CSOUND *, void *), aexprndi(CSOUND *, void *);
+int     icauchyi(CSOUND *, void *), cauchyiset(CSOUND *, void *);
+int     kcauchyi(CSOUND *, void *), acauchyi(CSOUND *, void *);
+int     igaussi(CSOUND *, void *), gaussiset(CSOUND *, void *);
+int     kgaussi(CSOUND *, void *), agaussi(CSOUND *, void *);
+int     lsgset_bkpt(CSOUND *csound, void *p);
+int     xsgset_bkpt(CSOUND *csound, void *p);
+int     xsgset_bkpt(CSOUND *csound, void *p), xsgset2b(CSOUND *, void *);
