@@ -25,26 +25,34 @@
 #define CSOUND_VERSION_H
 
 /* Define to the full name of this package. */
+#ifndef PARCS
 #define CS_PACKAGE_NAME     "Csound"
+#else /* PARCS */
+#define CS_PACKAGE_NAME     "ParCsound"
+#endif /* PARCS */
 
 /* Define to the full name and version of this package. */
-#define CS_PACKAGE_STRING   "Csound 5.12"
+#ifndef PARCS
+#define CS_PACKAGE_STRING   "Csound 5.14"
+#else /* PARCS */
+#define CS_PACKAGE_STRING   "ParCsound 5.14"
+#endif /* PARCS */
 
 /* Define to the one symbol short name of this package. */
 #define CS_PACKAGE_TARNAME  "csound"
 
 /* Define to the version of this package. */
-#define CS_PACKAGE_VERSION  "5.12"
+#define CS_PACKAGE_VERSION  "5.14"
 #define CS_VERSION          (5)
-#define CS_SUBVER           (12)
-#define CS_PATCHLEVEL       (1)
+#define CS_SUBVER           (14)
+#define CS_PATCHLEVEL       (2)
 
 #define CS_APIVERSION       2   /* should be increased anytime a new version
                                    contains changes that an older host will
                                    not be able to handle -- most likely this
                                    will be a change to an API function or
                                    the CSOUND struct */
-#define CS_APISUBVER        4   /* for minor changes that will still allow
+#define CS_APISUBVER        5   /* for minor changes that will still allow
                                    compatiblity with older hosts */
 
 #endif /* CSOUND_VERSION_H */
