@@ -177,15 +177,14 @@ static void writesf(CSOUND *csound, const MYFLT *outbuf, int nbytes)
     OPARMS  *O = csound->oparms;
     int     n;
 
-    if (ST(outfile) == NULL)
+    if (UNLIKELY(ST(outfile) == NULL))
       return;
     n = (int) sf_write_MYFLT(ST(outfile), (MYFLT*) outbuf,
                              nbytes / sizeof(MYFLT)) * (int) sizeof(MYFLT);
     if (UNLIKELY(n < nbytes))
       sndwrterr(csound, n, nbytes);
-#ifndef OLPC
-    if (O->rewrt_hdr)
-      rewriteheader(ST(outfile));
+    if (UNLIKELY(O->rewrt_hdr))
+      rewriteheader((void *)ST(outfile));
     switch (O->heartbeat) {
       case 1:
         csound->MessageS(csound, CSOUNDMSG_REALTIME,
@@ -210,7 +209,6 @@ static void writesf(CSOUND *csound, const MYFLT *outbuf, int nbytes)
         csound->MessageS(csound, CSOUNDMSG_REALTIME, "\a");
         break;
     }
-#endif
 }
 
 static void writesf_dither_16(CSOUND *csound, const MYFLT *outbuf, int nbytes)
@@ -220,7 +218,7 @@ static void writesf_dither_16(CSOUND *csound, const MYFLT *outbuf, int nbytes)
     int m = nbytes / sizeof(MYFLT);
     MYFLT *buf = (MYFLT*) outbuf;
 
-    if (ST(outfile) == NULL)
+    if (UNLIKELY(ST(outfile) == NULL))
       return;
 
     for (n=0; n<m; n++) {
@@ -237,7 +235,6 @@ static void writesf_dither_16(CSOUND *csound, const MYFLT *outbuf, int nbytes)
                              nbytes / sizeof(MYFLT)) * (int) sizeof(MYFLT);
     if (UNLIKELY(n < nbytes))
       sndwrterr(csound, n, nbytes);
-#ifndef OLPC
     if (UNLIKELY(O->rewrt_hdr))
       rewriteheader(ST(outfile));
     switch (O->heartbeat) {
@@ -264,7 +261,6 @@ static void writesf_dither_16(CSOUND *csound, const MYFLT *outbuf, int nbytes)
         csound->MessageS(csound, CSOUNDMSG_REALTIME, "\a");
         break;
     }
-#endif
 }
 
 static void writesf_dither_8(CSOUND *csound, const MYFLT *outbuf, int nbytes)
@@ -274,7 +270,7 @@ static void writesf_dither_8(CSOUND *csound, const MYFLT *outbuf, int nbytes)
     int m = nbytes / sizeof(MYFLT);
     MYFLT *buf = (MYFLT*) outbuf;
 
-    if (ST(outfile) == NULL)
+    if (UNLIKELY(ST(outfile) == NULL))
       return;
 
     for (n=0; n<m; n++) {
@@ -291,7 +287,6 @@ static void writesf_dither_8(CSOUND *csound, const MYFLT *outbuf, int nbytes)
                              nbytes / sizeof(MYFLT)) * (int) sizeof(MYFLT);
     if (UNLIKELY(n < nbytes))
       sndwrterr(csound, n, nbytes);
-#ifndef OLPC
     if (UNLIKELY(O->rewrt_hdr))
       rewriteheader(ST(outfile));
     switch (O->heartbeat) {
@@ -318,7 +313,6 @@ static void writesf_dither_8(CSOUND *csound, const MYFLT *outbuf, int nbytes)
         csound->MessageS(csound, CSOUNDMSG_REALTIME, "\a");
         break;
     }
-#endif
 }
 
 static void writesf_dither_u16(CSOUND *csound, const MYFLT *outbuf, int nbytes)
@@ -328,7 +322,7 @@ static void writesf_dither_u16(CSOUND *csound, const MYFLT *outbuf, int nbytes)
     int m = nbytes / sizeof(MYFLT);
     MYFLT *buf = (MYFLT*) outbuf;
 
-    if (ST(outfile) == NULL)
+    if (UNLIKELY(ST(outfile) == NULL))
       return;
 
     for (n=0; n<m; n++) {
@@ -343,7 +337,6 @@ static void writesf_dither_u16(CSOUND *csound, const MYFLT *outbuf, int nbytes)
                              nbytes / sizeof(MYFLT)) * (int) sizeof(MYFLT);
     if (UNLIKELY(n < nbytes))
       sndwrterr(csound, n, nbytes);
-#ifndef OLPC
     if (UNLIKELY(O->rewrt_hdr))
       rewriteheader(ST(outfile));
     switch (O->heartbeat) {
@@ -370,7 +363,6 @@ static void writesf_dither_u16(CSOUND *csound, const MYFLT *outbuf, int nbytes)
         csound->MessageS(csound, CSOUNDMSG_REALTIME, "\a");
         break;
     }
-#endif
 }
 
 static void writesf_dither_u8(CSOUND *csound, const MYFLT *outbuf, int nbytes)
@@ -380,7 +372,7 @@ static void writesf_dither_u8(CSOUND *csound, const MYFLT *outbuf, int nbytes)
     int m = nbytes / sizeof(MYFLT);
     MYFLT *buf = (MYFLT*) outbuf;
 
-    if (ST(outfile) == NULL)
+    if (UNLIKELY(ST(outfile) == NULL))
       return;
 
     for (n=0; n<m; n++) {
@@ -395,7 +387,6 @@ static void writesf_dither_u8(CSOUND *csound, const MYFLT *outbuf, int nbytes)
                              nbytes / sizeof(MYFLT)) * (int) sizeof(MYFLT);
     if (UNLIKELY(n < nbytes))
       sndwrterr(csound, n, nbytes);
-#ifndef OLPC
     if (UNLIKELY(O->rewrt_hdr))
       rewriteheader(ST(outfile));
     switch (O->heartbeat) {
@@ -422,7 +413,6 @@ static void writesf_dither_u8(CSOUND *csound, const MYFLT *outbuf, int nbytes)
         csound->MessageS(csound, CSOUNDMSG_REALTIME, "\a");
         break;
     }
-#endif
 }
 
 static int readsf(CSOUND *csound, MYFLT *inbuf, int inbufsize)
@@ -432,8 +422,8 @@ static int readsf(CSOUND *csound, MYFLT *inbuf, int inbufsize)
     (void) csound;
     n = inbufsize / (int) sizeof(MYFLT);
     i = (int) sf_read_MYFLT(ST(infile), inbuf, n);
-    if (i < 0)
-      i = 0;
+    if (UNLIKELY(i < 0))
+      return inbufsize;
     memset(&inbuf[i], 0, (n-i)*sizeof(MYFLT));
     /* while (i < n) */
     /*   inbuf[i++] = FL(0.0); */
@@ -511,7 +501,7 @@ void sfopenin(CSOUND *csound)           /* init for continuous soundin */
       parm.devNum = check_rtaudio_name(sfname, &(parm.devName), 0);
       if (parm.devNum >= 0) {
         /* set device parameters */
-        parm.bufSamp_SW = (int) O->inbufsamps / (int) csound->nchnls;
+        parm.bufSamp_SW = (int) O->inbufsamps / (int) csound->inchnls;
         parm.bufSamp_HW = O->oMaxLag;
         parm.nChannels = csound->nchnls;
         parm.sampleFormat = O->informat;
@@ -561,9 +551,9 @@ void sfopenin(CSOUND *csound)           /* init for continuous soundin */
                               sfname, (int) sfinfo.samplerate,
                               (int) (csound->esr + FL(0.5)));
     }
-    if (sfinfo.channels != csound->nchnls) {
-      csound->Warning(csound, Str("audio_in %s has %d chnls, orch %d chnls"),
-                              sfname, (int) sfinfo.channels, csound->nchnls);
+    if (sfinfo.channels != csound->inchnls) {
+      csound->Warning(csound, Str("audio_in %s has %d chnls, orch %d chnls_i"),
+                              sfname, (int) sfinfo.channels, csound->inchnls);
     }
     /* Do we care about the format?  Can assume float?? */
     O->informat = SF2FORMAT(sfinfo.format);
