@@ -727,11 +727,11 @@ static int midi_in_open(CSOUND *csound, void **userData, const char *devName)
               }
               if (device < 0) {
                 break;
-	      }
+              }
               sprintf(name, "hw:%d,%d", card, device);
               newdev = open_midi_device(csound, name);
               if (newdev != NULL) {   /* Device opened successfully */
-		numdevs++;
+                numdevs++;
                 if (olddev != NULL) {
                   olddev->next = newdev;
                 }
@@ -761,6 +761,7 @@ static int midi_in_open(CSOUND *csound, void **userData, const char *devName)
         free(name);
         return -1;
       }
+      numdevs = 1;
     }
     free(name);
     if (numdevs == 0) {
@@ -1125,7 +1126,7 @@ PUBLIC int csoundModuleInit(CSOUND *csound)
     cfg = csound->QueryConfigurationVariable(csound, "rtscheduler");
     priority = *(cfg->i.p);
 
-    if(priority != 0) set_scheduler_priority(csound, priority);
+    if (priority != 0) set_scheduler_priority(csound, priority);
 
     csound->DeleteConfigurationVariable(csound, "rtscheduler");
     csound->DestroyGlobalVariable(csound, "::priority");
