@@ -34,7 +34,7 @@
 #define ONEdLOG2    FL(1.4426950408889634074)
 #define MIDINOTE0   (3.00)  /* Lowest midi note is 3.00 in oct & pch formats */
 
-/* static lookup tables, initialised once at start-up */
+/* static lookup tables, initialised once at start-up; also used by midi ops */
 MYFLT   cpsocfrc[OCTRES] = { FL(0.0) };
 static  MYFLT   powerof2[4096];
 
@@ -75,12 +75,6 @@ int aassign(CSOUND *csound, ASSIGN *p)
     return OK;
 }
 
-int init(CSOUND *csound, ASSIGN *p)
-{
-    *p->r = *p->a;
-    return OK;
-}
-
 int ainit(CSOUND *csound, ASSIGN *p)
 {
     MYFLT aa = *p->a;
@@ -91,9 +85,121 @@ int ainit(CSOUND *csound, ASSIGN *p)
     return OK;
 }
 
+int minit(CSOUND *csound, ASSIGNM *p)
+{
+    int nargs = p->INCOUNT;
+    int i;
+    MYFLT *tmp;
+    if (UNLIKELY(nargs > p->OUTOCOUNT))
+      return csound->InitError(csound,
+                               Str("Cannot be more In arguments than Out in "
+                                   "init (%d,%d)"),p->OUTOCOUNT, nargs);
+    if (p->OUTOCOUNT==1) {
+      *p->r[0] =  *p->a[0];
+      return OK;
+    }
+    tmp = (MYFLT*)malloc(sizeof(MYFLT)*p->OUTOCOUNT);
+    for (i=0; i<nargs; i++)
+      tmp[i] =  *p->a[i];
+    for (; i<p->OUTOCOUNT; i++)
+      tmp[i] =  *p->a[nargs-1];
+    for (i=0; i<p->OUTOCOUNT; i++)
+      *p->r[i] = tmp[i];
+    free(tmp);
+    return OK;
+}
+
+int mainit(CSOUND *csound, ASSIGNM *p)
+{
+    int nargs = p->INCOUNT;
+    int   i, n, nsmps = csound->ksmps;
+    MYFLT aa = FL(0.0);
+    if (UNLIKELY(nargs > p->OUTOCOUNT))
+      return csound->InitError(csound,
+                               Str("Cannot be more In arguments than Out in "
+                                   "init (%d,%d)"),p->OUTOCOUNT, nargs);
+    for (i=0; i<nargs; i++) {
+      aa = *p->a[i];
+      MYFLT *r =p->r[i];
+      for (n = 0; n < nsmps; n++)
+        r[n] = aa;
+    }
+    for (; i<p->OUTOCOUNT; i++) {
+      MYFLT *r =p->r[i];
+      for (n = 0; n < nsmps; n++)
+        r[n] = aa;
+    }
+
+    return OK;
+}
+
+typedef struct {
+    OPDS    h;
+    TABDAT  *tab;
+} TABDEL;
+  
+static int tabdel(CSOUND *csound, void *p)
+{
+    TABDAT *t = ((TABDEL*)p)->tab;
+    mfree(csound, t->data);
+    mfree(csound, p);
+    return OK;
+}
+
+int tinit(CSOUND *csound, INITT *p)
+{
+    int size = MYFLT2LRND(*p->size);
+    MYFLT val = *p->value;
+    TABDAT *t = p->a;
+    int i;
+ 
+    t->size = size;
+    mfree(csound, t->data);
+    t->data = mmalloc(csound, sizeof(MYFLT)*(size+1));
+    for (i=0; i<=size; i++) t->data[i] = val;
+    { // Need to recover space eventually
+      TABDEL *op = (TABDEL*) mmalloc(csound, sizeof(TABDEL));
+      op->h.insdshead = ((OPDS*) p)->insdshead;
+      op->tab = t;
+      csound->RegisterDeinitCallback(csound, op, tabdel);
+    }
+    return OK;
+}
+
+int tassign(CSOUND *csound, ASSIGNT *p)
+{
+    TABDAT *t = p->tab;
+    int ind = MYFLT2LRND(*p->ind);
+    if (ind<0 || ind>t->size) 
+      return csound->PerfError(csound,
+                               Str("Index %d out of range [0,%d] in t[]\n"),
+                               ind, t->size);
+    t->data[ind] = *p->val;
+    return OK;
+}
+
+int tabref_check(CSOUND *csound, TABREF *p)
+{
+    if (UNLIKELY(p->tab->data==NULL))
+      return csound->InitError(csound, Str("Vector notinitialised\n"));
+    return OK;
+}
+
+int tabref(CSOUND *csound, TABREF *p)
+{
+    int ind = MYFLT2LRND(*p->ind);
+    TABDAT *t = p->tab;
+     if (ind<0 || ind>t->size) 
+      return csound->PerfError(csound,
+                               Str("Index %d out of range [0,%d] in t[]\n"),
+                               ind, t->size);
+     *p->ans = t->data[ind];
+     return OK;
+}
+
 #define RELATN(OPNAME,OP)                               \
   int OPNAME(CSOUND *csound, RELAT *p)                  \
-  { *p->rbool = (*p->a OP *p->b) ? 1 : 0; return OK; }
+  { *p->rbool = (*p->a OP *p->b) ? 1 : 0;  return OK; }
 
 RELATN(gt,>)
 RELATN(ge,>=)
@@ -119,7 +225,7 @@ KK(divkk,/)
 
 MYFLT MOD(MYFLT a, MYFLT bb)
 {
-    if (bb==FL(0.0)) return FL(0.0);
+    if (UNLIKELY(bb==FL(0.0))) return FL(0.0);
     else {
       MYFLT b = (bb<0 ? -bb : bb);
       MYFLT d = FMOD(a, b);
@@ -551,6 +657,22 @@ int ftchnls(CSOUND *csound, EVAL *p)
     return OK;
 }
 
+int ftcps(CSOUND *csound, EVAL *p)
+{
+    FUNC    *ftp;
+
+    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->a)) == NULL)
+        || ftp->cpscvt == FL(0.0)) {
+      *p->r = -FL(1.0);       /* Return something */
+      return NOTOK;
+    }
+    *p->r = (MYFLT)(ftp->cvtbas/ftp->cpscvt);
+
+    return OK;
+}
+
+
+
 int ftlptim(CSOUND *csound, EVAL *p)
 {
     FUNC    *ftp;
@@ -755,7 +877,7 @@ int cpstun_i(CSOUND *csound, CPSTUNI *p)
     int numgrades;
     int basekeymidi;
     MYFLT basefreq, factor, interval;
-    if ((ftp = csound->FTnp2Find(csound, p->tablenum)) == NULL) goto err1;
+    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->tablenum)) == NULL)) goto err1;
     func = ftp->ftable;
     numgrades = (int)*func++;
     interval = *func++;
@@ -789,7 +911,8 @@ int cpstun(CSOUND *csound, CPSTUN *p)
       int numgrades;
       int basekeymidi;
       MYFLT basefreq, factor, interval;
-      if ((ftp = csound->FTnp2Find(csound, p->tablenum)) == NULL) goto err1;
+      if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->tablenum)) == NULL))
+        goto err1;
       func = ftp->ftable;
       numgrades = (int)*func++;
       interval = *func++;
@@ -818,7 +941,7 @@ int cpstun(CSOUND *csound, CPSTUN *p)
 
 int logbasetwo_set(CSOUND *csound, EVAL *p)
 {
-    if (csound->logbase2 == NULL) {
+    if (UNLIKELY(csound->logbase2 == NULL)) {
       double  x = (1.0 / INTERVAL);
       int     i;
       csound->logbase2 = (MYFLT*) csound->Malloc(csound, (STEPS + 1)
@@ -972,7 +1095,6 @@ int ins(CSOUND *csound, INS *p)
     return OK;
 }
 
-#ifndef OLPC
 int inq(CSOUND *csound, INQ *p)
 {
     MYFLT       *sp = csound->spin, *ar1 = p->ar1, *ar2 = p->ar2,
@@ -1055,28 +1177,55 @@ int in32(CSOUND *csound, INALL *p)
 {
     return inn(csound, p, 32);
 }
-#endif
 
 int inch_opcode(CSOUND *csound, INCH *p)
-{
-    int   ch = (int)(*p->ch + FL(0.5));
-    int   n;
-    int   nsmps = csound->ksmps;
-    MYFLT *sp = csound->spin + (ch - 1);
-    MYFLT *ain = p->ar;
-    CSOUND_SPIN_SPINLOCK
-    if (UNLIKELY(ch > csound->nchnls_i)) {
-      CSOUND_SPIN_SPINUNLOCK
-      return NOTOK;
+{                               /* Rewritten to allow multiple args upto 40 */
+    int nc, nChannels = p->INCOUNT;
+    int   ch, n, nsmps = csound->ksmps;
+    MYFLT *sp, *ain;
+    if (UNLIKELY(nChannels != p->OUTOCOUNT))
+      return
+        csound->PerfError(csound,
+                          Str("Input and output argument count differs in inch"));
+    for (nc=0; nc<nChannels; nc++) {
+      ch = (int)(*p->ch[nc] + FL(0.5));
+      if (UNLIKELY(ch > csound->inchnls)) {
+        csound->Message(csound, Str("Input channel %d too large; ignored"), ch);
+        memset(p->ar[nc], 0, sizeof(MYFLT)*nsmps);
+        //        return OK;
+      }
+      else {
+        sp = csound->spin + (ch - 1);
+        ain = p->ar[nc];
+        for (n = 0; n < nsmps; n++) {
+          ain[n] = *sp;
+          sp += csound->inchnls;
+        }
+      }
     }
-    for (n = 0; n < nsmps; n++) {
-      ain[n] = *sp;
-      sp += csound->nchnls_i;
-    }
-    CSOUND_SPIN_SPINUNLOCK
     return OK;
 }
 
+/* int inch_opcode(CSOUND *csound, INCH *p) */
+/* { */
+/*     int   ch = (int)(*p->ch + FL(0.5)); */
+/*     int   n; */
+/*     int   nsmps = csound->ksmps; */
+/*     MYFLT *sp = csound->spin + (ch - 1); */
+/*     MYFLT *ain = p->ar; */
+/*     if (UNLIKELY(ch > csound->inchnls)) { */
+/*       return NOTOK; */
+/*     } */
+/*     /\* Are APINLOCKS really necessary for reading?? *\/ */
+/*     CSOUND_SPIN_SPINLOCK */
+/*     for (n = 0; n < nsmps; n++) { */
+/*       ain[n] = *sp; */
+/*       sp += csound->inchnls; */
+/*     } */
+/*     CSOUND_SPIN_SPINUNLOCK */
+/*     return OK; */
+/* } */
+
 int inall_opcode(CSOUND *csound, INALL *p)
 {
     int   n = (int)p->OUTOCOUNT;
@@ -1084,14 +1233,14 @@ int inall_opcode(CSOUND *csound, INALL *p)
     int   i, j = 0, k = 0, nsmps = csound->ksmps;
     MYFLT *spin = csound->spin;
     CSOUND_SPIN_SPINLOCK
-    m = (n < csound->nchnls_i ? n : csound->nchnls_i);
+    m = (n < csound->inchnls ? n : csound->inchnls);
     for (j=0; j<nsmps; j++) {
       for (i=0; i<m; i++) {
         p->ar[i][j] = spin[k + i];
       }
       for ( ; i < n; i++)
         p->ar[i][j] = FL(0.0);
-      k += csound->nchnls_i;
+      k += csound->inchnls;
     }
     CSOUND_SPIN_SPINUNLOCK
     return OK;
@@ -1139,7 +1288,6 @@ int outs(CSOUND *csound, OUTS *p)
     return OK;
 }
 
-#ifndef OLPC
 int outq(CSOUND *csound, OUTQ *p)
 {
     MYFLT       *sp= csound->spout, *ap1= p->asig1, *ap2= p->asig2,
@@ -1169,7 +1317,6 @@ int outq(CSOUND *csound, OUTQ *p)
     CSOUND_SPOUT_SPINUNLOCK
     return OK;
 }
-#endif
 
 int outs1(CSOUND *csound, OUTM *p)
 {
@@ -1241,7 +1388,6 @@ int outs12(CSOUND *csound, OUTM *p)
     return OK;
 }
 
-#ifndef OLPC
 int outq1(CSOUND *csound, OUTM *p)
 {
     MYFLT       *sp = csound->spout, *ap1 = p->asig;
@@ -1412,7 +1558,6 @@ int outo(CSOUND *csound, OUTO *p)
     CSOUND_SPOUT_SPINUNLOCK
     return OK;
 }
-#endif
 
 static int outn(CSOUND *csound, int n, OUTX *p)
 {
@@ -1443,7 +1588,6 @@ static int outn(CSOUND *csound, int n, OUTX *p)
     return OK;
 }
 
-#ifndef OLPC
 int outx(CSOUND *csound, OUTX *p)
 {
     return outn(csound, 16, p);
@@ -1453,7 +1597,6 @@ int outX(CSOUND *csound, OUTX *p)
 {
     return outn(csound, 32, p);
 }
-#endif
 
 int outall(CSOUND *csound, OUTX *p)             /* Output a list of channels */
 {
@@ -1520,7 +1663,7 @@ int invalset(CSOUND *csound, INVAL *p)
       /* check for starting with a $, which will confuse hosts
          -- pretty unlikely given that the parser thinks
          "$string" is a macro -- but just in case: */
-      if (*s == '$')
+      if (UNLIKELY(*s == '$'))
         return csound->InitError(csound, Str("k-rate invalue ChannelName "
                                              "cannot start with $"));
       /* allocate the space used to pass a string during the k-pass */
@@ -1619,3 +1762,39 @@ int outvalset(CSOUND *csound, OUTVAL *p)
     return OK;
 }
 
+int is_NaN(CSOUND *csound, ASSIGN *p)
+{
+    *p->r = isnan(*p->a);
+    return OK;
+}
+
+int is_NaNa(CSOUND *csound, ASSIGN *p)
+{
+    int k, nsmps = csound->ksmps;
+    MYFLT *a = p->a;
+    *p->r = FL(0.0);
+    for (k=0; k<nsmps; k++) 
+      *p->r += isnan(a[k]);
+    return OK;
+}
+
+int is_inf(CSOUND *csound, ASSIGN *p)
+{
+    *p->r = isinf(*p->a);
+    return OK;
+}
+
+int is_infa(CSOUND *csound, ASSIGN *p)
+{
+    int k, nsmps = csound->ksmps;
+    MYFLT *a = p->a;
+    MYFLT ans = FL(0.0);
+    int sign = 1;
+    for (k=0; k<nsmps; k++) {
+      if (isinf(a[k]))
+        if (ans==FL(0.0)) sign = (int)isinf(a[k]);
+      ans++;
+    }
+    *p->r = ans*sign;
+    return OK;
+}
