@@ -104,12 +104,18 @@ typedef struct {
     void    *nxt;               /* pointer to next opcode on the same port */
 } OSCLISTEN;
 
+static int oscsend_deinit(CSOUND *csound, OSCSEND *p)
+{
+    lo_address a = (lo_address)p->addr;
+    lo_address_free(a);
+    return OK;
+}
+
 static int osc_send_set(CSOUND *csound, OSCSEND *p)
 {
     char port[8];
     char *pp = port;
     char *hh;
-    lo_address t;
 
     /* with too many args, XINCODE/XSTRCODE may not work correctly */
     if (UNLIKELY(p->INOCOUNT > 31))
@@ -124,10 +130,11 @@ static int osc_send_set(CSOUND *csound, OSCSEND *p)
       sprintf(port, "%d", (int) MYFLT2LRND(*p->port));
     hh = (char*) p->host;
     if (*hh=='\0') hh = NULL;
-    t = lo_address_new(hh, pp);
-    p->addr = t;
+    p->addr = lo_address_new(hh, pp);
     p->cnt = 0;
     p->last = 0;
+    csound->RegisterDeinitCallback(csound, p,
+                                   (int (*)(CSOUND *, void *)) oscsend_deinit);
     return OK;
 }
 
@@ -139,6 +146,7 @@ static int osc_send(CSOUND *csound, OSCSEND *p)
        2) string
        3) double
        4) char
+       5) table as blob
     */
     if (p->cnt++ ==0 || *p->kwhen!=p->last) {
       int i=0;
@@ -213,6 +221,30 @@ static int osc_send(CSOUND *csound, OSCSEND *p)
             lo_message_add_timetag(msg, tt);
             break;
           }
+          //#ifdef SOMEFINEDAY
+        case 'T':               /* Table/blob */
+          {
+            lo_blob myblob;
+            int     len;
+            FUNC    *ftp;
+            void *data;
+            if (UNLIKELY(p->XSTRCODE&msk))
+              return csound->PerfError(csound, Str("String not expected"));
+            /* make sure fn exists */
+            if (LIKELY((ftp=csound->FTFind(csound,arg[i]))!=NULL)) {
+              data = ftp->ftable;
+              len = ftp->flen-1;        /* and set it up */
+            }
+            else {
+              return csound->PerfError(csound,
+                                       Str("ftable %.2f does not exist"), *arg[i]);
+            }
+            myblob = lo_blob_new(sizeof(MYFLT)*len, data);
+            lo_message_add_blob(msg, myblob);
+            lo_blob_free(myblob);
+            break;
+          }
+          //#endif
         default:
           csound->Warning(csound, Str("Unknown OSC type %c\n"), type[1]);
         }
@@ -543,7 +575,6 @@ static void OSC_error(int num, const char *msg, const char *path)
     fprintf(stderr, "OSC server error %d in path %s: %s\n", num, path, msg);
 }
 
-#ifdef BETA
 static int OSC_deinit(CSOUND *csound, OSCINIT *p)
 {
     int n = (int)*p->ihandle;
@@ -558,7 +589,6 @@ static int OSC_deinit(CSOUND *csound, OSCINIT *p)
     csound->Message(csound, Str("OSC deinitiatised\n"));
     return OK;
 }
-#endif
 
 static int osc_listener_init(CSOUND *csound, OSCINIT *p)
 {
@@ -582,10 +612,8 @@ static int osc_listener_init(CSOUND *csound, OSCINIT *p)
     pp->nPorts = n + 1;
     csound->Warning(csound, Str("OSC listener #%d started on port %s\n"), n, buff);
     *(p->ihandle) = (MYFLT) n;
-#ifdef BETA
     csound->RegisterDeinitCallback(csound, p,
                                    (int (*)(CSOUND *, void *)) OSC_deinit);
-#endif
     return OK;
 }
 
@@ -654,6 +682,10 @@ static int OSC_list_init(CSOUND *csound, OSCLISTEN *p)
       if (s[0] == 'g')
         s++;
       switch (p->saved_types[i]) {
+#ifdef SOMEFINEDAY
+      case 'T':
+        p->saved_types[i] = 'b';
+#endif
       case 'c':
       case 'd':
       case 'f':
