@@ -1087,7 +1087,7 @@ struct JackoAudioOut : public OpcodeBase<JackoAudioOut>
   {
     jack_default_audio_sample_t *buffer = (jack_default_audio_sample_t *)jack_port_get_buffer(csoundPort, csoundFramesPerTick);
     for (size_t frame = 0; frame < csoundFramesPerTick; ++frame) {
-      buffer[frame] += asignal[frame];
+      buffer[frame] = asignal[frame];
     }
     return OK;
   }
