@@ -75,6 +75,7 @@ typedef struct {
         OPDS    h;
         MYFLT   *cnt;
         MYFLT   *ins;
+        MYFLT   *opt;
 } INSTCNT;
 
 typedef struct {
@@ -199,7 +200,7 @@ typedef struct {
 
 typedef struct {
         OPDS    h;
-        MYFLT   *ar, *ain, *fco, *res, *dist;
+        MYFLT   *ar, *ain, *fco, *res, *dist, *istor;
         MYFLT   ay1, ay2, aout, lastin;
 } LPF18;
 
@@ -230,6 +231,20 @@ typedef struct {
         MYFLT   *pnum;
 } PFUN;
 
+typedef struct {
+        OPDS    h;
+        MYFLT   *ans;
+        MYFLT   *asig;
+        MYFLT   *kwind;
+        MYFLT   *imaxsize;
+        MYFLT   *iskip;
+        AUXCH   b;
+        MYFLT   *buff;
+        MYFLT   *med;
+        int     ind;
+        int     maxwind;
+} MEDFILT;
+
 int Foscaa(CSOUND *, XOSC *p);
 int Foscak(CSOUND *, XOSC *p);
 int Foscka(CSOUND *, XOSC *p);
@@ -251,6 +266,7 @@ int hsboscset(CSOUND *, HSBOSC *p);
 int impulse(CSOUND *, IMPULSE *p);
 int impulse_set(CSOUND *, IMPULSE *p);
 int instcount(CSOUND *, INSTCNT *p);
+int totalcount(CSOUND *, INSTCNT *p);
 int kphsorbnk(CSOUND *, PHSORBNK *p);
 int ktrnseg(CSOUND *, TRANSEG *p);
 int ktrnsegr(CSOUND *csound, TRANSEG *p);
@@ -273,10 +289,14 @@ int pitchset(CSOUND *, PITCH *p);
 int trnseg(CSOUND *, TRANSEG *p);
 int trnsegr(CSOUND *csound, TRANSEG *p);
 int trnset(CSOUND *, TRANSEG *p);
+int trnset_bkpt(CSOUND *, TRANSEG *p);
 int trnsetr(CSOUND *csound, TRANSEG *p);
 int varicol(CSOUND *, VARI *p);
 int varicolset(CSOUND *, VARI *p);
 int waveset(CSOUND *, BARRI *p);
 int wavesetset(CSOUND *, BARRI *p);
+int medfiltset(CSOUND *, MEDFILT *p);
+int medfilt(CSOUND *, MEDFILT *p);
+int kmedfilt(CSOUND *, MEDFILT *p);
 #endif /* PITCH_H */
 
