@@ -391,8 +391,8 @@ int pvcrossset(CSOUND *csound, PVCROSS *p)
     /* for (i = 0; i < pvfrsiz(p); ++i) */
     /*   p->outBuf[i] = FL(0.0); */
     MakeSinc(p->pp);                    /* sinctab is same for all instances */
-    if(p->memenv.auxp == NULL || p->memenv.size < pvdasiz(p)*sizeof(MYFLT))
-        csound->AuxAlloc(csound, pvdasiz(p) * sizeof(MYFLT), &p->memenv);
+    if (p->memenv.auxp == NULL || p->memenv.size < pvdasiz(p)*sizeof(MYFLT))
+      csound->AuxAlloc(csound, pvdasiz(p) * sizeof(MYFLT), &p->memenv);
     return OK;
 }
 
@@ -449,8 +449,10 @@ int pvcross(CSOUND *csound, PVCROSS *p)
     if (specwp == 0 || (p->prFlg)++ == -(int) specwp) {
       /* ?screws up when prFlg used */
       /* specwp=0 => normal; specwp = -n => just nth frame */
-      if (specwp < 0)
+#ifdef BETA
+     if (specwp < 0)
         csound->Message(csound, Str("PVOC debug: one frame gets through\n"));
+#endif
       if (specwp > 0)
         PreWarpSpec(p->pp, buf, asize, pex, (MYFLT *)p->memenv.auxp);
 
