@@ -48,7 +48,6 @@ void SPECset(CSOUND *p, SPECDAT *specdp, int32 npts)
       p->AuxAlloc(p, nbytes, &specdp->auxch);
     specdp->npts = npts;
 }
-#ifndef OLPC
 
 static const char *outstring[] = {"mag", "db", "mag sqrd", "root mag"};
 
@@ -101,7 +100,7 @@ int spectset(CSOUND *csound, SPECTRUM *p)
       p->curq = Q;
       p->hanning = hanning;
       p->ncoefs = ncoefs;
-      csound->Message(csound,
+      csound->Warning(csound,
                       Str("spectrum: %s window, %s out, making tables ...\n"),
                       (hanning) ? "hanning":"hamming", outstring[p->dbout]);
 
@@ -121,7 +120,7 @@ int spectset(CSOUND *csound, SPECTRUM *p)
       }
       dwnp->looct = (MYFLT)(oct - nocts);     /* true oct val of lowest frq */
       locps = hicps / (1L << nocts);
-      csound->Message(csound, Str("\thigh cps %7.1f\n\t low cps %7.1f\n"),
+      csound->Warning(csound, Str("\thigh cps %7.1f\n\t low cps %7.1f\n"),
                               hicps, locps);
 
       basfrq = hicps/2.0;                     /* oct below retuned top */
@@ -135,7 +134,7 @@ int spectset(CSOUND *csound, SPECTRUM *p)
         curfrq *= frqmlt;
       }
       windsiz = *(p->winlen);
-      csound->Message(csound,
+      csound->Warning(csound,
                       Str("\tQ %4.1f uses a %d sample window each octdown\n"),
                       Q, windsiz);
       auxsiz = (windsiz + 2*sumk) * sizeof(MYFLT);   /* calc lcl space rqd */
@@ -185,7 +184,7 @@ int spectset(CSOUND *csound, SPECTRUM *p)
         octp->begp = fltp;  fltp += bufsiz; /*        (lo oct first) */
         octp->endp = fltp;  minr *= 2;
       }
-      csound->Message(csound, Str("\t%d oct analysis window "
+      csound->Warning(csound, Str("\t%d oct analysis window "
                                   "delay = %ld samples (%d msecs)\n"),
                               nocts, bufsiz, (int)(bufsiz*1000/dwnp->srate));
       if (p->disprd) {                      /* if display requested, */
@@ -346,7 +345,6 @@ int spectrum(CSOUND *csound, SPECTRUM *p)
     return OK;
 }
 
-#if 0
 /* int nocdfset(CSOUND *csound, NOCTDFT *p) */
 /*     /\* noctdft - calcs disc Fourier transform of oct-downsampled data *\/ */
 /*     /\* outputs coefs (mag, db or mag2) of log freq within each octave *\/ */
@@ -506,7 +504,6 @@ int spectrum(CSOUND *csound, SPECTRUM *p)
 /*     specp->ktimstamp = csound->kcounter;        /\* time-stamp the output   *\/ */
 /*     return OK; */
 /* } */
-#endif
 
 int spdspset(CSOUND *csound, SPECDISP *p)
 {
@@ -632,14 +629,14 @@ int sptrkset(CSOUND *csound, SPECPTRK *p)
     for (fp = fhip; fp < fendp; )
       *fp++ = FL(0.0);
 
-    csound->Message(csound, Str("specptrk: %d freqs, %d%s ptls at "),
+    csound->Warning(csound, Str("specptrk: %d freqs, %d%s ptls at "),
                             (int)nfreqs, (int)nptls, inc==2 ? Str(" odd") : "");
     for (nn = 0; nn < nptls; nn++)
-      csound->Message(csound, "\t%d", p->pdist[nn]);
+      csound->Warning(csound, "\t%d", p->pdist[nn]);
     if (p->rolloff) {
-      csound->Message(csound, Str("\n\t\trolloff vals:"));
+      csound->Warning(csound, Str("\n\t\trolloff vals:"));
       for (nn = 0; nn < nptls; nn++)
-        csound->Message(csound, "\t%4.2f", p->pmult[nn]);
+        csound->Warning(csound, "\t%4.2f", p->pmult[nn]);
     }
 
     dbthresh = *p->idbthresh;                     /* thresholds: */
@@ -660,7 +657,7 @@ int sptrkset(CSOUND *csound, SPECPTRK *p)
     }
     p->threshon *= weightsum;
     p->threshoff *= weightsum;
-    csound->Message(csound, Str("\n\tdbthresh %4.1f: X-corr %s "
+    csound->Warning(csound, Str("\n\tdbthresh %4.1f: X-corr %s "
                                 "threshon %4.1f, threshoff %4.1f\n"),
                             dbthresh, outstring[inspecp->dbout],
                             p->threshon, p->threshoff);
@@ -1169,7 +1166,7 @@ int spfilset(CSOUND *csound, SPECFILT *p)
         }
       }
     }
-    csound->Message(csound, Str("coef range: %6.3f - %6.3f\n"),
+    csound->Warning(csound, Str("coef range: %6.3f - %6.3f\n"),
                             *p->coefs, *(p->coefs+npts-1));
     {
       MYFLT *flp = (MYFLT *) p->states;
@@ -1203,12 +1200,10 @@ int specfilt(CSOUND *csound, SPECFILT *p)
  err1:
     return csound->PerfError(csound, Str("specfilt: not initialised"));
 }
-#endif
 
 #define S       sizeof
 
 static OENTRY localops[] = {
-#ifndef OLPC
 { "spectrum", S(SPECTRUM),7, "w", "siiiqoooo",
                                    (SUBR)spectset,(SUBR)spectrum,(SUBR)spectrum},
 { "specaddm", S(SPECADDM),5, "w",  "wwp",  (SUBR)spadmset,NULL,  (SUBR)specaddm},
@@ -1220,7 +1215,6 @@ static OENTRY localops[] = {
                                              (SUBR)sptrkset,NULL,(SUBR)specptrk},
 { "specsum",  S(SPECSUM), 5, "k",  "wo",   (SUBR)spsumset,NULL,  (SUBR)specsum },
 { "specdisp", S(SPECDISP),5, "",   "wio",  (SUBR)spdspset,NULL,  (SUBR)specdisp},
-#endif
 { "pitch", S(PITCH),     5,    "kk", "aiiiiqooooojo",
                                              (SUBR)pitchset, NULL, (SUBR)pitch },
 { "maca", S(SUM),        5,  "a", "y",    (SUBR)macset,      NULL, (SUBR)maca  },
@@ -1235,18 +1229,21 @@ static OENTRY localops[] = {
                                 (SUBR)phsbnkset, (SUBR)kphsorbnk, (SUBR)phsorbnk },
 { "adsynt",S(HSBOSC),    5,  "a", "kkiiiio", (SUBR)adsyntset, NULL, (SUBR)adsynt },
 { "mpulse", S(IMPULSE),  5,  "a", "kko",  (SUBR)impulse_set, NULL, (SUBR)impulse },
-{ "lpf18", S(LPF18),     5,  "a", "akkk",  (SUBR)lpf18set, NULL, (SUBR)lpf18db   },
+{ "lpf18", S(LPF18),     5,  "a", "akkko",  (SUBR)lpf18set, NULL, (SUBR)lpf18db   },
 { "waveset", S(BARRI),   5,  "a", "ako",   (SUBR)wavesetset,  NULL, (SUBR)waveset},
 { "pinkish", S(PINKISH),  5, "a", "xoooo", (SUBR)pinkset, NULL, (SUBR)pinkish },
 { "noise",  S(VARI),   5,    "a", "xk",   (SUBR)varicolset, NULL, (SUBR)varicol },
 { "transeg", S(TRANSEG), 7,  "s", "iiim", (SUBR)trnset,(SUBR)ktrnseg,(SUBR)trnseg},
-{ "transegr", S(TRANSEG), 7, "s", "iiim", (SUBR)trnsetr,(SUBR)ktrnsegr,(SUBR)trnsegr},
+{ "transegb", S(TRANSEG), 7,  "s", "iiim",
+                              (SUBR)trnset_bkpt,(SUBR)ktrnseg,(SUBR)trnseg    },
+{ "transegr", S(TRANSEG), 7, "s", "iiim",
+                              (SUBR)trnsetr,(SUBR)ktrnsegr,(SUBR)trnsegr      },
 { "clip", S(CLIP),       5,  "a", "aiiv", (SUBR)clip_set, NULL, (SUBR)clip  },
-{ "cpuprc", S(CPU_PERC), 1,     "",     "ii",   (SUBR)cpuperc, NULL, NULL   },
-{ "maxalloc", S(CPU_PERC), 1,   "",     "ii",   (SUBR)maxalloc, NULL, NULL  },
+{ "cpuprc", S(CPU_PERC), 1,     "",     "Ti",   (SUBR)cpuperc, NULL, NULL   },
+{ "maxalloc", S(CPU_PERC), 1,   "",     "Ti",   (SUBR)maxalloc, NULL, NULL  },
 { "active", 0xffff                                                          },
-{ "active.i", S(INSTCNT),1,     "i",    "i",    (SUBR)instcount, NULL, NULL },
-{ "active.k", S(INSTCNT),2,     "k",    "k",    NULL, (SUBR)instcount, NULL },
+{ "active.i", S(INSTCNT),1,     "i",    "To",    (SUBR)instcount, NULL, NULL },
+{ "active.k", S(INSTCNT),2,     "k",    "Uo",    NULL, (SUBR)instcount, NULL },
 { "p.i", S(PFUN),        1,     "i",    "i",     (SUBR)pfun, NULL, NULL     },
 { "p.k", S(PFUN),        2,     "k",    "k",     NULL, (SUBR)pfun, NULL     },
 { "mute", S(MUTE), 1,          "",      "To",   (SUBR)mute_inst             },
@@ -1257,6 +1254,8 @@ static OENTRY localops[] = {
 { "oscilv.ak", S(XOSC),  5,     "a",   "akio", (SUBR)Foscset, NULL, (SUBR)Foscak },
 { "oscilv.aa", S(XOSC),  5,     "a",   "aaio", (SUBR)Foscset, NULL, (SUBR)Foscaa },
 #endif
+{ "median", S(MEDFILT),  5,     "a", "akio", (SUBR)medfiltset, NULL, (SUBR)medfilt},
+{ "mediank", S(MEDFILT), 5,     "k", "kkio", (SUBR)medfiltset, (SUBR)kmedfilt},
 };
 
 LINKAGE
