@@ -26,7 +26,6 @@
 assisting functions for VBAP
 functions for loudspeaker table initialization */
 
-#ifndef OLPC
 
 #include "csdl.h"
 #include "vbap.h"
@@ -129,12 +128,12 @@ void calc_vbap_gns(int ls_set_am, int dim, LS_SET *sets,
 
     gains[sets[j].ls_nos[0]-1] = sets[j].set_gains[0];
     gains[sets[j].ls_nos[1]-1] = sets[j].set_gains[1];
-    if(dim==3) gains[sets[j].ls_nos[2]-1] = sets[j].set_gains[2];
+    if (dim==3) gains[sets[j].ls_nos[2]-1] = sets[j].set_gains[2];
 
-      for (i=0;i<ls_amount;i++) {
+    for (i=0;i<ls_amount;i++) {
       if (gains[i]<LOWEST_ACCEPTABLE_WT)
         gains[i]=FL(0.0);
-        }
+    }
 }
 
 void scale_angles(ANG_VEC *avec)
@@ -569,7 +568,7 @@ int vbap_ls_init (CSOUND *csound, VBAP_LS_INIT *p)
     int ls_amount;
 
     dim = (int) *p->dim;
-    csound->Message(csound, "dim : %d\n",dim);
+    csound->Warning(csound, "dim : %d\n",dim);
     if (UNLIKELY(!((dim==2) || (dim == 3)))) {
       csound->Die(csound, Str("Error in loudspeaker dimension."));
     }
@@ -666,13 +665,13 @@ static void calculate_3x3_matrixes(CSOUND *csound,
     }
 
     k = 3;
-    csound->Message(csound, Str("\nConfigured loudspeakers\n"));
+    csound->Warning(csound, Str("\nConfigured loudspeakers\n"));
     for (i = 0; i < triplet_amount; i++) {
-      csound->Message(csound, Str("Triplet %d Loudspeakers: "), i);
+      csound->Warning(csound, Str("Triplet %d Loudspeakers: "), i);
       for (j = 0; j < 3; j++) {
-        csound->Message(csound, "%d ", (int) ls_table[k++]);
+        csound->Warning(csound, "%d ", (int) ls_table[k++]);
       }
-      csound->Message(csound, "\n");
+      csound->Warning(csound, "\n");
 
    /* printf("\nMatrix "); */
       for (j = 0; j < 9; j++) {
@@ -765,13 +764,13 @@ static void choose_ls_tuplets(CSOUND *csound,
       }
     }
     k=3;
-    csound->Message(csound, Str("\nConfigured loudspeakers\n"));
+    csound->Warning(csound, Str("\nConfigured loudspeakers\n"));
     for (i=0; i < amount; i++) {
-      csound->Message(csound, Str("Pair %d Loudspeakers: "), i);
+      csound->Warning(csound, Str("Pair %d Loudspeakers: "), i);
       for (j=0; j < 2; j++) {
-        csound->Message(csound, "%d ", (int) ls_table[k++]);
+        csound->Warning(csound, "%d ", (int) ls_table[k++]);
       }
-      csound->Message(csound, "\n");
+      csound->Warning(csound, "\n");
 
    /* csound->Message(csound, "\nMatrix "); */
       /* for (j=0; j < 4; j++) { */
@@ -931,4 +930,3 @@ PUBLIC int csoundModuleInfo(void)
     return ((CS_APIVERSION << 16) + (CS_APISUBVER << 8) + (int) sizeof(MYFLT));
 }
 
-#endif
