@@ -28,7 +28,6 @@
    Ville Pulkki & John ffitch
 */
 
-#ifndef OLPC
 
 #include "csdl.h"
 #include "vbap.h"
@@ -50,8 +49,8 @@ int vbap_zak(CSOUND *csound, VBAP_ZAK *p)   /* during note performance: */
 
     vbap_zak_control(csound,p);
     for (i=0; i<n; i++) {
-      p->beg_gains[i]=p->end_gains[i];
-      p->end_gains[i]=p->updated_gains[i];
+      p->beg_gains[i] = p->end_gains[i];
+      p->end_gains[i] = p->updated_gains[i];
     }
 
     /* write audio to result audio streams weighted
@@ -72,11 +71,13 @@ int vbap_zak(CSOUND *csound, VBAP_ZAK *p)   /* during note performance: */
           p->curr_gains[j]= ogain +
             (MYFLT) (i) * invfloatn * gainsubstr;
         }
-        else
+        else {
           for (i=0; i<nsmps; ++i)
-            outptr[n] = inptr[n] * ogain;
-      else
+            outptr[i] = inptr[i] * ogain;
+        }
+      else 
         memset(outptr, 0, nsmps*sizeof(MYFLT));
+      outptr += nsmps;
     }
     return OK;
 }
@@ -90,11 +91,10 @@ int vbap_zak_control(CSOUND *csound, VBAP_ZAK *p)
     int n = p->n;
     MYFLT tmp_gains[MAXCHNLS],sum = FL(0.0);
     if (UNLIKELY(p->dim == 2 && fabs(*p->ele) > 0.0)) {
-      csound->Message(csound,
+      csound->Warning(csound,
                       Str("Warning: truncating elevation to 2-D plane\n"));
       *p->ele = FL(0.0);
     }
-
     if (*p->spread <FL(0.0))
       *p->spread=FL(0.0);
     else if (*p->spread >FL(100.0))
@@ -235,7 +235,7 @@ int vbap_zak_init(CSOUND *csound, VBAP_ZAK *p)
 
     /* other initialization */
     if (UNLIKELY(p->dim == 2 && fabs(*p->ele) > 0.0)) {
-      csound->Message(csound,
+      csound->Warning(csound,
                       Str("Warning: truncating elevation to 2-D plane\n"));
       *p->ele = FL(0.0);
     }
@@ -306,7 +306,7 @@ int vbap_zak_moving_control(CSOUND *csound, VBAP_ZAK_MOVING *p)
     MYFLT coeff, angle;
     MYFLT tmp_gains[MAXCHNLS],sum = FL(0.0); /* Array long enough */
     if (UNLIKELY(p->dim == 2 && fabs(p->ang_dir.ele) > 0.0)) {
-      csound->Message(csound,
+      csound->Warning(csound,
                       Str("Warning: truncating elevation to 2-D plane\n"));
       p->ang_dir.ele = FL(0.0);
     }
@@ -338,7 +338,7 @@ int vbap_zak_moving_control(CSOUND *csound, VBAP_ZAK_MOVING *p)
       if (*p->field_am >= FL(0.0) && p->dim == 2) /* point-to-point */
         if (UNLIKELY(fabs(fabs(*p->fld[p->next_fld] - *p->fld[p->curr_fld])
                           - 180.0) < 1.0))
-          csound->Message(csound,
+          csound->Warning(csound,
                           Str("Warning: Ambiguous transition 180 degrees.\n"));
     }
     if (*p->field_am >= FL(0.0)) { /* point-to-point */
@@ -572,5 +572,3 @@ int vbap_zak_moving_init(CSOUND *csound, VBAP_ZAK_MOVING *p)
     }
     return OK;
 }
-
-#endif
