@@ -29,8 +29,8 @@
 extern void strset_option(CSOUND *csound, char *s);     /* from str_ops.c */
 
 #define FIND(MSG)   if (*s == '\0')  \
-                      if (!(--argc) || (((s = *++argv) != NULL) && *s == '-')) \
-                         dieu(csound, MSG);
+    if (UNLIKELY(!(--argc) || (((s = *++argv) != NULL) && *s == '-')))  \
+      dieu(csound, MSG);
 
 #define STDINASSIGN_SNDFILE     1
 #define STDINASSIGN_LINEIN      2
@@ -62,8 +62,9 @@ static void set_stdout_assign(CSOUND *csound, int type, int state)
 static const char *shortUsageList[] = {
   Str_noop("--help\tprint long usage options"),
   Str_noop("-U unam\trun utility program unam"),
-#ifndef OLPC
   Str_noop("-C\tuse Cscore processing of scorefile"),
+#ifdef PARCS
+  Str_noop("-j N\tuse N processes"),
 #endif
   Str_noop("-I\tI-time only orch run"),
   Str_noop("-n\tno sound onto disk"),
@@ -71,11 +72,8 @@ static const char *shortUsageList[] = {
   Str_noop("-o fnam\tsound output filename"),
   Str_noop("-b N\tsample frames (or -kprds) per software sound I/O buffer"),
   Str_noop("-B N\tsamples per hardware sound I/O buffer"),
-#ifndef OLPC
   Str_noop("-A\tcreate an AIFF format output soundfile"),
-#endif
   Str_noop("-W\tcreate a WAV format output soundfile"),
-#ifndef OLPC
   Str_noop("-J\tcreate an IRCAM format output soundfile"),
   Str_noop("-h\tno header on output soundfile"),
   Str_noop("-c\t8-bit signed_char sound samples"),
@@ -83,45 +81,32 @@ static const char *shortUsageList[] = {
   Str_noop("-a\talaw sound samples"),
 #endif
   Str_noop("-8\t8-bit unsigned_char sound samples"),
-#endif
   Str_noop("-u\tulaw sound samples"),
   Str_noop("-s\tshort_int sound samples"),
-#ifndef OLPC
   Str_noop("-l\tlong_int sound samples"),
-#endif
   Str_noop("-f\tfloat sound samples"),
-#ifndef OLPC
   Str_noop("-3\t24bit sound samples"),
-#endif
   Str_noop("-r N\torchestra srate override"),
   Str_noop("-k N\torchestra krate override"),
-#ifndef OLPC
   Str_noop("-K\tDo not generate PEAK chunks"),
-#endif
   Str_noop("-v\tverbose orch translation"),
   Str_noop("-m N\ttty message level. Sum of:"),
   Str_noop("\t\t1=note amps, 2=out-of-range msg, 4=warnings"),
   Str_noop("\t\t0/32/64/96=note amp format (raw,dB,colors)"),
   Str_noop("\t\t128=print benchmark information"),
-#ifndef OLPC
   Str_noop("-d\tsuppress all displays"),
-#endif
   Str_noop("-g\tsuppress graphics, use ascii displays"),
-#ifndef OLPC
   Str_noop("-G\tsuppress graphics, use Postscript displays"),
   Str_noop("-x fnam\textract from score.srt using extract file 'fnam'"),
-#endif
   Str_noop("-t N\tuse uninterpreted beats of the score, initially at tempo N"),
   Str_noop("-t 0\tuse score.srt for sorted score rather than a temporary"),
   Str_noop("-L dnam\tread Line-oriented realtime score events from device 'dnam'"),
   Str_noop("-M dnam\tread MIDI realtime events from device 'dnam'"),
   Str_noop("-F fnam\tread MIDIfile event stream from file 'fnam'"),
   /*  Str_noop("-P N\tMIDI sustain pedal threshold (0 - 128)"), */
-#ifndef OLPC
   Str_noop("-R\tcontinually rewrite header while writing soundfile (WAV/AIFF)"),
   Str_noop("-H#\tprint heartbeat style 1, 2 or 3 at each soundfile write"),
   Str_noop("-N\tnotify (ring the bell) when score or miditrack is done"),
-#endif
   Str_noop("-T\tterminate the performance when miditrack is done"),
   Str_noop("-D\tdefer GEN01 soundfile loads until performance time"),
   Str_noop("-Q dnam\tselect MIDI output device"),
@@ -137,25 +122,20 @@ static const char *shortUsageList[] = {
 };
 
 static const char *longUsageList[] = {
-  Str_noop("--format={wav,aiff,au,raw,ircam,w64,wavex,sd2,flac}"),
-  Str_noop("--format={alaw,ulaw,schar,uchar,float,short,long,24bit}"),
+  "--format={wav,aiff,au,raw,paf,svx,nist,voc,ircam,w64,mat4,mat5",
+  "          pvf,xi,htk,sds,avr,wavex,sd2,flac,caf,WVE,ogg,MPC,W64}",
+  "--format={alaw,ulaw,schar,uchar,float,short,long,24bit}",
   Str_noop("\t\t\tSet output file format"),
-#ifndef OLPC
   Str_noop("--aiff\t\t\tSet AIFF format"),
   Str_noop("--au\t\t\tSet AU format"),
-#endif
   Str_noop("--wave\t\t\tSet WAV format"),
-#ifndef OLPC
   Str_noop("--ircam\t\t\tSet IRCAM format"),
   Str_noop("--noheader\t\tRaw format"),
   Str_noop("--nopeaks\t\tDo not write peak information"),
-#endif
   " ",
   Str_noop("--nodisplays\t\tsUppress all displays"),
   Str_noop("--asciidisplay\t\tSuppress graphics, use ascii displays"),
-#ifndef OLPC
   Str_noop("--postscriptdisplay\tSuppress graphics, use Postscript displays"),
-#endif
   " ",
   Str_noop("--defer-gen1\t\tDefer GEN01 soundfile loads until performance time"),
   Str_noop("--iobufsamps=N\t\tSample frames (or -kprds) per software sound I/O buffer"),
@@ -167,12 +147,10 @@ static const char *longUsageList[] = {
   Str_noop("--midi-device=FNAME\tRead MIDI realtime events from device"),
   Str_noop("--terminate-on-midi\tTerminate the performance when miditrack is done"),
   " ",
-#ifndef OLPC
   Str_noop("--heartbeat=N\t\tPrint a heartbeat style 1, 2 or 3 at each soundfile write"),
   Str_noop("--notify\t\tNotify (ring the bell) when score or miditrack is done"),
   Str_noop("--rewrite\t\tContinually rewrite header while writing soundfile (WAV/AIFF)"),
   " ",
-#endif
   Str_noop("--input=FNAME\t\tSound input filename"),
   Str_noop("--output=FNAME\t\tSound output filename"),
   Str_noop("--logfile=FNAME\t\tLog output to file"),
@@ -215,6 +193,7 @@ static const char *longUsageList[] = {
   Str_noop("--sched\t\t\tSet real-time scheduling priority and lock memory"),
   Str_noop("--sched=N\t\tSet priority to N and lock memory"),
   Str_noop("--opcode-lib=NAMES\tDynamic libraries to load"),
+  Str_noop("--opcode-omit=NAMES\tDynamic libraries not to load"),
   Str_noop("--omacro:XXX=YYY\tSet orchestra macro XXX to value YYY"),
   Str_noop("--smacro:XXX=YYY\tSet score macro XXX to value YYY"),
   Str_noop("--midi-key=N\t\tRoute MIDI note on message"),
@@ -362,6 +341,9 @@ static const SOUNDFILE_TYPE_ENTRY file_type_map[] = {
 #  if HAVE_LIBSNDFILE >= 1018
     { "WVE",    TYP_WVE   },  { "ogg",    TYP_OGG   },
 #  endif
+#  if HAVE_LIBSNDFILE >= 1019
+    { "MPC",    TYPE_MPC2K }, { "W64",    TYP_RF64  },
+#  endif
 #endif
     { NULL , -1 }
 };
@@ -370,7 +352,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
 {
     OPARMS  *O = csound->oparms;
     /* Add other long options here */
-    if (O->odebug)
+    if (UNLIKELY(O->odebug))
       csound->Message(csound, "decode_long %s\n", s);
     if (!(strncmp(s, "omacro:", 7))) {
       NAMES *nn = (NAMES*) mmalloc(csound, sizeof(NAMES));
@@ -414,7 +396,6 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       } while (s != NULL);
       return 1;
     }
-#ifndef OLPC
     /* -A */
     else if (!(strcmp (s, "aiff"))) {
       O->filetyp = TYP_AIFF;            /* AIFF output request */
@@ -424,26 +405,23 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       O->filetyp = TYP_AU;              /* AU output request */
       return 1;
     }
-#endif
     else if (!(strncmp (s, "iobufsamps=", 11))) {
       s += 11;
-      if (*s=='\0') dieu(csound, Str("no iobufsamps"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no iobufsamps"));
       /* defaults in musmon.c */
       O->inbufsamps = O->outbufsamps = atoi(s);
       return 1;
     }
     else if (!(strncmp (s, "hardwarebufsamps=", 17))) {
       s += 17;
-      if (*s=='\0') dieu(csound, Str("no hardware bufsamps"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no hardware bufsamps"));
       O->inbufsamps = O->outbufsamps = atoi(s);
       return 1;
     }
-#ifndef OLPC
     else if (!(strcmp (s, "cscore"))) {
       O->usingcscore = 1;               /* use cscore processing  */
       return 1;
     }
-#endif
     else if (!(strcmp (s, "nodisplays"))) {
       O->displays = 0;                  /* no func displays */
       return 1;
@@ -458,7 +436,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     }
     else if (!(strncmp (s, "midifile=", 9))) {
       s += 9;
-      if (*s == '\0') dieu(csound, Str("no midifile name"));
+      if (UNLIKELY(*s == '\0')) dieu(csound, Str("no midifile name"));
       O->FMidiname = s;                 /* Midifile name */
       if (!strcmp(O->FMidiname, "stdin")) {
         set_stdin_assign(csound, STDINASSIGN_MIDIFILE, 1);
@@ -473,7 +451,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     }
     else if (!(strncmp (s, "midioutfile=", 12))) {
       s += 12;
-      if (*s == '\0') dieu(csound, Str("no midi output file name"));
+      if (UNLIKELY(*s == '\0')) dieu(csound, Str("no midi output file name"));
       O->FMidioutname = s;
       return 1;
     }
@@ -487,7 +465,6 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       O->postscript = 1;                /* don't use graphics but PostScript */
       return 1;
     }
-#ifndef OLPC
     /* -h */
     else if (!(strcmp (s, "noheader"))) {
       O->filetyp = TYP_RAW;             /* RAW output request */
@@ -499,20 +476,19 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       else O->heartbeat = atoi(s);
       return 1;
     }
-#endif
 #ifdef EMBEDDED_PYTHON
     else if (strncmp(s, "pyvar=", 6) == 0) {
       s += 6;
-      if (python_add_cmdline_definition(s))
+      if (UNLIKELY(python_add_cmdline_definition(s)))
         dieu(csound, Str("invalid python variable definition syntax"));
       return 1;
     }
 #endif
     else if (!(strncmp (s, "input=", 6))) {
       s += 6;
-      if (*s == '\0') dieu(csound, Str("no infilename"));
+      if (UNLIKELY(*s == '\0')) dieu(csound, Str("no infilename"));
       O->infilename = s;                /* soundin name */
-      if (strcmp(O->infilename, "stdout") == 0)
+      if (UNLIKELY(strcmp(O->infilename, "stdout") == 0))
         csoundDie(csound, Str("input cannot be stdout"));
       if (strcmp(O->infilename, "stdin") == 0) {
         set_stdin_assign(csound, STDINASSIGN_SNDFILE, 1);
@@ -534,7 +510,6 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       O->sfwrite = 0;                   /* and implies nosound */
       return 1;
     }
-#ifndef OLPC
     /*
       -j Used in localisation
       -J create an IRCAM format output soundfile
@@ -543,29 +518,26 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       O->filetyp = TYP_IRCAM;           /* IRCAM output request */
       return 1;
     }
-#endif
     /*
       -k N orchestra krate override
      */
     else if (!(strncmp(s, "control-rate=", 13))) {
       s += 13;
-      if (*s=='\0') dieu(csound, Str("no control rate"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no control rate"));
       O->kr_override = (float)atof(s);
       return 1;
     }
-#ifndef OLPC
     /* -K */
     else if (!(strcmp (s, "nopeaks"))) {
       csound->peakchunks = 0;           /* Do not write peak information */
       return 1;
     }
-#endif
     /*
       -L dnam read Line-oriented realtime score events from device 'dnam'
      */
     else if (!(strncmp (s, "score-in=", 9))) {
       s += 9;
-      if (*s=='\0') dieu(csound, Str("no Linein score device_name"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no Linein score device_name"));
       O->Linename = s;
       if (!strcmp(O->Linename, "stdin")) {
         set_stdin_assign(csound, STDINASSIGN_LINEIN, 1);
@@ -584,20 +556,20 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
      */
     else if (!(strncmp (s, "messagelevel=", 13))) {
       s += 13;
-      if (*s=='\0') dieu(csound, Str("no message level"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no message level"));
       O->msglevel = atoi(s);
       return 1;
     }
     else if (!(strncmp (s, "messageolevel=", 14))) {
       s += 14;
-      if (*s=='\0') dieu(csound, Str("no message level"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no message level"));
       sscanf(s, "%o", &(O->msglevel));
       return 1;
     }
     else if (!(strncmp (s, "m-amps=", 7))) {
       int n;
       s += 7;
-      if (*s=='\0') dieu(csound, Str("no message amps"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no message amps"));
       sscanf(s, "%d", &n);
       if (n) O->msglevel |= AMPLMSG;
       else O->msglevel &= ~AMPLMSG;
@@ -606,7 +578,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     else if (!(strncmp (s, "m-range=",8))) {
       int n;
       s += 8;
-      if (*s=='\0') dieu(csound, Str("no message range"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no message range"));
       sscanf(s, "%d", &n);
       if (n) O->msglevel |= RNGEMSG;
       else O->msglevel &= ~RNGEMSG;
@@ -615,7 +587,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     else if (!(strncmp (s, "m-warnings=",11))) {
       int n;
       s += 11;
-      if (*s=='\0') dieu(csound, Str("no message warnings"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no message warnings"));
       sscanf(s, "%d", &n);
       if (n) O->msglevel |= WARNMSG;
       else O->msglevel &= ~WARNMSG;
@@ -624,7 +596,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     else if (!(strncmp (s, "m-raw=",6))) {
       int n;
       s += 6;
-      if (*s=='\0') dieu(csound, Str("no message raw"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no message raw"));
       sscanf(s, "%d", &n);
       if (n) O->msglevel |= 32;
       else O->msglevel &= ~32;
@@ -633,7 +605,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     else if (!(strncmp (s, "m-dB=",5))) {
       int n;
       s += 5;
-      if (*s=='\0') dieu(csound, Str("no message dB"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no message dB"));
       sscanf(s, "%d", &n);
       if (n) O->msglevel |= RAWMSG;
       else O->msglevel &= ~RAWMSG;
@@ -651,7 +623,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     else if (!(strncmp (s, "m-benchmarks=",13))) {
       int n;
       s += 13;
-      if (*s=='\0') dieu(csound, Str("no benchmark level"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no benchmark level"));
       sscanf(s, "%d", &n);
       if (n) O->msglevel |= TIMEMSG;
       else O->msglevel &= ~TIMEMSG;
@@ -659,7 +631,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     }
     else if (!(strncmp (s, "csd-line-nums=",14))) {
       s += 14;
-      if (*s=='\0') dieu(csound, Str("no value for --csd-line-nums"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no value for --csd-line-nums"));
       O->useCsdLineCounts = (atoi(s) != 0);
       return 1;
     }
@@ -668,7 +640,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
      */
     else if (!(strncmp (s, "midi-device=", 12))) {
       s += 12;
-      if (*s=='\0') dieu(csound, Str("no midi device_name"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no midi device_name"));
       O->Midiname = s;
       if (!strcmp(O->Midiname, "stdin")) {
         set_stdin_assign(csound, STDINASSIGN_MIDIDEV, 1);
@@ -686,18 +658,16 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       O->sfwrite = 0;                   /* nosound        */
       return 1;
     }
-#ifndef OLPC
     /* -N */
     else if (!(strcmp (s, "notify"))) {
       O->ringbell = 1;                  /* notify on completion */
       return 1;
     }
-#endif
     else if (!(strncmp (s, "output=", 7))) {
       s += 7;
-      if (*s == '\0') dieu(csound, Str("no outfilename"));
+      if (UNLIKELY(*s == '\0')) dieu(csound, Str("no outfilename"));
       O->outfilename = s;               /* soundout name */
-      if (strcmp(O->outfilename, "stdin") == 0)
+      if (UNLIKELY(strcmp(O->outfilename, "stdin")) == 0)
         dieu(csound, Str("-o cannot be stdin"));
       if (strcmp(O->outfilename, "stdout") == 0) {
         set_stdout_assign(csound, STDOUTASSIGN_SNDFILE, 1);
@@ -712,7 +682,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     }
     else if (!(strncmp (s, "logfile=", 8))) {
       s += 8;
-      if (*s=='\0') dieu(csound, Str("no log file"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no log file"));
       return 1;
     }
     /* -r N */
@@ -721,17 +691,15 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       O->sr_override = (float)atof(s);
       return 1;
     }
-#ifndef OLPC
     /* R */
     else if (!(strcmp (s, "rewrite"))) {
       O->rewrt_hdr = 1;
       return 1;
     }
-#endif
     /* -S  */
     /* tempo=N use uninterpreted beats of the score, initially at tempo N
      */
-    else if (!(strncmp (s, "tempo=", 6))) {
+    else if (UNLIKELY(!(strncmp (s, "tempo=", 6)))) {
       s += 6;
       O->cmdTempo = atoi(s);
       O->Beatmode = 1;                  /* on uninterpreted Beats */
@@ -781,7 +749,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     /* -x fnam extract from score.srt using extract file 'fnam' */
     else if (!(strncmp(s, "extract-score=", 14))) {
       s += 14;
-      if (*s=='\0') dieu(csound, Str("no xfilename"));
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no xfilename"));
       csound->xfilename = s;
       return 1;
     }
@@ -873,12 +841,12 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       O->noDefaultPaths = 1;
       return 1;
     }
-    else if(!(strncmp (s, "num-threads=", 12))) {
+    else if (!(strncmp (s, "num-threads=", 12))) {
       s += 12 ;
       O->numThreads = atoi(s);
       return 1;
     }
-    else if(!(strcmp (s, "syntax-check-only"))) {
+    else if (!(strcmp (s, "syntax-check-only"))) {
       O->syntaxCheckOnly = 1;
       return 1;
     }
@@ -891,6 +859,30 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       O->newParser = 1;             /* Use New Parser */
       return 1;
     }
+#ifdef PARCS
+    else if (!(strncmp(s, "weight-info=", 12))) {
+      s += 12;
+      if (*s=='\0') dieu(csound, Str("no weight-info"));
+      csound->weight_info = s;
+      return 1;
+    }
+    else if (!(strncmp(s, "weight-dump=", 12))) {
+      s += 12;
+      if (*s=='\0') dieu(csound, Str("no weight-dump"));
+      csound->weight_dump = s;
+      return 1;
+    }
+    else if (!(strncmp(s, "weights=", 8))) {
+      s += 8;
+      if (*s=='\0') dieu(csound, Str("no weights"));
+      csound->weights = s;
+      return 1;
+    }
+    else if (!(strcmp(s, "compute-weights"))) {
+      O->calculateWeights = 1;
+      return 1;
+    }
+#endif
     else if (!(strcmp(s, "old-parser"))) {
       O->newParser = 0;             /* Use Old Parser */
       return 1;
@@ -938,11 +930,9 @@ int argdecode(CSOUND *csound, int argc, char **argv_)
               csound->LongJmp(csound, retval);
             }
             break;
-#ifndef OLPC
           case 'C':
             O->usingcscore = 1;           /* use cscore processing  */
             break;
-#endif
           case 'I':
             csound->initonly = 1;         /* I-only overrides */
             O->syntaxCheckOnly = 0;       /* --syntax-check-only and implies */
@@ -953,7 +943,7 @@ int argdecode(CSOUND *csound, int argc, char **argv_)
             FIND(Str("no infilename"));
             O->infilename = s;            /* soundin name */
             s += (int) strlen(s);
-            if (strcmp(O->infilename, "stdout") == 0)
+            if (UNLIKELY(strcmp(O->infilename, "stdout")) == 0)
               csoundDie(csound, Str("input cannot be stdout"));
             if (strcmp(O->infilename, "stdin") == 0) {
               set_stdin_assign(csound, STDINASSIGN_SNDFILE, 1);
@@ -969,7 +959,7 @@ int argdecode(CSOUND *csound, int argc, char **argv_)
             FIND(Str("no outfilename"));
             O->outfilename = s;           /* soundout name */
             s += (int) strlen(s);
-            if (strcmp(O->outfilename, "stdin") == 0)
+            if (UNLIKELY(strcmp(O->outfilename, "stdin") == 0))
               dieu(csound, Str("-o cannot be stdin"));
             if (strcmp(O->outfilename, "stdout") == 0) {
               set_stdout_assign(csound, STDOUTASSIGN_SNDFILE, 1);
@@ -994,14 +984,12 @@ int argdecode(CSOUND *csound, int argc, char **argv_)
             /* defaults in rtaudio.c */
             s += n;
             break;
-#ifndef OLPC
           case 'A':
             O->filetyp = TYP_AIFF;        /* AIFF output request*/
             break;
           case 'J':
             O->filetyp = TYP_IRCAM;       /* IRCAM output request */
             break;
-#endif
           case 'W':
             O->filetyp = TYP_WAV;         /* WAV output request */
             break;
@@ -1042,11 +1030,9 @@ int argdecode(CSOUND *csound, int argc, char **argv_)
           case 'g':
             O->graphsoff = 1;             /* don't use graphics */
             break;
-#ifndef OLPC
           case 'G':
             O->postscript = 1;            /* Postscript graphics*/
             break;
-#endif
           case 'x':
             FIND(Str("no xfilename"));
             csound->xfilename = s;        /* extractfile name */
@@ -1058,12 +1044,12 @@ int argdecode(CSOUND *csound, int argc, char **argv_)
               int val;
               sscanf(s, "%d%n", &val, &n); /* use this tempo .. */
               s += n;
-              if (val < 0) dieu(csound, Str("illegal tempo"));
+              if (UNLIKELY(val < 0)) dieu(csound, Str("illegal tempo"));
               else if (val == 0) {
                 csound->keep_tmp = 1;
                 break;
               }
-              else O->cmdTempo = val;
+              O->cmdTempo = val;
               O->Beatmode = 1;            /* on uninterpreted Beats */
             }
             break;
@@ -1114,7 +1100,6 @@ int argdecode(CSOUND *csound, int argc, char **argv_)
             O->Midioutname = s;
             s += (int) strlen(s);
             break;
-#ifndef OLPC
           case 'R':
             O->rewrt_hdr = 1;
             break;
@@ -1128,17 +1113,6 @@ int argdecode(CSOUND *csound, int argc, char **argv_)
           case 'N':
             O->ringbell = 1;              /* notify on completion */
             break;
-#else
-          case 'R': case 'N':
-            break;
-          case 'H':
-            if (isdigit(*s)) {
-              int x;
-              sscanf(s, "%d%n", &x, &n);
-              s += n;
-            }
-            break;
-#endif
           case 'T':
             O->termifend = 1;             /* terminate on midifile end */
             break;
@@ -1178,7 +1152,7 @@ int argdecode(CSOUND *csound, int argc, char **argv_)
               void *fd;
               fd = csound->FileOpen2(csound, &ind, CSFILE_STD,
                                      s, "rb", NULL, CSFTYPE_OPTIONS, 0);
-              if (fd == NULL) {
+              if (UNLIKELY(fd == NULL)) {
                 dieu(csound, Str("Cannot open indirection file %s\n"), s);
               }
               else {
@@ -1207,6 +1181,11 @@ int argdecode(CSOUND *csound, int argc, char **argv_)
               csound->LongJmp(csound, 1);
             while (*(++s));
             break;
+          case 'j':
+            FIND(Str("no number of threads"));
+            sscanf(s, "%d%n", &(O->numThreads), &n);
+            s += n;
+            break;
           case '+':                                   /* IV - Feb 01 2005 */
             if (parse_option_as_cfgvar(csound, (char*) s - 2) != 0)
               csound->LongJmp(csound, 1);
@@ -1226,7 +1205,7 @@ int argdecode(CSOUND *csound, int argc, char **argv_)
         else if (csound->orcname_mode == 0) {
           if (csound->orchname == NULL)
             csound->orchname = --s;
-          else if (csound->scorename == NULL)
+          else if (LIKELY(csound->scorename == NULL))
             csound->scorename = --s;
           else {
             csound->Message(csound,"argc=%d Additional string \"%s\"\n",argc,--s);
