@@ -46,7 +46,7 @@ namespace csound
   bool Conversions::initialized_ = false;
   static bool initialized__ = Conversions::initialize();
 
-  void Conversions::subfill(std::string root, char *cname, double cpcs)
+  void Conversions::subfill(std::string root, const char *cname, double cpcs)
   {
     double pcs = pitchClassSetsForNames[root];
     root.append(cname);
@@ -60,7 +60,7 @@ namespace csound
     pitchClassSetsForNames[root] = mcpcs;
   }
 
-  void Conversions::fill(char *cname, char *cpitches_)
+  void Conversions::fill(const char *cname, const char *cpitches_)
   {
     double cpcs = 0.0;
     char separators[] = " ";
@@ -391,8 +391,11 @@ namespace csound
     returnValue +=(((int) Source & 0xff00) >> 8);
     return (short) returnValue;
   }
-  bool Conversions::stringToBool(std::string value)
+  bool Conversions::stringToBool(std::string value, bool default_)
   {
+    if (value.empty()) {
+      return default_;
+    }
     switch(value[0])
       {
       case '1':
@@ -413,8 +416,11 @@ namespace csound
         return "False";
       }
   }
-  int Conversions::stringToInt(std::string value)
+  int Conversions::stringToInt(std::string value, int default_)
   {
+    if (value.empty()) {
+      return default_;
+    }
     return atoi(value.c_str());
   }
   std::string Conversions::intToString(int value)
@@ -423,8 +429,11 @@ namespace csound
     sprintf(buffer, "%d", value);
     return buffer;
   }
-  double Conversions::stringToDouble(std::string value)
+  double Conversions::stringToDouble(std::string value, double default_)
   {
+    if (value.empty()) {
+      return default_;
+    }
     return atof(value.c_str());
   }
   std::string Conversions::doubleToString(double value)
@@ -606,4 +615,17 @@ namespace csound
     }
     return std::exp( factor * std::log( 10.0 ) * gain / 20.0 ) * inputDb;
   }
+  void Conversions::stringToVector(const std::string &text, std::vector<double> &vector)
+  {
+    vector.clear();
+    size_t index = 0;
+    for(;;) {
+      size_t nextIndex = text.find(",");
+      if (nextIndex == text.npos) {
+        break;
+      }
+      vector.push_back(std::atof(text.substr(index, nextIndex - index).c_str()));
+      index = nextIndex + 1;
+    }
+  }
 }
