@@ -52,40 +52,6 @@ namespace csound
     Composition::clear();
   }
 
-  std::string ScoreModel::getFilename() const
-  {
-    return filename;
-  }
-
-  void ScoreModel::setFilename(std::string filename)
-  {
-    this->filename = filename;
-  }
-
-  std::string ScoreModel::generateFilename()
-  {
-    time_t time_ = 0;
-    time(&time_);
-    struct tm* tm_ = gmtime(&time_);
-    char buffer[0x100];
-    strftime(buffer, 0x100, "silence.%Y-%m-%d.%H-%M-%S.py", tm_);
-    return buffer;
-  }
-
-  std::string ScoreModel::getMidiFilename()
-  {
-    std::string name = getFilename();
-    name.append(".mid");
-    return name;
-  }
-
-  std::string ScoreModel::getOutputSoundfileName()
-  {
-    std::string name = getFilename();
-    name.append(".wav");
-    return name;
-  }
-
   long ScoreModel::getThis()
   {
     return (long) this;
