@@ -14,7 +14,7 @@ headerFiles = ['H/cfgvar.h', 'H/cscore.h', 'H/csdl.h', 'H/csound.h',
                'H/csound.hpp', 'H/csoundCore.h', 'H/cwindow.h',
                'H/msg_attr.h', 'H/OpcodeBase.hpp', 'H/pstream.h',
                'H/pvfileio.h', 'H/soundio.h', 'H/sysdep.h', 'H/text.h',
-               'H/version.h',
+               'H/version.h', 'H/float-version-double.h',  'H/float-version.h',
                'interfaces/CppSound.hpp', 'interfaces/filebuilding.h',
                'interfaces/CsoundFile.hpp', 'interfaces/csPerfThread.hpp']
 
@@ -23,8 +23,8 @@ exeFiles1 = ['csound', 'csound5gui', 'CsoundVST', 'winsound',
              'cvanal', 'dnoise', 'envext', 'extractor',
              'het_export', 'het_import', 'hetro', 'lpanal',
              'lpc_export', 'lpc_import', 'mixer', 'pvanal',
-             'pv_export', 'pv_import',
-             'pvlook', 'scale', 'sndinfo', 'srconv',
+             'pv_export', 'pv_import', 'atsa',
+             'pvlook', 'scale', 'sndinfo', 'srconv', 'beats',
              'scsort', 'extract', 'cs', 'csb64enc', 'makecsd', 'scot']
 
 exeFiles2 = ['brkpt', 'linseg', 'tabdes']
@@ -271,7 +271,7 @@ for i in libList:
             err = installLink(i, concatPath([libDir, 'libcsound.so']))
         elif i[:15] == 'libcsound64.so.':
             err = installLink(i, concatPath([libDir, 'libcsound64.so']))
-        elif i[:11] == 'libcsnd.so':
+        elif i[:11] == 'libcsnd.so.':
             err = installLink(i, concatPath([libDir, 'libcsnd.so']))
         elif i == 'lib_CsoundVST.so':
             err = installLink(concatPath([libDir, i]),
@@ -307,10 +307,12 @@ print ' === Installing language interfaces ==='
 wrapperList = [['csnd\\.py', '0', pythonDir],
                ['loris\\.py', '0', pythonDir],
                ['CsoundVST\\.py', '0', pythonDir],
+               ['CsoundVSTCsoundAC\\.py', '0', pythonDir],
                ['scoregen\\.py', '0', pythonDir],
                ['_csnd\\.so', '1', pythonDir2],
                ['_loris\\.so', '1', pythonDir2],
                ['_scoregen\\.so', '1', pythonDir2],
+               ['_CsoundAC\\.so ', '1', pythonDir2],
                ['csnd\\.jar', '0', javaDir],
                ['interfaces/csound5\\.lisp', '0', lispDir]]
 for i in wrapperList:
@@ -335,7 +337,7 @@ else:
   for i in xmgList:
     makeDir(concatPath([xmgDir, i, 'LC_MESSAGES']))
     src = 'po/' + i + '/LC_MESSAGES/csound5.mo'
-    fileName = concatPath([xmgDir, i, 'LC_MESSAGES/csound5.mo'])
+    fileName = concatPath([instDir, xmgDir, i, 'LC_MESSAGES/csound5.mo'])
     err = runCmd(['install', '-p', '-m', '0644', src, fileName])
     if err == 0:
         addMD5(fileName, fileName)
@@ -454,6 +456,7 @@ except:
     print ' *** Error installing MD5 checksums'
     installErrors = 1
 
+    
 # -----------------------------------------------------------------------------
 
 print ''
