@@ -447,12 +447,10 @@ static int lpanal(CSOUND *csound, int argc, char **argv)
                         sscanf(s,"%d",&lpc.verbose);
                         if (lpc.verbose > 1)  lpc.debug = 1;
                         break;
-#ifndef OLPC
         case 'g':
                         csound->Warning(csound,
                           Str("graphical display is currently unsupported"));
                         break;
-#endif
         case 'a':
                         storePoles = TRUE;
                         break;
@@ -590,7 +588,8 @@ static int lpanal(CSOUND *csound, int argc, char **argv)
 
       /* Analyze current frame */
 #ifdef TRACE_POLES
-      csound->Message(csound, "Starting new frame...\n");
+      csound->Message
+        (csound, Str("Starting new frame...\n"));
 #endif
       counter++;
       alpol(csound, &lpc, sigbuf, &errn, &rms1, &rms2, filterCoef);
@@ -762,8 +761,9 @@ static void alpol(CSOUND *csound, LPC *thislp, MYFLT *sig, double *errn,
     int i, j, k, limit;
 
    /* Transfer signal in x array */
-    for (xp=thislp->x; xp-thislp->x < thislp->WINDIN;++xp,++sig)/*   &  copy sigin into */
+    for (xp=thislp->x; xp-thislp->x < thislp->WINDIN;++xp,++sig){ /*   &  copy sigin into */
       *xp = (double) *sig;
+    }
 
    /* Build system to be solved */
     for (i=0; i < thislp->poleCount;++i)  {
@@ -838,11 +838,13 @@ static void gauss(CSOUND *csound, LPC* thislp,
           amax = npq;
         }
       }
-      if (amax < 1.0e-20) {
-        csound->Message(csound,"Row %d or %d have maximum of %g\n",
-                        i, thislp->poleCount, amax);
-        csound->Die(csound, Str("gauss: ill-conditioned"));
-      }
+       if (amax < 1.0e-20) {
+   /* csound->Message(csound,Str("Row %d or %d have maximum of %g\n"),
+                      i, thislp->poleCount, amax);
+      csound->Die(csound, Str("gauss: ill-conditioned"));
+   */ 
+	 for (ii=i; ii < thislp->poleCount;++ii) a[ii][i] = 1.0e-20; /* VL: fix for very low values */
+       }
       if (i != istar) {
         for (j=0; j < thislp->poleCount;++j)  {    /* switch rows */
           dum = a[istar][j];
@@ -871,11 +873,14 @@ static void gauss(CSOUND *csound, LPC* thislp,
       }
     }                               /* return if last pivot is too small */
     if (fabs(a[thislp->poleCount-1][thislp->poleCount-1]) < 1e-20) {
-      csound->Message(csound,"Row %d or %d have maximum of %g\n",
+      a[thislp->poleCount-1][thislp->poleCount-1] = 1.0e-20; /* VL: fix for very low values */
+
+      /*
+            csound->Message(csound,"Row %d or %d have maximum of %g\n",
              thislp->poleCount-1, thislp->poleCount,
              fabs(a[thislp->poleCount-1][thislp->poleCount-1]));
-      csound->Die(csound, Str("gauss: ill-conditioned"));
-    }
+	     csound->Die(csound, Str("gauss: ill-conditioned"));*/
+      }
 
     b[thislp->poleCount-1] =
       c[thislp->poleCount-1] / a[thislp->poleCount-1][thislp->poleCount-1];
@@ -911,9 +916,7 @@ static const char *usage_txt[] = {
   Str_noop("-Q<maxcps>\tupper limit for pitch search (default 200 Hz)"),
   Str_noop("-v<verblevel>\tprinting verbosity: 0=none, 1=verbose, 2=debug"
            " (default 0)"),
-#ifndef OLPC
   Str_noop("-g\tgraphical display of results"),
-#endif
   Str_noop("-a\t\talternate (pole) file storage"),
   Str_noop("-- fname\tLog output to file"),
   Str_noop("see also:  Csound Manual Appendix"),
