@@ -103,10 +103,8 @@ static const char *usage_txt[] = {
   Str_noop("-s\tshort_int sound samples"),
   Str_noop("-l\tlong_int sound samples"),
   Str_noop("-f\tfloat sound samples"),
-#ifndef OLPC
   Str_noop("-R\tcontinually rewrite header while writing soundfile (WAV/AIFF)"),
   Str_noop("-H#\tprint a heartbeat style 1, 2 or 3 at each soundfile write"),
-#endif
   Str_noop("-N\tnotify (ring the bell) when score or miditrack is done"),
   Str_noop("-F fpnum\tamount to scale amplitude for next input"),
   Str_noop("-F fname\tfile of a scale table for next input"),
@@ -297,7 +295,6 @@ static int mixer_main(CSOUND *csound, int argc, char **argv)
           case 'f':
             outformch = set_output_format(csound, c, outformch);
             break;
-#ifndef OLPC
           case 'R':
             O->rewrt_hdr = 1;
             break;
@@ -309,7 +306,6 @@ static int mixer_main(CSOUND *csound, int argc, char **argv)
             }
             else O->heartbeat = 1;
             break;
-#endif
           case 'N':
             O->ringbell = 1;             /* notify on completion */
             break;
@@ -324,7 +320,7 @@ static int mixer_main(CSOUND *csound, int argc, char **argv)
         mixin[n].name = --s;
         if (!mixin[n].non_clear)
           for (i=1; i<5; i++) mixin[n].channels[i] = i;
-        if (n++ >= NUMBER_OF_FILES) {
+        if (UNLIKELY(n++ >= NUMBER_OF_FILES)) {
           usage(csound,Str("Too many mixin"));
         }
         mixin[n].start = -1;
@@ -507,7 +503,7 @@ static MYFLT gain(MIXER_GLOBALS *pp, int n, int i)
     if (i<mixin[n].table->x0) mixin[n].table = mixin[n].fulltable;
     while (i<mixin[n].table->x0 ||
            i>=mixin[n].table->x1) {/* Get correct segment */
-      if (pp->debug)
+      if (UNLIKELY(pp->debug))
         csound->Message(csound, "Table %d: %d (%d %f) -> %d %f [%f]\n",
                         n, i, mixin[n].table->x0, mixin[n].table->y0,
                         mixin[n].table->x1, mixin[n].table->y1,
@@ -531,7 +527,7 @@ static SNDFILE *MXsndgetset(CSOUND *csound, inputs *ddd)
     p->skiptime = FL(0.0);
     strcpy(p->sfname, ddd->name);
     /* open sndfil, do skiptime */
-    if ((infd = csound->sndgetset(csound, p)) == NULL)
+    if (UNLIKELY((infd = csound->sndgetset(csound, p)) == NULL))
       return NULL;
     p->getframes = p->framesrem;
     dur = (MYFLT) p->getframes / p->sr;
@@ -573,7 +569,8 @@ static void MixSound(MIXER_GLOBALS *pp, int n, SNDFILE *outfd)
       for (i = 0; i < n; i++)
         if (mixin[i].start > sample && mixin[i].start - sample < size)
           size = mixin[i].start - sample;
-      for (j=0; j<size*outputs; j++) buffer[j] = FL(0.0);
+      /* for (j=0; j<size*outputs; j++) buffer[j] = FL(0.0); */
+      memset(buffer, 0, sizeof(MYFLT)*size*outputs);
       this_block = 0;
       for (i = 0; i<n; i++) {
         if (sample >= mixin[i].start) {
@@ -610,7 +607,7 @@ static void MixSound(MIXER_GLOBALS *pp, int n, SNDFILE *outfd)
           more_to_read++;
       }
       for (j = 0; j < this_block * outputs; j++) {
-        if (buffer[j] > csound->e0dbfs || buffer[j] < -(csound->e0dbfs))
+        if (UNLIKELY(buffer[j] > csound->e0dbfs || buffer[j] < -(csound->e0dbfs)))
           pp->outrange++;
         if (buffer[j] == max) maxtimes++;
         if (buffer[j] == min) mintimes++;
@@ -651,7 +648,7 @@ static void MixSound(MIXER_GLOBALS *pp, int n, SNDFILE *outfd)
                                 "%d times\n"),
                             (int) min, lminpos, tpersample * (lminpos/outputs),
                             (int) lminpos % outputs, mintimes);
-    if (pp->outrange)
+    if (UNLIKELY(pp->outrange))
       csound->Message(csound, Str("%d sample%s out of range\n"),
                               pp->outrange, (pp->outrange == 1 ? "" : "s"));
     else
