@@ -70,7 +70,7 @@ static int writebuffer(CSOUND *csound, MYFLT *out_buf, int *block,
     sf_write_MYFLT(outfd, out_buf, length);
     (*block)++;
     if (csound->oparms->rewrt_hdr)
-       csound->rewriteheader(outfd);
+      csound->rewriteheader((struct SNDFILE *)outfd);
     switch (csound->oparms->heartbeat) {
       case 1:
         csound->MessageS(csound, CSOUNDMSG_REALTIME, "%c\010",
@@ -281,7 +281,6 @@ static int srconv(CSOUND *csound, int argc, char **argv)
           case 'f':
             outformch = set_output_format(csound, c, outformch);
             break;
-#ifndef OLPC
           case 'R':
             O->rewrt_hdr = 1;
             break;
@@ -293,7 +292,6 @@ static int srconv(CSOUND *csound, int argc, char **argv)
             }
             else O->heartbeat = 1;
             break;
-#endif
           case 'N':
             O->ringbell = 1;        /* notify on completion */
             break;
@@ -501,7 +499,7 @@ static int srconv(CSOUND *csound, int argc, char **argv)
 
  /* calculate increment: if decimating, then window is impulse response of low-
     pass filter with cutoff frequency at half of Rout; if interpolating,
-    then window is impulse response of lowpass filter with cutoff frequency
+    then window is ipulse response of lowpass filter with cutoff frequency
     at half of Rin. */
 
     fdel = ((MYFLT) (L * Rin) / Rout);
@@ -751,10 +749,8 @@ static const char *usage_txt[] = {
   Str_noop("-f\tfloat sound samples"),
   Str_noop("-r N\torchestra srate override"),
   Str_noop("-K\tDo not generate PEAK chunks"),
-#ifndef OLPC
   Str_noop("-R\tcontinually rewrite header while writing soundfile (WAV/AIFF)"),
   Str_noop("-H#\tprint a heartbeat style 1, 2 or 3 at each soundfile write"),
-#endif
   Str_noop("-N\tnotify (ring the bell) when score or miditrack is done"),
   Str_noop("-- fnam\tlog output to file"),
     NULL
